@@ -1,26 +1,7 @@
-/*
- * Copyright (C) 2008-2021 The QXmpp developers
- *
- * Authors:
- *	Ian Reinhart Geiser
- *	Jeremy Lainé
- *
- * Source:
- *	https://github.com/qxmpp-project/qxmpp
- *
- * This file is a part of QXmpp library.
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- */
+// SPDX-FileCopyrightText: 2010 Ian Reinhart Geiser <geiseri@kde.org>
+// SPDX-FileCopyrightText: 2010 Jeremy Lainé <jeremy.laine@m4x.org>
+//
+// SPDX-License-Identifier: LGPL-2.1-or-later
 
 #include "rpcClient.h"
 
@@ -50,10 +31,11 @@ void rpcClient::slotInvokeRemoteMethod()
 {
     QXmppRemoteMethodResult methodResult = m_rpcManager->callRemoteMethod(
         m_remoteJid, "RemoteInterface.echoString", "This is a test");
-    if (methodResult.hasError)
+    if (methodResult.hasError) {
         qDebug() << "Error:" << methodResult.code << methodResult.errorMessage;
-    else
+    } else {
         qDebug() << "Result:" << methodResult.result;
+    }
 }
 
 /// A presence was received.
@@ -66,8 +48,9 @@ void rpcClient::slotPresenceReceived(const QXmppPresence &presence)
     // do nothing
     if (QXmppUtils::jidToBareJid(configuration().jid()) == recipient ||
         QXmppUtils::jidToBareJid(presence.from()) != recipient ||
-        presence.type() != QXmppPresence::Available)
+        presence.type() != QXmppPresence::Available) {
         return;
+    }
 
     // invoke the remote method in 1 second
     m_remoteJid = presence.from();
