@@ -1,25 +1,6 @@
-/*
- * Copyright (C) 2008-2021 The QXmpp developers
- *
- * Author:
- *	Jeremy Lainé
- *
- * Source:
- *	https://github.com/qxmpp-project/qxmpp
- *
- * This file is a part of QXmpp library.
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- */
+// SPDX-FileCopyrightText: 2012 Jeremy Lainé <jeremy.laine@m4x.org>
+//
+// SPDX-License-Identifier: LGPL-2.1-or-later
 
 #include "example_7_archiveHandling.h"
 
@@ -97,8 +78,9 @@ void xmppClient::archiveListReceived(const QList<QXmppArchiveChat> &chats, const
         logStart("fetching collection first page");
         QXmppResultSetQuery rsmQuery;
         rsmQuery.setMax(m_pageSize);
-        if (m_pageDirection == PageBackwards)
+        if (m_pageDirection == PageBackwards) {
             rsmQuery.setBefore("");
+        }
         archiveManager->listCollections("", m_startDate, m_endDate, rsmQuery);
     } else if (!chats.size()) {
         logEnd("no items");
@@ -107,7 +89,7 @@ void xmppClient::archiveListReceived(const QList<QXmppArchiveChat> &chats, const
         for (const auto &chat : chats) {
             qDebug("chat start %s", qPrintable(chat.start().toString()));
             // NOTE: to actually retrieve conversations, uncomment this
-            //archiveManager->retrieveCollection(chat.with(), chat.start());
+            // archiveManager->retrieveCollection(chat.with(), chat.start());
         }
         if (!rsmReply.isNull()) {
             // fetch next page
