@@ -1,25 +1,6 @@
-/*
- * Copyright (C) 2008-2021 The QXmpp developers
- *
- * Author:
- *  Jeremy Lainé
- *
- * Source:
- *  https://github.com/qxmpp-project/qxmpp
- *
- * This file is a part of QXmpp library.
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- */
+// SPDX-FileCopyrightText: 2010 Jeremy Lainé <jeremy.laine@m4x.org>
+//
+// SPDX-License-Identifier: LGPL-2.1-or-later
 
 #include "QXmppArchiveIq.h"
 
@@ -115,12 +96,14 @@ void QXmppArchiveChat::toXml(QXmlStreamWriter *writer, const QXmppResultSetReply
     writer->writeStartElement(QStringLiteral("chat"));
     writer->writeDefaultNamespace(ns_archive);
     helperToXmlAddAttribute(writer, QStringLiteral("with"), m_with);
-    if (m_start.isValid())
+    if (m_start.isValid()) {
         helperToXmlAddAttribute(writer, QStringLiteral("start"), QXmppUtils::datetimeToString(m_start));
+    }
     helperToXmlAddAttribute(writer, QStringLiteral("subject"), m_subject);
     helperToXmlAddAttribute(writer, QStringLiteral("thread"), m_thread);
-    if (m_version)
+    if (m_version) {
         helperToXmlAddAttribute(writer, QStringLiteral("version"), QString::number(m_version));
+    }
 
     QDateTime prevTime = m_start;
 
@@ -131,8 +114,9 @@ void QXmppArchiveChat::toXml(QXmlStreamWriter *writer, const QXmppResultSetReply
         writer->writeEndElement();
         prevTime = message.date();
     }
-    if (!rsm.isNull())
+    if (!rsm.isNull()) {
         rsm.toXml(writer);
+    }
     writer->writeEndElement();
 }
 /// \endcond
@@ -258,7 +242,7 @@ bool QXmppArchiveChatIq::isArchiveChatIq(const QDomElement &element)
 {
     QDomElement chatElement = element.firstChildElement(QStringLiteral("chat"));
     return !chatElement.attribute(QStringLiteral("with")).isEmpty();
-    //return (chatElement.namespaceURI() == ns_archive);
+    // return (chatElement.namespaceURI() == ns_archive);
 }
 
 void QXmppArchiveChatIq::parseElementFromChild(const QDomElement &element)
@@ -414,18 +398,23 @@ void QXmppArchiveListIq::toXmlElementFromChild(QXmlStreamWriter *writer) const
 {
     writer->writeStartElement(QStringLiteral("list"));
     writer->writeDefaultNamespace(ns_archive);
-    if (!m_with.isEmpty())
+    if (!m_with.isEmpty()) {
         helperToXmlAddAttribute(writer, QStringLiteral("with"), m_with);
-    if (m_start.isValid())
+    }
+    if (m_start.isValid()) {
         helperToXmlAddAttribute(writer, QStringLiteral("start"), QXmppUtils::datetimeToString(m_start));
-    if (m_end.isValid())
+    }
+    if (m_end.isValid()) {
         helperToXmlAddAttribute(writer, QStringLiteral("end"), QXmppUtils::datetimeToString(m_end));
-    if (!m_rsmQuery.isNull())
+    }
+    if (!m_rsmQuery.isNull()) {
         m_rsmQuery.toXml(writer);
-    else if (!m_rsmReply.isNull())
+    } else if (!m_rsmReply.isNull()) {
         m_rsmReply.toXml(writer);
-    for (const auto &chat : m_chats)
+    }
+    for (const auto &chat : m_chats) {
         chat.toXml(writer);
+    }
     writer->writeEndElement();
 }
 
@@ -519,12 +508,15 @@ void QXmppArchiveRemoveIq::toXmlElementFromChild(QXmlStreamWriter *writer) const
 {
     writer->writeStartElement(QStringLiteral("remove"));
     writer->writeDefaultNamespace(ns_archive);
-    if (!m_with.isEmpty())
+    if (!m_with.isEmpty()) {
         helperToXmlAddAttribute(writer, QStringLiteral("with"), m_with);
-    if (m_start.isValid())
+    }
+    if (m_start.isValid()) {
         helperToXmlAddAttribute(writer, QStringLiteral("start"), QXmppUtils::datetimeToString(m_start));
-    if (m_end.isValid())
+    }
+    if (m_end.isValid()) {
         helperToXmlAddAttribute(writer, QStringLiteral("end"), QXmppUtils::datetimeToString(m_end));
+    }
     writer->writeEndElement();
 }
 /// \endcond
@@ -608,8 +600,9 @@ void QXmppArchiveRetrieveIq::toXmlElementFromChild(QXmlStreamWriter *writer) con
     writer->writeDefaultNamespace(ns_archive);
     helperToXmlAddAttribute(writer, QStringLiteral("with"), m_with);
     helperToXmlAddAttribute(writer, QStringLiteral("start"), QXmppUtils::datetimeToString(m_start));
-    if (!m_rsmQuery.isNull())
+    if (!m_rsmQuery.isNull()) {
         m_rsmQuery.toXml(writer);
+    }
     writer->writeEndElement();
 }
 /// \endcond
