@@ -1,25 +1,6 @@
-/*
- * Copyright (C) 2008-2020 The QXmpp developers
- *
- * Author:
- *  Jeremy Lainé
- *
- * Source:
- *  https://github.com/qxmpp-project/qxmpp
- *
- * This file is a part of QXmpp library.
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- */
+// SPDX-FileCopyrightText: 2010 Jeremy Lainé <jeremy.laine@m4x.org>
+//
+// SPDX-License-Identifier: LGPL-2.1-or-later
 
 #ifndef QXMPPDISCOVERY_H
 #define QXMPPDISCOVERY_H
@@ -33,29 +14,19 @@ class QXmppDiscoveryIdentityPrivate;
 class QXmppDiscoveryItemPrivate;
 class QXmppDiscoveryIqPrivate;
 
-///
-/// \brief QXmppDiscoveryIq represents a discovery IQ request or result
-/// containing a list of features and other information about an entity as
-/// defined by \xep{0030}: Service Discovery.
-///
-/// \ingroup Stanzas
-///
 class QXMPP_EXPORT QXmppDiscoveryIq : public QXmppIq
 {
 public:
-    ///
-    /// \brief Identity represents one of possibly multiple identities of an
-    /// XMPP entity obtained from a service discovery request as defined in
-    /// \xep{0030}: Service Discovery.
-    ///
     class QXMPP_EXPORT Identity
     {
     public:
         Identity();
         Identity(const Identity &other);
+        Identity(Identity &&);
         ~Identity();
 
         Identity &operator=(const Identity &other);
+        Identity &operator=(Identity &&);
 
         QString category() const;
         void setCategory(const QString &category);
@@ -73,18 +44,16 @@ public:
         QSharedDataPointer<QXmppDiscoveryIdentityPrivate> d;
     };
 
-    ///
-    /// \brief Item represents a related XMPP entity that can be queried using
-    /// \xep{0030}: Service Discovery.
-    ///
     class QXMPP_EXPORT Item
     {
     public:
         Item();
         Item(const Item &);
+        Item(Item &&);
         ~Item();
 
         Item &operator=(const Item &);
+        Item &operator=(Item &&);
 
         QString jid() const;
         void setJid(const QString &jid);
@@ -101,9 +70,11 @@ public:
 
     QXmppDiscoveryIq();
     QXmppDiscoveryIq(const QXmppDiscoveryIq &);
+    QXmppDiscoveryIq(QXmppDiscoveryIq &&);
     ~QXmppDiscoveryIq();
 
     QXmppDiscoveryIq &operator=(const QXmppDiscoveryIq &);
+    QXmppDiscoveryIq &operator=(QXmppDiscoveryIq &&);
 
     enum QueryType {
         InfoQuery,
@@ -131,9 +102,10 @@ public:
     QByteArray verificationString() const;
 
     static bool isDiscoveryIq(const QDomElement &element);
+    /// \cond
+    static bool checkIqType(const QString &tagName, const QString &xmlNamespace);
 
 protected:
-    /// \cond
     void parseElementFromChild(const QDomElement &element) override;
     void toXmlElementFromChild(QXmlStreamWriter *writer) const override;
     /// \endcond
