@@ -1,25 +1,6 @@
-/*
- * Copyright (C) 2008-2021 The QXmpp developers
- *
- * Author:
- *  Jeremy Lainé
- *
- * Source:
- *  https://github.com/qxmpp-project/qxmpp
- *
- * This file is a part of QXmpp library.
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- */
+// SPDX-FileCopyrightText: 2010 Jeremy Lainé <jeremy.laine@m4x.org>
+//
+// SPDX-License-Identifier: LGPL-2.1-or-later
 
 #include "QXmppElement.h"
 
@@ -31,13 +12,13 @@
 class QXmppElementPrivate
 {
 public:
-    QXmppElementPrivate();
+    QXmppElementPrivate() = default;
     QXmppElementPrivate(const QDomElement &element);
     ~QXmppElementPrivate();
 
-    QAtomicInt counter;
+    QAtomicInt counter = 1;
 
-    QXmppElementPrivate *parent;
+    QXmppElementPrivate *parent = nullptr;
     QMap<QString, QString> attributes;
     QList<QXmppElementPrivate *> children;
     QString name;
@@ -46,22 +27,18 @@ public:
     QByteArray serializedSource;
 };
 
-QXmppElementPrivate::QXmppElementPrivate()
-    : counter(1), parent(nullptr)
-{
-}
-
 QXmppElementPrivate::QXmppElementPrivate(const QDomElement &element)
-    : counter(1), parent(nullptr)
 {
-    if (element.isNull())
+    if (element.isNull()) {
         return;
+    }
 
     name = element.tagName();
     QString xmlns = element.namespaceURI();
     QString parentns = element.parentNode().namespaceURI();
-    if (!xmlns.isEmpty() && xmlns != parentns)
+    if (!xmlns.isEmpty() && xmlns != parentns) {
         attributes.insert("xmlns", xmlns);
+    }
     QDomNamedNodeMap attrs = element.attributes();
     for (int i = 0; i < attrs.size(); i++) {
         QDomAttr attr = attrs.item(i).toAttr();
@@ -86,16 +63,30 @@ QXmppElementPrivate::QXmppElementPrivate(const QDomElement &element)
 
 QXmppElementPrivate::~QXmppElementPrivate()
 {
-    for (auto *child : children)
-        if (!child->counter.deref())
+    for (auto *child : std::as_const(children)) {
+        if (!child->counter.deref()) {
             delete child;
+        }
+    }
 }
 
+///
+/// \class QXmppElement
+///
+/// QXmppElement represents a raw XML element with possible children.
+///
+
+///
+/// Default constructor
+///
 QXmppElement::QXmppElement()
 {
     d = new QXmppElementPrivate();
 }
 
+///
+/// Copy constructor
+///
 QXmppElement::QXmppElement(const QXmppElement &other)
 {
     other.d->counter.ref();
@@ -108,6 +99,9 @@ QXmppElement::QXmppElement(QXmppElementPrivate *other)
     d = other;
 }
 
+///
+/// Copy-construct DOM element contents
+///
 QXmppElement::QXmppElement(const QDomElement &element)
 {
     d = new QXmppElementPrivate(element);
@@ -115,26 +109,38 @@ QXmppElement::QXmppElement(const QDomElement &element)
 
 QXmppElement::~QXmppElement()
 {
-    if (!d->counter.deref())
+    if (!d->counter.deref()) {
         delete d;
+    }
 }
 
+///
+/// Assignment operator
+///
 QXmppElement &QXmppElement::operator=(const QXmppElement &other)
 {
-    if (this != &other)  // self-assignment check
-    {
+    // self-assignment check
+    if (this != &other) {
         other.d->counter.ref();
-        if (!d->counter.deref())
+        if (!d->counter.deref()) {
             delete d;
+        }
         d = other.d;
     }
     return *this;
 }
 
+///
+/// Creates a DOM element from the source element
+///
+/// The source DOM element is saved as XML and needs to be parsed again in this
+/// step.
+///
 QDomElement QXmppElement::sourceDomElement() const
 {
-    if (d->serializedSource.isEmpty())
+    if (d->serializedSource.isEmpty()) {
         return QDomElement();
+    }
 
     QDomDocument doc;
     if (!doc.setContent(d->serializedSource, true)) {
@@ -145,102 +151,157 @@ QDomElement QXmppElement::sourceDomElement() const
     return doc.documentElement();
 }
 
+///
+/// Returns the list of attributes
+///
 QStringList QXmppElement::attributeNames() const
 {
     return d->attributes.keys();
 }
 
+///
+/// Returns an attribute by name
+///
 QString QXmppElement::attribute(const QString &name) const
 {
     return d->attributes.value(name);
 }
 
+///
+/// Sets an attribute
+///
 void QXmppElement::setAttribute(const QString &name, const QString &value)
 {
     d->attributes.insert(name, value);
 }
 
+///
+/// Adds a child element
+///
 void QXmppElement::appendChild(const QXmppElement &child)
 {
-    if (child.d->parent == d)
+    if (child.d->parent == d) {
         return;
+    }
 
-    if (child.d->parent)
+    if (child.d->parent) {
         child.d->parent->children.removeAll(child.d);
-    else
+    } else {
         child.d->counter.ref();
+    }
     child.d->parent = d;
     d->children.append(child.d);
 }
 
+///
+/// Returns the first child element with the given name or the first child
+/// element if the given name is empty.
+///
 QXmppElement QXmppElement::firstChildElement(const QString &name) const
 {
-    for (auto *child_d : d->children)
-        if (name.isEmpty() || child_d->name == name)
+    for (auto *child_d : std::as_const(d->children)) {
+        if (name.isEmpty() || child_d->name == name) {
             return QXmppElement(child_d);
+        }
+    }
     return QXmppElement();
 }
 
+///
+/// Returns the next sibling element with the given name or the next sibling
+/// element if the given name is empty.
+///
 QXmppElement QXmppElement::nextSiblingElement(const QString &name) const
 {
-    if (!d->parent)
+    if (!d->parent) {
         return QXmppElement();
+    }
     const QList<QXmppElementPrivate *> &siblings_d = d->parent->children;
-    for (int i = siblings_d.indexOf(d) + 1; i < siblings_d.size(); i++)
-        if (name.isEmpty() || siblings_d[i]->name == name)
+    for (int i = siblings_d.indexOf(d) + 1; i < siblings_d.size(); i++) {
+        if (name.isEmpty() || siblings_d[i]->name == name) {
             return QXmppElement(siblings_d[i]);
+        }
+    }
     return QXmppElement();
 }
 
+///
+/// Returns true if the element is null
+///
 bool QXmppElement::isNull() const
 {
     return d->name.isEmpty();
 }
 
+///
+/// Removes a child element
+///
 void QXmppElement::removeChild(const QXmppElement &child)
 {
-    if (child.d->parent != d)
+    if (child.d->parent != d) {
         return;
+    }
 
     d->children.removeAll(child.d);
     child.d->counter.deref();
     child.d->parent = nullptr;
 }
 
+///
+/// Returns the tag name of the element
+///
 QString QXmppElement::tagName() const
 {
     return d->name;
 }
 
+///
+/// Sets the tag name of the element
+///
 void QXmppElement::setTagName(const QString &tagName)
 {
     d->name = tagName;
 }
 
+///
+/// Returns the text content of the element
+///
 QString QXmppElement::value() const
 {
     return d->value;
 }
 
+///
+/// Sets the text content of the element
+///
 void QXmppElement::setValue(const QString &value)
 {
     d->value = value;
 }
 
+///
+/// Serializes the element to XML
+///
 void QXmppElement::toXml(QXmlStreamWriter *writer) const
 {
-    if (isNull())
+    if (isNull()) {
         return;
+    }
 
     writer->writeStartElement(d->name);
-    if (d->attributes.contains("xmlns"))
+    if (d->attributes.contains("xmlns")) {
         writer->writeDefaultNamespace(d->attributes.value("xmlns"));
-    for (const auto &attr : d->attributes.keys())
-        if (attr != "xmlns")
-            helperToXmlAddAttribute(writer, attr, d->attributes.value(attr));
-    if (!d->value.isEmpty())
+    }
+    std::for_each(d->attributes.keyBegin(), d->attributes.keyEnd(), [this, writer](const QString &key) {
+        if (key != "xmlns") {
+            helperToXmlAddAttribute(writer, key, d->attributes.value(key));
+        }
+    });
+    if (!d->value.isEmpty()) {
         writer->writeCharacters(d->value);
-    for (auto *childPrivate : d->children)
+    }
+    for (auto *childPrivate : std::as_const(d->children)) {
         QXmppElement(childPrivate).toXml(writer);
+    }
     writer->writeEndElement();
 }
