@@ -1,25 +1,6 @@
-/*
- * Copyright (C) 2008-2021 The QXmpp developers
- *
- * Author:
- *  Manjeet Dahiya
- *
- * Source:
- *  https://github.com/qxmpp-project/qxmpp
- *
- * This file is a part of QXmpp library.
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- */
+// SPDX-FileCopyrightText: 2010 Manjeet Dahiya <manjeetdahiya@gmail.com>
+//
+// SPDX-License-Identifier: LGPL-2.1-or-later
 
 #include "QXmppEntityTimeIq.h"
 
@@ -28,47 +9,57 @@
 
 #include <QDomElement>
 
+///
 /// Returns the timezone offset in seconds.
 ///
-
 int QXmppEntityTimeIq::tzo() const
 {
     return m_tzo;
 }
 
+///
 /// Sets the timezone offset in seconds.
 ///
 /// \param tzo
-
+///
 void QXmppEntityTimeIq::setTzo(int tzo)
 {
     m_tzo = tzo;
 }
 
+///
 /// Returns the date/time in Coordinated Universal Time (UTC).
 ///
-
 QDateTime QXmppEntityTimeIq::utc() const
 {
     return m_utc;
 }
 
+///
 /// Sets the date/time in Coordinated Universal Time (UTC).
 ///
 /// \param utc
-
+///
 void QXmppEntityTimeIq::setUtc(const QDateTime &utc)
 {
     m_utc = utc;
 }
 
-/// \cond
+///
+/// Returns true, if the element is a valid entity time IQ.
+///
 bool QXmppEntityTimeIq::isEntityTimeIq(const QDomElement &element)
 {
     QDomElement timeElement = element.firstChildElement("time");
     return timeElement.namespaceURI() == ns_entity_time;
 }
 
+/// \cond
+bool QXmppEntityTimeIq::checkIqType(const QString &tagName, const QString &xmlns)
+{
+    return tagName == QStringLiteral("time") && xmlns == ns_entity_time;
+}
+
 void QXmppEntityTimeIq::parseElementFromChild(const QDomElement &element)
 {
     QDomElement timeElement = element.firstChildElement("time");
