@@ -1,25 +1,6 @@
-/*
- * Copyright (C) 2008-2021 The QXmpp developers
- *
- * Authors:
- *  Linus Jahn
- *
- * Source:
- *  https://github.com/qxmpp-project/qxmpp
- *
- * This file is a part of QXmpp library.
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- */
+// SPDX-FileCopyrightText: 2019 Linus Jahn <lnj@kaidan.im>
+//
+// SPDX-License-Identifier: LGPL-2.1-or-later
 
 #include "QXmppHttpUploadIq.h"
 
@@ -43,57 +24,70 @@ QXmppHttpUploadRequestIq::QXmppHttpUploadRequestIq()
 {
 }
 
+/// Default copy-constructor
 QXmppHttpUploadRequestIq::QXmppHttpUploadRequestIq(const QXmppHttpUploadRequestIq &) = default;
-
+/// Default move-constructor
+QXmppHttpUploadRequestIq::QXmppHttpUploadRequestIq(QXmppHttpUploadRequestIq &&) = default;
 QXmppHttpUploadRequestIq::~QXmppHttpUploadRequestIq() = default;
-
+/// Default assignment operator
 QXmppHttpUploadRequestIq &QXmppHttpUploadRequestIq::operator=(const QXmppHttpUploadRequestIq &) = default;
+/// Default assignment operator
+QXmppHttpUploadRequestIq &QXmppHttpUploadRequestIq::operator=(QXmppHttpUploadRequestIq &&) = default;
 
+///
 /// Returns the file name of the file to be uploaded.
-
+///
 QString QXmppHttpUploadRequestIq::fileName() const
 {
     return d->fileName;
 }
 
+///
 /// Sets the file name. The upload service will use this to create the upload/
 /// download URLs. This may also differ from the actual file name to get a
 /// different URL. It's not required to replace special characters (this is the
 /// server's job).
-
+///
 void QXmppHttpUploadRequestIq::setFileName(const QString &fileName)
 {
     d->fileName = fileName;
 }
 
+///
 /// Returns the file's size in bytes.
-
+///
 qint64 QXmppHttpUploadRequestIq::size() const
 {
     return d->size;
 }
 
+///
 /// Sets the file's size in bytes.
-
+///
 void QXmppHttpUploadRequestIq::setSize(qint64 size)
 {
     d->size = size;
 }
 
+///
 /// Returns the (optional) MIME-type of the file.
-
+///
 QMimeType QXmppHttpUploadRequestIq::contentType() const
 {
     return d->contentType;
 }
 
+///
 /// Sets the MIME-type of the file. This is optional.
-
+///
 void QXmppHttpUploadRequestIq::setContentType(const QMimeType &type)
 {
     d->contentType = type;
 }
 
+///
+/// Returns true, if the the element is an HTTP File Upload slot request IQ.
+///
 bool QXmppHttpUploadRequestIq::isHttpUploadRequestIq(const QDomElement &element)
 {
     if (element.tagName() == "iq") {
@@ -112,8 +106,9 @@ void QXmppHttpUploadRequestIq::parseElementFromChild(const QDomElement &element)
     if (request.hasAttribute("content-type")) {
         QMimeDatabase mimeDb;
         QMimeType type = mimeDb.mimeTypeForName(request.attribute("content-type"));
-        if (!type.isDefault() && type.isValid())
+        if (!type.isDefault() && type.isValid()) {
             d->contentType = type;
+        }
     }
 }
 
@@ -125,8 +120,9 @@ void QXmppHttpUploadRequestIq::toXmlElementFromChild(QXmlStreamWriter *writer) c
     writer->writeAttribute("filename", d->fileName);
     writer->writeAttribute("size", QString::number(d->size));
     // content-type is optional
-    if (!d->contentType.isDefault() && d->contentType.isValid())
+    if (!d->contentType.isDefault() && d->contentType.isValid()) {
         writer->writeAttribute("content-type", d->contentType.name());
+    }
     writer->writeEndElement();
 }
 /// \endcond
@@ -144,62 +140,77 @@ QXmppHttpUploadSlotIq::QXmppHttpUploadSlotIq()
 {
 }
 
+/// Default copy-constructor
 QXmppHttpUploadSlotIq::QXmppHttpUploadSlotIq(const QXmppHttpUploadSlotIq &) = default;
-
+/// Default move-constructor
+QXmppHttpUploadSlotIq::QXmppHttpUploadSlotIq(QXmppHttpUploadSlotIq &&) = default;
 QXmppHttpUploadSlotIq::~QXmppHttpUploadSlotIq() = default;
-
+/// Default assignment operator
 QXmppHttpUploadSlotIq &QXmppHttpUploadSlotIq::operator=(const QXmppHttpUploadSlotIq &) = default;
+/// Default move-assignment operator
+QXmppHttpUploadSlotIq &QXmppHttpUploadSlotIq::operator=(QXmppHttpUploadSlotIq &&) = default;
 
+///
 /// Returns the URL for uploading via. HTTP PUT.
-
+///
 QUrl QXmppHttpUploadSlotIq::putUrl() const
 {
     return d->putUrl;
 }
 
+///
 /// Sets the URL the client should use for uploading.
-
+///
 void QXmppHttpUploadSlotIq::setPutUrl(const QUrl &putUrl)
 {
     d->putUrl = putUrl;
 }
 
+///
 /// Returns the URL to where the file will be served.
-
+///
 QUrl QXmppHttpUploadSlotIq::getUrl() const
 {
     return d->getUrl;
 }
 
+///
 /// Sets the download URL.
-
+///
 void QXmppHttpUploadSlotIq::setGetUrl(const QUrl &getUrl)
 {
     d->getUrl = getUrl;
 }
 
+///
 /// Returns a map of header fields (header name -> value) that need to be
 /// included in the PUT (upload) request. This won't contain any other fields
 /// than: "Authorization", "Cookie" or "Expires".
-
+///
 QMap<QString, QString> QXmppHttpUploadSlotIq::putHeaders() const
 {
     return d->putHeaders;
 }
 
+///
 /// Sets the header fields the client needs to include in the PUT (upload)
 /// request. All fields other than "Authorization", "Cookie" or "Expires" will
 /// be ignored.
-
+///
 void QXmppHttpUploadSlotIq::setPutHeaders(const QMap<QString, QString> &putHeaders)
 {
     d->putHeaders.clear();
-    for (QString &name : putHeaders.keys()) {
-        if (name == "Authorization" || name == "Cookie" || name == "Expires")
-            d->putHeaders[name] = putHeaders[name];
-    }
+    std::for_each(putHeaders.keyBegin(), putHeaders.keyEnd(),
+                  [this, &putHeaders](const QString &name) {
+                      if (name == "Authorization" || name == "Cookie" || name == "Expires") {
+                          d->putHeaders.insert(name, putHeaders[name]);
+                      }
+                  });
 }
 
+///
+/// Returns true, if the the element is an HTTP File Upload slot result IQ.
+///
 bool QXmppHttpUploadSlotIq::isHttpUploadSlotIq(const QDomElement &element)
 {
     if (element.tagName() == "iq") {
@@ -236,14 +247,12 @@ void QXmppHttpUploadSlotIq::toXmlElementFromChild(QXmlStreamWriter *writer) cons
 
     writer->writeStartElement("put");
     writer->writeAttribute("url", d->putUrl.toEncoded());
-    if (!d->putHeaders.isEmpty()) {
-        for (const QString &name : d->putHeaders.keys()) {
-            writer->writeStartElement("header");
-            writer->writeAttribute("name", name);
-            writer->writeCharacters(d->putHeaders[name]);
-            writer->writeEndElement();
-        }
-    }
+    std::for_each(d->putHeaders.keyBegin(), d->putHeaders.keyEnd(), [=](const QString &name) {
+        writer->writeStartElement("header");
+        writer->writeAttribute("name", name);
+        writer->writeCharacters(d->putHeaders.value(name));
+        writer->writeEndElement();
+    });
     writer->writeEndElement();
 
     writer->writeStartElement("get");
