@@ -1,25 +1,6 @@
-/*
- * Copyright (C) 2008-2021 The QXmpp developers
- *
- * Author:
- *  Manjeet Dahiya
- *
- * Source:
- *  https://github.com/qxmpp-project/qxmpp
- *
- * This file is a part of QXmpp library.
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- */
+// SPDX-FileCopyrightText: 2009 Manjeet Dahiya <manjeetdahiya@gmail.com>
+//
+// SPDX-License-Identifier: LGPL-2.1-or-later
 
 #include "QXmppIq.h"
 
@@ -41,10 +22,11 @@ public:
     QXmppIq::Type type;
 };
 
+///
 /// Constructs a QXmppIq with the specified \a type.
 ///
 /// \param type
-
+///
 QXmppIq::QXmppIq(QXmppIq::Type type)
     : QXmppStanza(), d(new QXmppIqPrivate)
 {
@@ -53,37 +35,29 @@ QXmppIq::QXmppIq(QXmppIq::Type type)
 }
 
 /// Constructs a copy of \a other.
-
-QXmppIq::QXmppIq(const QXmppIq &other)
-    : QXmppStanza(other), d(other.d)
-{
-}
-
-QXmppIq::~QXmppIq()
-{
-}
+QXmppIq::QXmppIq(const QXmppIq &other) = default;
+/// Default move-constructor.
+QXmppIq::QXmppIq(QXmppIq &&) = default;
+QXmppIq::~QXmppIq() = default;
 
 /// Assigns \a other to this IQ.
+QXmppIq &QXmppIq::operator=(const QXmppIq &other) = default;
+/// Move-assignment operator.
+QXmppIq &QXmppIq::operator=(QXmppIq &&) = default;
 
-QXmppIq &QXmppIq::operator=(const QXmppIq &other)
-{
-    QXmppStanza::operator=(other);
-    d = other.d;
-    return *this;
-}
-
+///
 /// Returns the IQ's type.
 ///
-
 QXmppIq::Type QXmppIq::type() const
 {
     return d->type;
 }
 
+///
 /// Sets the IQ's type.
 ///
 /// \param type
-
+///
 void QXmppIq::setType(QXmppIq::Type type)
 {
     d->type = type;
@@ -142,7 +116,9 @@ void QXmppIq::toXml(QXmlStreamWriter *xmlWriter) const
 
 void QXmppIq::toXmlElementFromChild(QXmlStreamWriter *writer) const
 {
-    for (const QXmppElement &extension : extensions())
+    const auto exts = extensions();
+    for (const QXmppElement &extension : exts) {
         extension.toXml(writer);
+    }
 }
 /// \endcond
