@@ -1,25 +1,6 @@
-/*
- * Copyright (C) 2008-2021 The QXmpp developers
- *
- * Author:
- *  Manjeet Dahiya
- *
- * Source:
- *  https://github.com/qxmpp-project/qxmpp
- *
- * This file is a part of QXmpp library.
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- */
+// SPDX-FileCopyrightText: 2009 Manjeet Dahiya <manjeetdahiya@gmail.com>
+//
+// SPDX-License-Identifier: LGPL-2.1-or-later
 
 #ifndef QXMPPIQ_H
 #define QXMPPIQ_H
@@ -51,9 +32,11 @@ public:
 
     QXmppIq(QXmppIq::Type type = QXmppIq::Get);
     QXmppIq(const QXmppIq &other);
+    QXmppIq(QXmppIq &&);
     ~QXmppIq() override;
 
     QXmppIq &operator=(const QXmppIq &other);
+    QXmppIq &operator=(QXmppIq &&);
 
     QXmppIq::Type type() const;
     void setType(QXmppIq::Type);
@@ -64,7 +47,6 @@ public:
     void parse(const QDomElement &element) override;
     void toXml(QXmlStreamWriter *writer) const override;
 
-protected:
     virtual void parseElementFromChild(const QDomElement &element);
     virtual void toXmlElementFromChild(QXmlStreamWriter *writer) const;
     /// \endcond
