@@ -1,26 +1,7 @@
-/*
- * Copyright (C) 2008-2021 The QXmpp developers
- *
- * Authors:
- *  Manjeet Dahiya
- *  Jeremy Lainé
- *
- * Source:
- *  https://github.com/qxmpp-project/qxmpp
- *
- * This file is a part of QXmpp library.
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- */
+// SPDX-FileCopyrightText: 2009 Manjeet Dahiya <manjeetdahiya@gmail.com>
+// SPDX-FileCopyrightText: 2010 Jeremy Lainé <jeremy.laine@m4x.org>
+//
+// SPDX-License-Identifier: LGPL-2.1-or-later
 
 #include "QXmppLogger.h"
 
@@ -86,8 +67,9 @@ QXmppLoggable::QXmppLoggable(QObject *parent)
 void QXmppLoggable::childEvent(QChildEvent *event)
 {
     auto *child = qobject_cast<QXmppLoggable *>(event->child());
-    if (!child)
+    if (!child) {
         return;
+    }
 
     if (event->added()) {
         relaySignals(child, this);
@@ -139,8 +121,9 @@ QXmppLogger::~QXmppLogger()
 
 QXmppLogger *QXmppLogger::getLogger()
 {
-    if (!m_logger)
+    if (!m_logger) {
         m_logger = new QXmppLogger();
+    }
 
     return m_logger;
 }
@@ -184,8 +167,9 @@ void QXmppLogger::setMessageTypes(QXmppLogger::MessageTypes types)
 void QXmppLogger::log(QXmppLogger::MessageType type, const QString &text)
 {
     // filter messages
-    if (!d->messageTypes.testFlag(type))
+    if (!d->messageTypes.testFlag(type)) {
         return;
+    }
 
     switch (d->loggingType) {
     case QXmppLogger::FileLogging:
@@ -199,7 +183,7 @@ void QXmppLogger::log(QXmppLogger::MessageType type, const QString &text)
         std::cout << qPrintable(formatted(type, text)) << std::endl;
         break;
     case QXmppLogger::SignalLogging:
-        emit message(type, text);
+        Q_EMIT message(type, text);
         break;
     default:
         break;
