@@ -1,25 +1,6 @@
-/*
- * Copyright (C) 2008-2020 The QXmpp developers
- *
- * Author:
- *  Niels Ole Salscheider
- *
- * Source:
- *  https://github.com/qxmpp-project/qxmpp
- *
- * This file is a part of QXmpp library.
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- */
+// SPDX-FileCopyrightText: 2016 Niels Ole Salscheider <niels_ole@salscheider-online.de>
+//
+// SPDX-License-Identifier: LGPL-2.1-or-later
 
 #ifndef QXMPPMAMIQ_H
 #define QXMPPMAMIQ_H
@@ -33,22 +14,16 @@
 class QXmppMamQueryIqPrivate;
 class QXmppMamResultIqPrivate;
 
-///
-/// \brief The QXmppMamQueryIq class represents the query IQ for
-/// \xep{0313}: Message Archive Management.
-///
-/// \ingroup Stanzas
-///
-/// \since QXmpp 1.0
-///
-class QXmppMamQueryIq : public QXmppIq
+class QXMPP_EXPORT QXmppMamQueryIq : public QXmppIq
 {
 public:
     QXmppMamQueryIq();
     QXmppMamQueryIq(const QXmppMamQueryIq &);
+    QXmppMamQueryIq(QXmppMamQueryIq &&);
     ~QXmppMamQueryIq();
 
     QXmppMamQueryIq &operator=(const QXmppMamQueryIq &);
+    QXmppMamQueryIq &operator=(QXmppMamQueryIq &&);
 
     QXmppDataForm form() const;
     void setForm(const QXmppDataForm &form);
@@ -59,43 +34,41 @@ public:
     QString queryId() const;
     void setQueryId(const QString &id);
 
+    /// \cond
     static bool isMamQueryIq(const QDomElement &element);
 
 protected:
     void parseElementFromChild(const QDomElement &element) override;
     void toXmlElementFromChild(QXmlStreamWriter *writer) const override;
+    /// \endcond
 
 private:
     QSharedDataPointer<QXmppMamQueryIqPrivate> d;
 };
 
-///
-/// \brief The QXmppMamQueryIq class represents the result IQ for
-/// \xep{0313}: Message Archive Management.
-///
-/// \ingroup Stanzas
-///
-/// \since QXmpp 1.0
-///
-class QXmppMamResultIq : public QXmppIq
+class QXMPP_EXPORT QXmppMamResultIq : public QXmppIq
 {
 public:
     QXmppMamResultIq();
     QXmppMamResultIq(const QXmppMamResultIq &);
+    QXmppMamResultIq(QXmppMamResultIq &&);
     ~QXmppMamResultIq();
 
     QXmppMamResultIq &operator=(const QXmppMamResultIq &);
+    QXmppMamResultIq &operator=(QXmppMamResultIq &&);
 
     QXmppResultSetReply resultSetReply() const;
     void setResultSetReply(const QXmppResultSetReply &resultSetReply);
     bool complete() const;
     void setComplete(bool complete);
 
+    /// \cond
     static bool isMamResultIq(const QDomElement &element);
 
 protected:
     void parseElementFromChild(const QDomElement &element) override;
     void toXmlElementFromChild(QXmlStreamWriter *writer) const override;
+    /// \endcond
 
 private:
     QSharedDataPointer<QXmppMamResultIqPrivate> d;
