@@ -1,25 +1,6 @@
-/*
- * Copyright (C) 2008-2021 The QXmpp developers
- *
- * Author:
- *  Linus Jahn
- *
- * Source:
- *  https://github.com/qxmpp-project/qxmpp
- *
- * This file is a part of QXmpp library.
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- */
+// SPDX-FileCopyrightText: 2019 Linus Jahn <lnj@kaidan.im>
+//
+// SPDX-License-Identifier: LGPL-2.1-or-later
 
 #include "QXmppMixIq.h"
 
@@ -57,11 +38,15 @@ QXmppMixIq::QXmppMixIq()
 {
 }
 
-QXmppMixIq::QXmppMixIq(const QXmppMixIq&) = default;
-
+/// Default copy-constructor
+QXmppMixIq::QXmppMixIq(const QXmppMixIq &) = default;
+/// Default move-constructor
+QXmppMixIq::QXmppMixIq(QXmppMixIq &&) = default;
 QXmppMixIq::~QXmppMixIq() = default;
-
-QXmppMixIq& QXmppMixIq::operator=(const QXmppMixIq&) = default;
+/// Default assignment operator
+QXmppMixIq &QXmppMixIq::operator=(const QXmppMixIq &) = default;
+/// Default move-assignment operator
+QXmppMixIq &QXmppMixIq::operator=(QXmppMixIq &&) = default;
 
 /// Returns the channel JID. It also contains a participant id for Join/
 /// ClientJoin results.
@@ -74,7 +59,7 @@ QString QXmppMixIq::jid() const
 /// Sets the channel JID. For results of Join/ClientJoin queries this also
 /// needs to contain a participant id.
 
-void QXmppMixIq::setJid(const QString& jid)
+void QXmppMixIq::setJid(const QString &jid)
 {
     d->jid = jid;
 }
@@ -91,7 +76,7 @@ QString QXmppMixIq::channelName() const
 /// create a new channel, this can also be left empty to let the server
 /// generate a name.
 
-void QXmppMixIq::setChannelName(const QString& channelName)
+void QXmppMixIq::setChannelName(const QString &channelName)
 {
     d->channelName = channelName;
 }
@@ -106,7 +91,7 @@ QStringList QXmppMixIq::nodes() const
 /// Sets the nodes to subscribe to. Note that for UpdateSubscription queries
 /// you only need to include the new subscriptions.
 
-void QXmppMixIq::setNodes(const QStringList& nodes)
+void QXmppMixIq::setNodes(const QStringList &nodes)
 {
     d->nodes = nodes;
 }
@@ -120,7 +105,7 @@ QString QXmppMixIq::nick() const
 
 /// Sets the nickname for the channel.
 
-void QXmppMixIq::setNick(const QString& nick)
+void QXmppMixIq::setNick(const QString &nick)
 {
     d->nick = nick;
 }
@@ -140,75 +125,87 @@ void QXmppMixIq::setActionType(QXmppMixIq::Type type)
 }
 
 /// \cond
-bool QXmppMixIq::isMixIq(const QDomElement& element)
+bool QXmppMixIq::isMixIq(const QDomElement &element)
 {
-    const QDomElement& child = element.firstChildElement();
+    const QDomElement &child = element.firstChildElement();
     return !child.isNull() && (child.namespaceURI() == ns_mix || child.namespaceURI() == ns_mix_pam);
 }
 
-void QXmppMixIq::parseElementFromChild(const QDomElement& element)
+void QXmppMixIq::parseElementFromChild(const QDomElement &element)
 {
     QDomElement child = element.firstChildElement();
     // determine action type
-    d->actionType = (QXmppMixIq::Type)MIX_ACTION_TYPES.indexOf(child.tagName());
+    if (auto index = MIX_ACTION_TYPES.indexOf(child.tagName()); index >= 0) {
+        d->actionType = Type(index);
+    }
 
     if (child.namespaceURI() == ns_mix_pam) {
-        if (child.hasAttribute(QStringLiteral("channel")))
+        if (child.hasAttribute(QStringLiteral("channel"))) {
             d->jid = child.attribute(QStringLiteral("channel"));
+        }
 
         child = child.firstChildElement();
     }
 
     if (!child.isNull() && child.namespaceURI() == ns_mix) {
-        if (child.hasAttribute(QStringLiteral("jid")))
+        if (child.hasAttribute(QStringLiteral("jid"))) {
             d->jid = child.attribute(QStringLiteral("jid"));
-        if (child.hasAttribute(QStringLiteral("channel")))
+        }
+        if (child.hasAttribute(QStringLiteral("channel"))) {
             d->channelName = child.attribute(QStringLiteral("channel"));
+        }
 
         QDomElement subChild = child.firstChildElement();
         while (!subChild.isNull()) {
-            if (subChild.tagName() == QStringLiteral("subscribe"))
+            if (subChild.tagName() == QStringLiteral("subscribe")) {
                 d->nodes << subChild.attribute(QStringLiteral("node"));
-            else if (subChild.tagName() == QStringLiteral("nick"))
+            } else if (subChild.tagName() == QStringLiteral("nick")) {
                 d->nick = subChild.text();
+            }
 
             subChild = subChild.nextSiblingElement();
         }
     }
 }
 
-void QXmppMixIq::toXmlElementFromChild(QXmlStreamWriter* writer) const
+void QXmppMixIq::toXmlElementFromChild(QXmlStreamWriter *writer) const
 {
-    if (d->actionType == None)
+    if (d->actionType == None) {
         return;
+    }
 
     writer->writeStartElement(MIX_ACTION_TYPES.at(d->actionType));
     if (d->actionType == ClientJoin || d->actionType == ClientLeave) {
         writer->writeDefaultNamespace(ns_mix_pam);
-        if (type() == Set)
+        if (type() == Set) {
             helperToXmlAddAttribute(writer, QStringLiteral("channel"), d->jid);
+        }
 
-        if (d->actionType == ClientJoin)
+        if (d->actionType == ClientJoin) {
             writer->writeStartElement(QStringLiteral("join"));
-        else if (d->actionType == ClientLeave)
+        } else if (d->actionType == ClientLeave) {
             writer->writeStartElement(QStringLiteral("leave"));
+        }
     }
 
     writer->writeDefaultNamespace(ns_mix);
     helperToXmlAddAttribute(writer, QStringLiteral("channel"), d->channelName);
-    if (type() == Result)
+    if (type() == Result) {
         helperToXmlAddAttribute(writer, QStringLiteral("jid"), d->jid);
+    }
 
-    for (const auto& node : d->nodes) {
+    for (const auto &node : d->nodes) {
         writer->writeStartElement(QStringLiteral("subscribe"));
         writer->writeAttribute(QStringLiteral("node"), node);
         writer->writeEndElement();
     }
-    if (!d->nick.isEmpty())
+    if (!d->nick.isEmpty()) {
         writer->writeTextElement(QStringLiteral("nick"), d->nick);
+    }
 
     writer->writeEndElement();
-    if (d->actionType == ClientJoin || d->actionType == ClientLeave)
+    if (d->actionType == ClientJoin || d->actionType == ClientLeave) {
         writer->writeEndElement();
+    }
 }
 /// \endcond
