@@ -1,29 +1,12 @@
-/*
- * Copyright (C) 2008-2021 The QXmpp developers
- *
- * Author:
- *  Manjeet Dahiya
- *
- * Source:
- *  https://github.com/qxmpp-project/qxmpp
- *
- * This file is a part of QXmpp library.
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- */
+// SPDX-FileCopyrightText: 2009 Manjeet Dahiya <manjeetdahiya@gmail.com>
+// SPDX-FileCopyrightText: 2022 Melvin Keskin <melvo@olomono.de>
+//
+// SPDX-License-Identifier: LGPL-2.1-or-later
 
 #include "QXmppPresence.h"
 
 #include "QXmppConstants_p.h"
+#include "QXmppJingleIq.h"
 #include "QXmppUtils.h"
 
 #include <QDateTime>
@@ -78,6 +61,10 @@ public:
     QByteArray photoHash;
     QXmppPresence::VCardUpdateType vCardUpdateType;
 
+    // XEP-0272: Multiparty Jingle (Muji)
+    bool isPreparingMujiSession = false;
+    QVector<QXmppJingleIq::Content> mujiContents;
+
     // XEP-0319: Last User Interaction in Presence
     QDateTime lastUserInteraction;
 
@@ -95,27 +82,25 @@ QXmppPresencePrivate::QXmppPresencePrivate()
 {
 }
 
+///
 /// Constructs a QXmppPresence.
 ///
-/// \param type
-
 QXmppPresence::QXmppPresence(QXmppPresence::Type type)
     : d(new QXmppPresencePrivate)
 {
     d->type = type;
 }
 
-/// Constructs a copy of \a other.
-
+/// Copy-constructor.
 QXmppPresence::QXmppPresence(const QXmppPresence &other) = default;
-
+/// Move-constructor.
+QXmppPresence::QXmppPresence(QXmppPresence &&) = default;
 /// Destroys a QXmppPresence.
-
 QXmppPresence::~QXmppPresence() = default;
-
-/// Assigns \a other to this presence.
-
+/// Assignemnt operator.
 QXmppPresence &QXmppPresence::operator=(const QXmppPresence &other) = default;
+/// Move-assignemnt operator.
+QXmppPresence &QXmppPresence::operator=(QXmppPresence &&) = default;
 
 ///
 /// Indicates if the QXmppStanza is a stanza in the XMPP sence (i. e. a message,
@@ -274,6 +259,54 @@ QStringList QXmppPresence::capabilityExt() const
     return d->capabilityExt;
 }
 
+///
+/// Returns whether a \xep{0272, Multiparty Jingle (Muji)} session is being prepared.
+///
+/// \return whether a Muji session is being prepared
+///
+/// \since QXmpp 1.5
+///
+bool QXmppPresence::isPreparingMujiSession() const
+{
+    return d->isPreparingMujiSession;
+}
+
+///
+/// Sets whether a \xep{0272, Multiparty Jingle (Muji)} session is being prepared.
+///
+/// \param isPreparingMujiSession whether a Muji session is being prepared
+///
+/// \since QXmpp 1.5
+///
+void QXmppPresence::setIsPreparingMujiSession(bool isPreparingMujiSession)
+{
+    d->isPreparingMujiSession = isPreparingMujiSession;
+}
+
+///
+/// Returns \xep{0272, Multiparty Jingle (Muji)} contents.
+///
+/// \return Muji contents
+///
+/// \since QXmpp 1.5
+///
+QVector<QXmppJingleIq::Content> QXmppPresence::mujiContents() const
+{
+    return d->mujiContents;
+}
+
+///
+/// Sets \xep{0272, Multiparty Jingle (Muji)} contents.
+///
+/// \param mujiContents Muji contents
+///
+/// \since QXmpp 1.5
+///
+void QXmppPresence::setMujiContents(const QVector<QXmppJingleIq::Content> &mujiContents)
+{
+    d->mujiContents = mujiContents;
+}
+
 /// Returns the MUC item.
 
 QXmppMucItem QXmppPresence::mucItem() const
@@ -399,8 +432,9 @@ void QXmppPresence::parse(const QDomElement &element)
 
     // attributes
     int type = PRESENCE_TYPES.indexOf(element.attribute(QStringLiteral("type")));
-    if (type > -1)
+    if (type > -1) {
         d->type = Type(type);
+    }
 
     QXmppElementList unknownElements;
     QDomElement childElement = element.firstChildElement();
@@ -408,8 +442,9 @@ void QXmppPresence::parse(const QDomElement &element)
     while (!childElement.isNull()) {
         if (childElement.tagName() == QStringLiteral("show")) {
             int availableStatusType = AVAILABLE_STATUS_TYPES.indexOf(childElement.text());
-            if (availableStatusType > -1)
+            if (availableStatusType > -1) {
                 d->availableStatusType = AvailableStatusType(availableStatusType);
+            }
         } else if (childElement.tagName() == QStringLiteral("status")) {
             d->statusText = childElement.text();
         } else if (childElement.tagName() == QStringLiteral("priority")) {
@@ -460,10 +495,24 @@ void QXmppPresence::parseExtension(const QDomElement &element, QXmppElementList
             d->vCardUpdateType = VCardUpdateNotReady;
         } else {
             d->photoHash = QByteArray::fromHex(photoElement.text().toLatin1());
-            if (d->photoHash.isEmpty())
+            if (d->photoHash.isEmpty()) {
                 d->vCardUpdateType = VCardUpdateNoPhoto;
-            else
+            } else {
                 d->vCardUpdateType = VCardUpdateValidPhoto;
+            }
+        }
+        // XEP-0272: Multiparty Jingle (Muji)
+    } else if (element.tagName() == QStringLiteral("muji") && element.namespaceURI() == ns_muji) {
+        if (!element.firstChildElement(QStringLiteral("preparing")).isNull()) {
+            d->isPreparingMujiSession = true;
+        }
+
+        for (auto contentElement = element.firstChildElement(QStringLiteral("content"));
+             !contentElement.isNull();
+             contentElement = contentElement.nextSiblingElement(QStringLiteral("content"))) {
+            QXmppJingleIq::Content content;
+            content.parse(contentElement);
+            d->mujiContents.append(content);
         }
         // XEP-0319: Last User Interaction in Presence
     } else if (element.tagName() == QStringLiteral("idle") && element.namespaceURI() == ns_idle) {
@@ -490,12 +539,15 @@ void QXmppPresence::toXml(QXmlStreamWriter *xmlWriter) const
     helperToXmlAddAttribute(xmlWriter, QStringLiteral("type"), PRESENCE_TYPES.at(d->type));
 
     const QString show = AVAILABLE_STATUS_TYPES.at(d->availableStatusType);
-    if (!show.isEmpty())
+    if (!show.isEmpty()) {
         helperToXmlAddTextElement(xmlWriter, QStringLiteral("show"), show);
-    if (!d->statusText.isEmpty())
+    }
+    if (!d->statusText.isEmpty()) {
         helperToXmlAddTextElement(xmlWriter, QStringLiteral("status"), d->statusText);
-    if (d->priority != 0)
+    }
+    if (d->priority != 0) {
         helperToXmlAddTextElement(xmlWriter, QStringLiteral("priority"), QString::number(d->priority));
+    }
 
     error().toXml(xmlWriter);
 
@@ -503,16 +555,18 @@ void QXmppPresence::toXml(QXmlStreamWriter *xmlWriter) const
     if (d->mucSupported) {
         xmlWriter->writeStartElement(QStringLiteral("x"));
         xmlWriter->writeDefaultNamespace(ns_muc);
-        if (!d->mucPassword.isEmpty())
+        if (!d->mucPassword.isEmpty()) {
             xmlWriter->writeTextElement(QStringLiteral("password"), d->mucPassword);
+        }
         xmlWriter->writeEndElement();
     }
 
     if (!d->mucItem.isNull() || !d->mucStatusCodes.isEmpty()) {
         xmlWriter->writeStartElement(QStringLiteral("x"));
         xmlWriter->writeDefaultNamespace(ns_muc_user);
-        if (!d->mucItem.isNull())
+        if (!d->mucItem.isNull()) {
             d->mucItem.toXml(xmlWriter);
+        }
         for (const auto code : d->mucStatusCodes) {
             xmlWriter->writeStartElement(QStringLiteral("status"));
             xmlWriter->writeAttribute(QStringLiteral("code"), QString::number(code));
@@ -550,6 +604,22 @@ void QXmppPresence::toXml(QXmlStreamWriter *xmlWriter) const
         xmlWriter->writeEndElement();
     }
 
+    // XEP-0272: Multiparty Jingle (Muji)
+    if (d->isPreparingMujiSession || !d->mujiContents.isEmpty()) {
+        xmlWriter->writeStartElement(QStringLiteral("muji"));
+        xmlWriter->writeDefaultNamespace(ns_muji);
+
+        if (d->isPreparingMujiSession) {
+            xmlWriter->writeEmptyElement(QStringLiteral("preparing"));
+        }
+
+        for (const auto &mujiContent : d->mujiContents) {
+            mujiContent.toXml(xmlWriter);
+        }
+
+        xmlWriter->writeEndElement();
+    }
+
     // XEP-0319: Last User Interaction in Presence
     if (!d->lastUserInteraction.isNull() && d->lastUserInteraction.isValid()) {
         xmlWriter->writeStartElement(QStringLiteral("idle"));
@@ -562,10 +632,12 @@ void QXmppPresence::toXml(QXmlStreamWriter *xmlWriter) const
     if (!d->mixUserJid.isEmpty() || !d->mixUserNick.isEmpty()) {
         xmlWriter->writeStartElement(QStringLiteral("mix"));
         xmlWriter->writeDefaultNamespace(ns_mix_presence);
-        if (!d->mixUserJid.isEmpty())
+        if (!d->mixUserJid.isEmpty()) {
             helperToXmlAddTextElement(xmlWriter, QStringLiteral("jid"), d->mixUserJid);
-        if (!d->mixUserNick.isEmpty())
+        }
+        if (!d->mixUserNick.isEmpty()) {
             helperToXmlAddTextElement(xmlWriter, QStringLiteral("nick"), d->mixUserNick);
+        }
         xmlWriter->writeEndElement();
     }
 
