@@ -1,37 +1,22 @@
-/*
- * Copyright (C) 2008-2021 The QXmpp developers
- *
- * Author:
- *  Manjeet Dahiya
- *
- * Source:
- *  https://github.com/qxmpp-project/qxmpp
- *
- * This file is a part of QXmpp library.
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- */
+// SPDX-FileCopyrightText: 2009 Manjeet Dahiya <manjeetdahiya@gmail.com>
+// SPDX-FileCopyrightText: 2022 Melvin Keskin <melvo@olomono.de>
+//
+// SPDX-License-Identifier: LGPL-2.1-or-later
 
 #ifndef QXMPPPRESENCE_H
 #define QXMPPPRESENCE_H
 
+#include "QXmppJingleIq.h"
 #include "QXmppMucIq.h"
 #include "QXmppStanza.h"
 
 class QXmppPresencePrivate;
 
+///
 /// \brief The QXmppPresence class represents an XMPP presence stanza.
 ///
 /// \ingroup Stanzas
+///
 class QXMPP_EXPORT QXmppPresence : public QXmppStanza
 {
 public:
@@ -71,9 +56,11 @@ public:
 
     QXmppPresence(QXmppPresence::Type type = QXmppPresence::Available);
     QXmppPresence(const QXmppPresence &other);
+    QXmppPresence(QXmppPresence &&);
     ~QXmppPresence() override;
 
     QXmppPresence &operator=(const QXmppPresence &other);
+    QXmppPresence &operator=(QXmppPresence &&);
 
     bool isXmppStanza() const override;
 
@@ -121,6 +108,13 @@ public:
 
     QStringList capabilityExt() const;
 
+    // XEP-0272: Multiparty Jingle (Muji)
+    bool isPreparingMujiSession() const;
+    void setIsPreparingMujiSession(bool isPreparingMujiSession);
+
+    QVector<QXmppJingleIq::Content> mujiContents() const;
+    void setMujiContents(const QVector<QXmppJingleIq::Content> &mujiContents);
+
     // XEP-0319: Last User Interaction in Presence
     QDateTime lastUserInteraction() const;
     void setLastUserInteraction(const QDateTime &);
