@@ -1,27 +1,8 @@
-/*
- * Copyright (C) 2008-2021 The QXmpp developers
- *
- * Author:
- *  Robert Märkisch
- *  Linus Jahn
- *  Jonah Brüchert
- *
- * Source:
- *  https://github.com/qxmpp-project/qxmpp
- *
- * This file is a part of QXmpp library.
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- */
+// SPDX-FileCopyrightText: 2020 Robert Märkisch <zatrox@kaidan.im>
+// SPDX-FileCopyrightText: 2021 Linus Jahn <lnj@kaidan.im>
+// SPDX-FileCopyrightText: 2020 Jonah Brüchert <jbb@kaidan.im>
+//
+// SPDX-License-Identifier: LGPL-2.1-or-later
 
 #include "QXmppPushEnableIq.h"
 
@@ -44,9 +25,15 @@ QXmppPushEnableIq::QXmppPushEnableIq()
 {
 }
 
+/// Default copy-constructor
 QXmppPushEnableIq::QXmppPushEnableIq(const QXmppPushEnableIq &) = default;
+/// Default move-constructor
+QXmppPushEnableIq::QXmppPushEnableIq(QXmppPushEnableIq &&) = default;
 QXmppPushEnableIq::~QXmppPushEnableIq() = default;
+/// Default assignment operator
 QXmppPushEnableIq &QXmppPushEnableIq::operator=(const QXmppPushEnableIq &) = default;
+/// Default move-assignment operator
+QXmppPushEnableIq &QXmppPushEnableIq::operator=(QXmppPushEnableIq &&) = default;
 
 ///
 /// \brief Returns the jid of the app server
