@@ -1,26 +1,7 @@
-/*
- * Copyright (C) 2008-2021 The QXmpp developers
- *
- * Author:
- *  Jeremy Lainé
- *  Linus Jahn
- *
- * Source:
- *  https://github.com/qxmpp-project/qxmpp
- *
- * This file is a part of QXmpp library.
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- */
+// SPDX-FileCopyrightText: 2012 Jeremy Lainé <jeremy.laine@m4x.org>
+// SPDX-FileCopyrightText: 2019 Linus Jahn <lnj@kaidan.im>
+//
+// SPDX-License-Identifier: LGPL-2.1-or-later
 
 #include "QXmppRegisterIq.h"
 
@@ -46,6 +27,7 @@ public:
     bool isRegistered;
     bool isRemove;
     QXmppBitsOfBinaryDataList bitsOfBinaryData;
+    QString outOfBandUrl;
 };
 
 QXmppRegisterIqPrivate::QXmppRegisterIqPrivate()
@@ -59,11 +41,15 @@ QXmppRegisterIq::QXmppRegisterIq()
 {
 }
 
+/// Default copy-constructor
 QXmppRegisterIq::QXmppRegisterIq(const QXmppRegisterIq &other) = default;
-
+/// Default move-constructor
+QXmppRegisterIq::QXmppRegisterIq(QXmppRegisterIq &&) = default;
 QXmppRegisterIq::~QXmppRegisterIq() = default;
-
+/// Default assignment operator
 QXmppRegisterIq &QXmppRegisterIq::operator=(const QXmppRegisterIq &other) = default;
+/// Default move-assignment operator
+QXmppRegisterIq &QXmppRegisterIq::operator=(QXmppRegisterIq &&) = default;
 
 /// Constructs a regular change password request.
 ///
@@ -257,6 +243,26 @@ void QXmppRegisterIq::setBitsOfBinaryData(const QXmppBitsOfBinaryDataList &bitsO
     d->bitsOfBinaryData = bitsOfBinaryData;
 }
 
+///
+/// Returns a \xep{0066, Out of Band Data} URL used for out-of-band registration.
+///
+/// \since QXmpp 1.5
+///
+QString QXmppRegisterIq::outOfBandUrl() const
+{
+    return d->outOfBandUrl;
+}
+
+///
+/// Sets a \xep{0066, Out of Band Data} URL used for out-of-band registration.
+///
+/// \since QXmpp 1.5
+///
+void QXmppRegisterIq::setOutOfBandUrl(const QString &outOfBandUrl)
+{
+    d->outOfBandUrl = outOfBandUrl;
+}
+
 /// \cond
 bool QXmppRegisterIq::isRegisterIq(const QDomElement &element)
 {
@@ -270,7 +276,17 @@ void QXmppRegisterIq::parseElementFromChild(const QDomElement &element)
     d->username = queryElement.firstChildElement(QStringLiteral("username")).text();
     d->password = queryElement.firstChildElement(QStringLiteral("password")).text();
     d->email = queryElement.firstChildElement(QStringLiteral("email")).text();
-    d->form.parse(queryElement.firstChildElement(QStringLiteral("x")));
+
+    for (auto xElement = queryElement.firstChildElement(QStringLiteral("x"));
+         !xElement.isNull();
+         xElement = xElement.nextSiblingElement(QStringLiteral("x"))) {
+        if (xElement.namespaceURI() == ns_data) {
+            d->form.parse(xElement);
+        } else if (xElement.namespaceURI() == ns_oob) {
+            d->outOfBandUrl = xElement.firstChildElement(QStringLiteral("url")).text();
+        }
+    }
+
     d->isRegistered = !queryElement.firstChildElement(ELEMENT_REGISTERED).isNull();
     d->isRemove = !queryElement.firstChildElement(ELEMENT_REMOVE).isNull();
     d->bitsOfBinaryData.parse(queryElement);
@@ -281,32 +297,45 @@ void QXmppRegisterIq::toXmlElementFromChild(QXmlStreamWriter *writer) const
     writer->writeStartElement(QStringLiteral("query"));
     writer->writeDefaultNamespace(ns_register);
 
-    if (!d->instructions.isEmpty())
+    if (!d->instructions.isEmpty()) {
         writer->writeTextElement(QStringLiteral("instructions"), d->instructions);
+    }
 
-    if (d->isRegistered)
+    if (d->isRegistered) {
         writer->writeEmptyElement(ELEMENT_REGISTERED);
-    if (d->isRemove)
+    }
+    if (d->isRemove) {
         writer->writeEmptyElement(ELEMENT_REMOVE);
+    }
 
-    if (!d->username.isEmpty())
+    if (!d->username.isEmpty()) {
         writer->writeTextElement(QStringLiteral("username"), d->username);
-    else if (!d->username.isNull())
+    } else if (!d->username.isNull()) {
         writer->writeEmptyElement(QStringLiteral("username"));
+    }
 
-    if (!d->password.isEmpty())
+    if (!d->password.isEmpty()) {
         writer->writeTextElement(QStringLiteral("password"), d->password);
-    else if (!d->password.isNull())
+    } else if (!d->password.isNull()) {
         writer->writeEmptyElement(QStringLiteral("password"));
+    }
 
-    if (!d->email.isEmpty())
+    if (!d->email.isEmpty()) {
         writer->writeTextElement(QStringLiteral("email"), d->email);
-    else if (!d->email.isNull())
+    } else if (!d->email.isNull()) {
         writer->writeEmptyElement(QStringLiteral("email"));
+    }
 
     d->form.toXml(writer);
     d->bitsOfBinaryData.toXml(writer);
 
+    if (!d->outOfBandUrl.isEmpty()) {
+        writer->writeStartElement(QStringLiteral("x"));
+        writer->writeDefaultNamespace(ns_oob);
+        writer->writeTextElement(QStringLiteral("url"), d->outOfBandUrl);
+        writer->writeEndElement();
+    }
+
     writer->writeEndElement();
 }
 
