@@ -1,26 +1,7 @@
-/*
- * Copyright (C) 2008-2020 The QXmpp developers
- *
- * Author:
- *  Jeremy Lainé
- *  Linus Jahn
- *
- * Source:
- *  https://github.com/qxmpp-project/qxmpp
- *
- * This file is a part of QXmpp library.
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- */
+// SPDX-FileCopyrightText: 2012 Jeremy Lainé <jeremy.laine@m4x.org>
+// SPDX-FileCopyrightText: 2019 Linus Jahn <lnj@kaidan.im>
+//
+// SPDX-License-Identifier: LGPL-2.1-or-later
 
 #ifndef QXMPPREGISTERIQ_H
 #define QXMPPREGISTERIQ_H
@@ -43,9 +24,11 @@ class QXMPP_EXPORT QXmppRegisterIq : public QXmppIq
 public:
     QXmppRegisterIq();
     QXmppRegisterIq(const QXmppRegisterIq &other);
+    QXmppRegisterIq(QXmppRegisterIq &&);
     ~QXmppRegisterIq();
 
     QXmppRegisterIq &operator=(const QXmppRegisterIq &other);
+    QXmppRegisterIq &operator=(QXmppRegisterIq &&);
 
     static QXmppRegisterIq createChangePasswordRequest(const QString &username, const QString &newPassword, const QString &to = {});
     static QXmppRegisterIq createUnregistrationRequest(const QString &to = {});
@@ -75,6 +58,9 @@ public:
     QXmppBitsOfBinaryDataList &bitsOfBinaryData();
     void setBitsOfBinaryData(const QXmppBitsOfBinaryDataList &bitsOfBinaryData);
 
+    QString outOfBandUrl() const;
+    void setOutOfBandUrl(const QString &outOfBandUrl);
+
     /// \cond
     static bool isRegisterIq(const QDomElement &element);
     /// \endcond
