@@ -1,25 +1,6 @@
-/*
- * Copyright (C) 2008-2021 The QXmpp developers
- *
- * Author:
- *  Olivier Goffart
- *
- * Source:
- *  https://github.com/qxmpp-project/qxmpp
- *
- * This file is a part of QXmpp library.
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- */
+// SPDX-FileCopyrightText: 2012 Oliver Goffart <ogoffart@woboq.com>
+//
+// SPDX-License-Identifier: LGPL-2.1-or-later
 
 #include "QXmppResultSet.h"
 
@@ -84,7 +65,7 @@ QString QXmppResultSetQuery::before() const
 ///
 /// This is used for for paging backwards through results.
 
-void QXmppResultSetQuery::setBefore(const QString& before)
+void QXmppResultSetQuery::setBefore(const QString &before)
 {
     m_before = before;
 }
@@ -102,7 +83,7 @@ QString QXmppResultSetQuery::after() const
 ///
 /// This is used for for paging forwards through results.
 
-void QXmppResultSetQuery::setAfter(const QString& after)
+void QXmppResultSetQuery::setAfter(const QString &after)
 {
     m_after = after;
 }
@@ -115,36 +96,43 @@ bool QXmppResultSetQuery::isNull() const
 }
 
 /// \cond
-void QXmppResultSetQuery::parse(const QDomElement& element)
+void QXmppResultSetQuery::parse(const QDomElement &element)
 {
     QDomElement setElement = (element.tagName() == QStringLiteral("set")) ? element : element.firstChildElement(QStringLiteral("set"));
     if (setElement.namespaceURI() == ns_rsm) {
         bool ok = false;
         m_max = setElement.firstChildElement(QStringLiteral("max")).text().toInt(&ok);
-        if (!ok)
+        if (!ok) {
             m_max = -1;
+        }
         m_after = setElement.firstChildElement(QStringLiteral("after")).text();
         m_before = setElement.firstChildElement(QStringLiteral("before")).text();
         m_index = setElement.firstChildElement(QStringLiteral("index")).text().toInt(&ok);
-        if (!ok)
+        if (!ok) {
             m_index = -1;
+        }
     }
 }
 
-void QXmppResultSetQuery::toXml(QXmlStreamWriter* writer) const
+void QXmppResultSetQuery::toXml(QXmlStreamWriter *writer) const
 {
-    if (isNull())
+    if (isNull()) {
         return;
+    }
     writer->writeStartElement(QStringLiteral("set"));
     writer->writeDefaultNamespace(ns_rsm);
-    if (m_max >= 0)
+    if (m_max >= 0) {
         helperToXmlAddTextElement(writer, QStringLiteral("max"), QString::number(m_max));
-    if (!m_after.isNull())
+    }
+    if (!m_after.isNull()) {
         helperToXmlAddTextElement(writer, QStringLiteral("after"), m_after);
-    if (!m_before.isNull())
+    }
+    if (!m_before.isNull()) {
         helperToXmlAddTextElement(writer, QStringLiteral("before"), m_before);
-    if (m_index >= 0)
+    }
+    if (m_index >= 0) {
         helperToXmlAddTextElement(writer, QStringLiteral("index"), QString::number(m_index));
+    }
     writer->writeEndElement();
 }
 /// \endcond
@@ -163,7 +151,7 @@ QString QXmppResultSetReply::first() const
 
 /// Sets the UID of the first result in the page.
 
-void QXmppResultSetReply::setFirst(const QString& first)
+void QXmppResultSetReply::setFirst(const QString &first)
 {
     m_first = first;
 }
@@ -177,7 +165,7 @@ QString QXmppResultSetReply::last() const
 
 /// Sets the UID of the last result in the page.
 
-void QXmppResultSetReply::setLast(const QString& last)
+void QXmppResultSetReply::setLast(const QString &last)
 {
     m_last = last;
 }
@@ -230,7 +218,7 @@ bool QXmppResultSetReply::isNull() const
 }
 
 /// \cond
-void QXmppResultSetReply::parse(const QDomElement& element)
+void QXmppResultSetReply::parse(const QDomElement &element)
 {
     QDomElement setElement = (element.tagName() == "set") ? element : element.firstChildElement("set");
     if (setElement.namespaceURI() == ns_rsm) {
@@ -239,30 +227,35 @@ void QXmppResultSetReply::parse(const QDomElement& element)
         m_first = firstElem.text();
         bool ok = false;
         m_index = firstElem.attribute("index").toInt(&ok);
-        if (!ok)
+        if (!ok) {
             m_index = -1;
+        }
         m_last = setElement.firstChildElement("last").text();
     }
 }
 
-void QXmppResultSetReply::toXml(QXmlStreamWriter* writer) const
+void QXmppResultSetReply::toXml(QXmlStreamWriter *writer) const
 {
-    if (isNull())
+    if (isNull()) {
         return;
+    }
     writer->writeStartElement("set");
     writer->writeDefaultNamespace(ns_rsm);
     if (!m_first.isNull() || m_index >= 0) {
         writer->writeStartElement("first");
-        if (m_index >= 0)
+        if (m_index >= 0) {
             writer->writeAttribute("index", QString::number(m_index));
+        }
         writer->writeCharacters(m_first);
         writer->writeEndElement();
     }
-    if (!m_last.isNull())
+    if (!m_last.isNull()) {
         helperToXmlAddTextElement(writer, "last", m_last);
+    }
 
-    if (m_count >= 0)
+    if (m_count >= 0) {
         helperToXmlAddTextElement(writer, "count", QString::number(m_count));
+    }
     writer->writeEndElement();
 }
 /// \endcond
