@@ -1,26 +1,7 @@
-/*
- * Copyright (C) 2008-2021 The QXmpp developers
- *
- * Authors:
- *  Manjeet Dahiya
- *  Jeremy Lainé
- *
- * Source:
- *  https://github.com/qxmpp-project/qxmpp
- *
- * This file is a part of QXmpp library.
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- */
+// SPDX-FileCopyrightText: 2009 Manjeet Dahiya <manjeetdahiya@gmail.com>
+// SPDX-FileCopyrightText: 2010 Jeremy Lainé <jeremy.laine@m4x.org>
+//
+// SPDX-License-Identifier: LGPL-2.1-or-later
 
 #include "QXmppRosterIq.h"
 
@@ -46,11 +27,15 @@ QXmppRosterIq::QXmppRosterIq()
 {
 }
 
+/// Default copy-constructor
 QXmppRosterIq::QXmppRosterIq(const QXmppRosterIq &) = default;
-
+/// Default move-constructor
+QXmppRosterIq::QXmppRosterIq(QXmppRosterIq &&) = default;
 QXmppRosterIq::~QXmppRosterIq() = default;
-
+/// Default assignment operator
 QXmppRosterIq &QXmppRosterIq::operator=(const QXmppRosterIq &) = default;
+/// Default move-assignment operator
+QXmppRosterIq &QXmppRosterIq::operator=(QXmppRosterIq &&) = default;
 
 ///
 /// Adds an item to the roster IQ.
@@ -144,8 +129,9 @@ void QXmppRosterIq::toXmlElementFromChild(QXmlStreamWriter *writer) const
     writer->writeDefaultNamespace(ns_roster);
 
     // XEP-0237 roster versioning - If the server does not advertise support for roster versioning, the client MUST NOT include the 'ver' attribute.
-    if (!version().isEmpty())
+    if (!version().isEmpty()) {
         writer->writeAttribute(QStringLiteral("ver"), version());
+    }
 
     // XEP-0405: Mediated Information eXchange (MIX): Participant Server Requirements
     if (d->mixAnnotate) {
@@ -154,8 +140,9 @@ void QXmppRosterIq::toXmlElementFromChild(QXmlStreamWriter *writer) const
         writer->writeEndElement();
     }
 
-    for (int i = 0; i < d->items.count(); ++i)
+    for (int i = 0; i < d->items.count(); ++i) {
         d->items.at(i).toXml(writer);
+    }
     writer->writeEndElement();
 }
 /// \endcond
@@ -191,11 +178,15 @@ QXmppRosterIq::Item::Item()
 {
 }
 
+/// Default copy-constructor
 QXmppRosterIq::Item::Item(const QXmppRosterIq::Item &other) = default;
-
+/// Default move-constructor
+QXmppRosterIq::Item::Item(QXmppRosterIq::Item &&) = default;
 QXmppRosterIq::Item::~Item() = default;
-
+/// Default assignment operator
 QXmppRosterIq::Item &QXmppRosterIq::Item::operator=(const Item &other) = default;
+/// Default assignment operator
+QXmppRosterIq::Item &QXmppRosterIq::Item::operator=(Item &&) = default;
 
 ///
 /// Returns the bareJid of the roster entry.
@@ -347,20 +338,21 @@ QString QXmppRosterIq::Item::getSubscriptionTypeStr() const
 
 void QXmppRosterIq::Item::setSubscriptionTypeFromStr(const QString &type)
 {
-    if (type.isEmpty())
+    if (type.isEmpty()) {
         setSubscriptionType(NotSet);
-    else if (type == QStringLiteral("none"))
+    } else if (type == QStringLiteral("none")) {
         setSubscriptionType(None);
-    else if (type == QStringLiteral("both"))
+    } else if (type == QStringLiteral("both")) {
         setSubscriptionType(Both);
-    else if (type == QStringLiteral("from"))
+    } else if (type == QStringLiteral("from")) {
         setSubscriptionType(From);
-    else if (type == QStringLiteral("to"))
+    } else if (type == QStringLiteral("to")) {
         setSubscriptionType(To);
-    else if (type == QStringLiteral("remove"))
+    } else if (type == QStringLiteral("remove")) {
         setSubscriptionType(Remove);
-    else
+    } else {
         qWarning("QXmppRosterIq::Item::setTypeFromStr(): invalid type");
+    }
 }
 
 ///
@@ -437,8 +429,9 @@ void QXmppRosterIq::Item::toXml(QXmlStreamWriter *writer) const
     helperToXmlAddAttribute(writer, QStringLiteral("name"), d->name);
     helperToXmlAddAttribute(writer, QStringLiteral("subscription"), getSubscriptionTypeStr());
     helperToXmlAddAttribute(writer, QStringLiteral("ask"), subscriptionStatus());
-    if (d->approved)
+    if (d->approved) {
         writer->writeAttribute(QStringLiteral("approved"), QStringLiteral("true"));
+    }
 
     QSet<QString>::const_iterator i = d->groups.constBegin();
     while (i != d->groups.constEnd()) {
