@@ -1,26 +1,7 @@
-/*
- * Copyright (C) 2008-2021 The QXmpp developers
- *
- * Authors:
- *  Manjeet Dahiya
- *  Jeremy Lainé
- *
- * Source:
- *  https://github.com/qxmpp-project/qxmpp
- *
- * This file is a part of QXmpp library.
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- */
+// SPDX-FileCopyrightText: 2012 Manjeet Dahiya <manjeetdahiya@gmail.com>
+// SPDX-FileCopyrightText: 2012 Jeremy Lainé <jeremy.laine@m4x.org>
+//
+// SPDX-License-Identifier: LGPL-2.1-or-later
 
 #include "QXmppSasl_p.h"
 #include "QXmppUtils.h"
@@ -34,10 +15,6 @@
 #include <QUrlQuery>
 #include <QtEndian>
 
-#if QT_VERSION >= QT_VERSION_CHECK(5, 9, 2)
-#define QT_HAS_SHA3_SUPPORT
-#endif
-
 const char *ns_xmpp_sasl = "urn:ietf:params:xml:ns:xmpp-sasl";
 
 static QByteArray forcedNonce;
@@ -47,9 +24,7 @@ static const QMap<QString, QCryptographicHash::Algorithm> SCRAM_ALGORITHMS = {
     { QStringLiteral("SCRAM-SHA-1"), QCryptographicHash::Sha1 },
     { QStringLiteral("SCRAM-SHA-256"), QCryptographicHash::Sha256 },
     { QStringLiteral("SCRAM-SHA-512"), QCryptographicHash::Sha512 },
-#ifdef QT_HAS_SHA3_SUPPORT
     { QStringLiteral("SCRAM-SHA3-512"), QCryptographicHash::RealSha3_512 },
-#endif
 };
 
 // Returns the hash length in bytes (QCH::hashLength() only exists since 5.12).
@@ -64,9 +39,7 @@ int hashLength(QCryptographicHash::Algorithm algorithm)
     case QCryptographicHash::Sha256:
         return 256 / 8;
     case QCryptographicHash::Sha512:
-#ifdef QT_HAS_SHA3_SUPPORT
     case QCryptographicHash::RealSha3_512:
-#endif
         return 512 / 8;
     default:
         return QCryptographicHash::hash({}, algorithm).size();
@@ -119,8 +92,9 @@ static QByteArray deriveKeyPbkdf2(QCryptographicHash::Algorithm algorithm,
 
 static QByteArray generateNonce()
 {
-    if (!forcedNonce.isEmpty())
+    if (!forcedNonce.isEmpty()) {
         return forcedNonce;
+    }
 
     QByteArray nonce = QXmppUtils::generateRandomBytes(32);
 
@@ -132,7 +106,8 @@ static QByteArray generateNonce()
 static QMap<char, QByteArray> parseGS2(const QByteArray &ba)
 {
     QMap<char, QByteArray> map;
-    for (const auto &keyValue : ba.split(',')) {
+    const auto keyValuePairs = ba.split(u',');
+    for (const auto &keyValue : keyValuePairs) {
         if (keyValue.size() >= 2 && keyValue[1] == '=') {
             map[keyValue[0]] = keyValue.mid(2);
         }
@@ -176,8 +151,9 @@ void QXmppSaslAuth::toXml(QXmlStreamWriter *writer) const
     writer->writeStartElement(QStringLiteral("auth"));
     writer->writeDefaultNamespace(ns_xmpp_sasl);
     writer->writeAttribute(QStringLiteral("mechanism"), m_mechanism);
-    if (!m_value.isEmpty())
+    if (!m_value.isEmpty()) {
         writer->writeCharacters(m_value.toBase64());
+    }
     writer->writeEndElement();
 }
 
@@ -205,8 +181,9 @@ void QXmppSaslChallenge::toXml(QXmlStreamWriter *writer) const
 {
     writer->writeStartElement(QStringLiteral("challenge"));
     writer->writeDefaultNamespace(ns_xmpp_sasl);
-    if (!m_value.isEmpty())
+    if (!m_value.isEmpty()) {
         writer->writeCharacters(m_value.toBase64());
+    }
     writer->writeEndElement();
 }
 
@@ -234,8 +211,9 @@ void QXmppSaslFailure::toXml(QXmlStreamWriter *writer) const
 {
     writer->writeStartElement(QStringLiteral("failure"));
     writer->writeDefaultNamespace(ns_xmpp_sasl);
-    if (!m_condition.isEmpty())
+    if (!m_condition.isEmpty()) {
         writer->writeEmptyElement(m_condition);
+    }
     writer->writeEndElement();
 }
 
@@ -263,8 +241,9 @@ void QXmppSaslResponse::toXml(QXmlStreamWriter *writer) const
 {
     writer->writeStartElement(QStringLiteral("response"));
     writer->writeDefaultNamespace(ns_xmpp_sasl);
-    if (!m_value.isEmpty())
+    if (!m_value.isEmpty()) {
         writer->writeCharacters(m_value.toBase64());
+    }
     writer->writeEndElement();
 }
 
@@ -309,9 +288,7 @@ QXmppSaslClient::~QXmppSaslClient()
 QStringList QXmppSaslClient::availableMechanisms()
 {
     return {
-#ifdef QT_HAS_SHA3_SUPPORT
         QStringLiteral("SCRAM-SHA3-512"),
-#endif
         QStringLiteral("SCRAM-SHA-512"),
         QStringLiteral("SCRAM-SHA-256"),
         QStringLiteral("SCRAM-SHA-1"),
@@ -473,8 +450,9 @@ bool QXmppSaslClientDigestMd5::respond(const QByteArray &challenge, QByteArray &
         // Build response
         QMap<QByteArray, QByteArray> output;
         output[QByteArrayLiteral("username")] = username().toUtf8();
-        if (!realm.isEmpty())
+        if (!realm.isEmpty()) {
             output[QByteArrayLiteral("realm")] = realm;
+        }
         output[QByteArrayLiteral("nonce")] = m_nonce;
         output[QByteArrayLiteral("qop")] = QByteArrayLiteral("auth");
         output[QByteArrayLiteral("cnonce")] = m_cnonce;
@@ -813,8 +791,9 @@ QXmppSaslServer::Response QXmppSaslServerDigestMd5::respond(const QByteArray &re
     if (m_step == 0) {
         QMap<QByteArray, QByteArray> output;
         output[QByteArrayLiteral("nonce")] = m_nonce;
-        if (!realm().isEmpty())
+        if (!realm().isEmpty()) {
             output[QByteArrayLiteral("realm")] = realm().toUtf8();
+        }
         output[QByteArrayLiteral("qop")] = QByteArrayLiteral("auth");
         output[QByteArrayLiteral("charset")] = QByteArrayLiteral("utf-8");
         output[QByteArrayLiteral("algorithm")] = QByteArrayLiteral("md5-sess");
@@ -833,8 +812,9 @@ QXmppSaslServer::Response QXmppSaslServerDigestMd5::respond(const QByteArray &re
         }
 
         setUsername(QString::fromUtf8(input.value(QByteArrayLiteral("username"))));
-        if (password().isEmpty() && passwordDigest().isEmpty())
+        if (password().isEmpty() && passwordDigest().isEmpty()) {
             return InputNeeded;
+        }
 
         m_nc = input.value(QByteArrayLiteral("nc"));
         m_cnonce = input.value(QByteArrayLiteral("cnonce"));
@@ -846,8 +826,9 @@ QXmppSaslServer::Response QXmppSaslServerDigestMd5::respond(const QByteArray &re
             m_secret = passwordDigest();
         }
 
-        if (input.value(QByteArrayLiteral("response")) != calculateDigest(QByteArrayLiteral("AUTHENTICATE"), digestUri, m_secret, m_nonce, m_cnonce, m_nc))
+        if (input.value(QByteArrayLiteral("response")) != calculateDigest(QByteArrayLiteral("AUTHENTICATE"), digestUri, m_secret, m_nonce, m_cnonce, m_nc)) {
             return Failed;
+        }
 
         QMap<QByteArray, QByteArray> output;
         output[QByteArrayLiteral("rspauth")] = calculateDigest(QByteArray(), digestUri, m_secret, m_nonce, m_cnonce, m_nc);
@@ -915,14 +896,19 @@ QMap<QByteArray, QByteArray> QXmppSaslDigestMd5::parseMessage(const QByteArray &
         const QByteArray key = ba.mid(startIndex, pos - startIndex).trimmed();
         pos++;
 
-        // check whether string is quoted
-        if (ba.at(pos) == '"') {
+        if (pos == ba.size()) {
+            // end of the input
+            map.insert(key, QByteArray());
+            startIndex = pos;
+        } else if (ba.at(pos) == '"') {
+            // check whether string is quoted
             // skip opening quote
             pos++;
             int endPos = ba.indexOf('"', pos);
             // skip quoted quotes
-            while (endPos >= 0 && ba.at(endPos - 1) == '\\')
+            while (endPos >= 0 && ba.at(endPos - 1) == '\\') {
                 endPos = ba.indexOf('"', endPos + 1);
+            }
             if (endPos < 0) {
                 qWarning("Unfinished quoted string");
                 return map;
@@ -937,8 +923,9 @@ QMap<QByteArray, QByteArray> QXmppSaslDigestMd5::parseMessage(const QByteArray &
         } else {
             // non-quoted string
             int endPos = ba.indexOf(',', pos);
-            if (endPos < 0)
+            if (endPos < 0) {
                 endPos = ba.size();
+            }
             map[key] = ba.mid(pos, endPos - pos);
             // skip comma
             startIndex = endPos + 1;
@@ -950,11 +937,12 @@ QMap<QByteArray, QByteArray> QXmppSaslDigestMd5::parseMessage(const QByteArray &
 QByteArray QXmppSaslDigestMd5::serializeMessage(const QMap<QByteArray, QByteArray> &map)
 {
     QByteArray ba;
-    for (const auto &key : map.keys()) {
-        if (!ba.isEmpty())
+    for (auto itr = map.begin(); itr != map.end(); itr++) {
+        if (!ba.isEmpty()) {
             ba.append(',');
-        ba.append(key + QByteArrayLiteral("="));
-        QByteArray value = map[key];
+        }
+        ba.append(itr.key() + QByteArrayLiteral("="));
+        auto value = itr.value();
         const char *separators = "()<>@,;:\\\"/[]?={} \t";
         bool quote = false;
         for (const char *c = separators; *c; c++) {
@@ -964,8 +952,8 @@ QByteArray QXmppSaslDigestMd5::serializeMessage(const QMap<QByteArray, QByteArra
             }
         }
         if (quote) {
-            value.replace(QByteArrayLiteral("\\"), QByteArrayLiteral("\\\\"));
-            value.replace(QByteArrayLiteral("\""), QByteArrayLiteral("\\\""));
+            value.replace('\\', QByteArrayLiteral("\\\\"));
+            value.replace('\"', QByteArrayLiteral("\\\""));
             ba.append('"' + value + '"');
         } else {
             ba.append(value);
