@@ -1,26 +1,7 @@
-/*
- * Copyright (C) 2008-2021 The QXmpp developers
- *
- * Authors:
- *  Manjeet Dahiya
- *  Jeremy Lainé
- *
- * Source:
- *  https://github.com/qxmpp-project/qxmpp
- *
- * This file is a part of QXmpp library.
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- */
+// SPDX-FileCopyrightText: 2012 Manjeet Dahiya <manjeetdahiya@gmail.com>
+// SPDX-FileCopyrightText: 2012 Jeremy Lainé <jeremy.laine@m4x.org>
+//
+// SPDX-License-Identifier: LGPL-2.1-or-later
 
 #ifndef QXMPPSASL_P_H
 #define QXMPPSASL_P_H
@@ -121,7 +102,7 @@ public:
     static QByteArray serializeMessage(const QMap<QByteArray, QByteArray> &map);
 };
 
-class QXMPP_AUTOTEST_EXPORT QXmppSaslAuth : public QXmppStanza
+class QXMPP_AUTOTEST_EXPORT QXmppSaslAuth : public QXmppNonza
 {
 public:
     QXmppSaslAuth(const QString &mechanism = QString(), const QByteArray &value = QByteArray());
@@ -142,7 +123,7 @@ private:
     QByteArray m_value;
 };
 
-class QXMPP_AUTOTEST_EXPORT QXmppSaslChallenge : public QXmppStanza
+class QXMPP_AUTOTEST_EXPORT QXmppSaslChallenge : public QXmppNonza
 {
 public:
     QXmppSaslChallenge(const QByteArray &value = QByteArray());
@@ -159,7 +140,7 @@ private:
     QByteArray m_value;
 };
 
-class QXMPP_AUTOTEST_EXPORT QXmppSaslFailure : public QXmppStanza
+class QXMPP_AUTOTEST_EXPORT QXmppSaslFailure : public QXmppNonza
 {
 public:
     QXmppSaslFailure(const QString &condition = QString());
@@ -176,7 +157,7 @@ private:
     QString m_condition;
 };
 
-class QXMPP_AUTOTEST_EXPORT QXmppSaslResponse : public QXmppStanza
+class QXMPP_AUTOTEST_EXPORT QXmppSaslResponse : public QXmppNonza
 {
 public:
     QXmppSaslResponse(const QByteArray &value = QByteArray());
@@ -193,7 +174,7 @@ private:
     QByteArray m_value;
 };
 
-class QXMPP_AUTOTEST_EXPORT QXmppSaslSuccess : public QXmppStanza
+class QXMPP_AUTOTEST_EXPORT QXmppSaslSuccess : public QXmppNonza
 {
 public:
     QXmppSaslSuccess();
