@@ -1,25 +1,6 @@
-/*
- * Copyright (C) 2008-2021 The QXmpp developers
- *
- * Authors:
- *  Linus Jahn
- *
- * Source:
- *  https://github.com/qxmpp-project/qxmpp
- *
- * This file is a part of QXmpp library.
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- */
+// SPDX-FileCopyrightText: 2019 Linus Jahn <lnj@kaidan.im>
+//
+// SPDX-License-Identifier: LGPL-2.1-or-later
 
 #include "QXmppStartTlsPacket.h"
 
@@ -62,17 +43,24 @@ void QXmppStartTlsPacket::setType(QXmppStartTlsPacket::Type type)
 /// \cond
 void QXmppStartTlsPacket::parse(const QDomElement &element)
 {
-    if (!QXmppStartTlsPacket::isStartTlsPacket(element))
+    if (!QXmppStartTlsPacket::isStartTlsPacket(element)) {
         return;
+    }
 
-    m_type = Type(STARTTLS_TYPES.indexOf(element.tagName()));
+    if (auto index = STARTTLS_TYPES.indexOf(element.tagName()); index >= 0) {
+        m_type = Type(index);
+    } else {
+        m_type = Invalid;
+    }
 }
 
 void QXmppStartTlsPacket::toXml(QXmlStreamWriter *writer) const
 {
-    writer->writeStartElement(STARTTLS_TYPES.at(int(m_type)));
-    writer->writeDefaultNamespace(ns_tls);
-    writer->writeEndElement();
+    if (m_type != Invalid) {
+        writer->writeStartElement(STARTTLS_TYPES.at(int(m_type)));
+        writer->writeDefaultNamespace(ns_tls);
+        writer->writeEndElement();
+    }
 }
 /// \endcond
 
