@@ -1,25 +1,6 @@
-/*
- * Copyright (C) 2008-2021 The QXmpp developers
- *
- * Authors:
- *  Linus Jahn
- *
- * Source:
- *  https://github.com/qxmpp-project/qxmpp
- *
- * This file is a part of QXmpp library.
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- */
+// SPDX-FileCopyrightText: 2019 Linus Jahn <lnj@kaidan.im>
+//
+// SPDX-License-Identifier: LGPL-2.1-or-later
 
 #ifndef QXMPPSTARTTLSPACKET_H
 #define QXMPPSTARTTLSPACKET_H
@@ -32,14 +13,15 @@
 ///
 /// \ingroup Stanzas
 ///
-class QXMPP_EXPORT QXmppStartTlsPacket : public QXmppStanza
+class QXMPP_EXPORT QXmppStartTlsPacket : public QXmppNonza
 {
 public:
     /// The type of the STARTTLS packet.
     enum Type {
         StartTls,  ///< Used by the client to initiate STARTTLS.
         Proceed,   ///< Used by the server to accept STARTTLS.
-        Failure    ///< Used by the server to reject STARTTLS.
+        Failure,   ///< Used by the server to reject STARTTLS.
+        Invalid,   ///< Invalid type
     };
 
     QXmppStartTlsPacket(Type type = StartTls);
