@@ -1,37 +1,24 @@
-/*
- * Copyright (C) 2008-2021 The QXmpp developers
- *
- * Authors:
- *  Manjeet Dahiya
- *  Jeremy Lainé
- *
- * Source:
- *  https://github.com/qxmpp-project/qxmpp
- *
- * This file is a part of QXmpp library.
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- */
+// SPDX-FileCopyrightText: 2009 Manjeet Dahiya <manjeetdahiya@gmail.com>
+// SPDX-FileCopyrightText: 2010 Jeremy Lainé <jeremy.laine@m4x.org>
+//
+// SPDX-License-Identifier: LGPL-2.1-or-later
 
 #include "QXmppStream.h"
 
 #include "QXmppConstants_p.h"
+#include "QXmppFutureUtils_p.h"
+#include "QXmppIq.h"
 #include "QXmppLogger.h"
+#include "QXmppPacket_p.h"
 #include "QXmppStanza.h"
 #include "QXmppStreamManagement_p.h"
 #include "QXmppUtils.h"
 
 #include <QBuffer>
 #include <QDomDocument>
+#include <QFuture>
+#include <QFutureInterface>
+#include <QFutureWatcher>
 #include <QHostAddress>
 #include <QMap>
 #include <QRegularExpression>
@@ -40,10 +27,18 @@
 #include <QTime>
 #include <QXmlStreamWriter>
 
+using namespace QXmpp::Private;
+
 #if QT_VERSION < QT_VERSION_CHECK(5, 10, 0)
 static bool randomSeeded = false;
 #endif
 
+struct IqState
+{
+    QXmppPromise<QXmppStream::IqResult> interface;
+    QString jid;
+};
+
 class QXmppStreamPrivate
 {
 public:
@@ -57,6 +52,9 @@ public:
 
     // stream management
     QXmppStreamManager streamManager;
+
+    // iq response handling
+    QMap<QString, IqState> runningIqs;
 };
 
 QXmppStreamPrivate::QXmppStreamPrivate(QXmppStream *stream)
@@ -65,6 +63,17 @@ QXmppStreamPrivate::QXmppStreamPrivate(QXmppStream *stream)
 {
 }
 
+///
+/// \typedef QXmppStream::IqResult
+///
+/// Contains a QDomElement containing the IQ response or if the request couldn't
+/// be sent a QXmpp::PacketState.
+///
+/// \warning THIS API IS NOT FINALIZED YET!
+///
+/// \since QXmpp 1.5
+///
+
 ///
 /// Constructs a base XMPP stream.
 ///
@@ -88,6 +97,7 @@ QXmppStream::QXmppStream(QObject *parent)
 ///
 QXmppStream::~QXmppStream()
 {
+    cancelOngoingIqs();
     delete d;
 }
 
@@ -139,30 +149,152 @@ bool QXmppStream::isConnected() const
 bool QXmppStream::sendData(const QByteArray &data)
 {
     logSent(QString::fromUtf8(data));
-    if (!d->socket || d->socket->state() != QAbstractSocket::ConnectedState)
+    if (!d->socket || d->socket->state() != QAbstractSocket::ConnectedState) {
         return false;
+    }
     return d->socket->write(data) == data.size();
 }
 
 ///
 /// Sends an XMPP packet to the peer.
 ///
-/// \param packet
+/// \param nonza
 ///
-bool QXmppStream::sendPacket(const QXmppStanza &packet)
+bool QXmppStream::sendPacket(const QXmppNonza &nonza)
 {
-    // prepare packet
-    QByteArray data;
-    QXmlStreamWriter xmlStream(&data);
-    packet.toXml(&xmlStream);
+    bool success;
+    send(nonza, success);
+    return success;
+}
 
-    // send packet
-    bool success = sendData(data);
+///
+/// Sends an XMPP packet to the peer.
+///
+/// \since QXmpp 1.5
+///
+QXmppTask<QXmpp::SendResult> QXmppStream::send(QXmppNonza &&nonza)
+{
+    bool success;
+    return send(QXmppPacket(nonza), success);
+}
+
+///
+/// Sends an XMPP packet to the peer.
+///
+/// \since QXmpp 1.5
+///
+QXmppTask<QXmpp::SendResult> QXmppStream::send(QXmppPacket &&packet)
+{
+    bool success;
+    return send(std::move(packet), success);
+}
+
+QXmppTask<QXmpp::SendResult> QXmppStream::send(QXmppPacket &&packet, bool &writtenToSocket)
+{
+    // the writtenToSocket parameter is just for backwards compat (see
+    // QXmppStream::sendPacket())
+    writtenToSocket = sendData(packet.data());
 
     // handle stream management
-    d->streamManager.handlePacketSent(packet, data);
+    d->streamManager.handlePacketSent(packet, writtenToSocket);
 
-    return success;
+    return packet.task();
+}
+
+///
+/// Sends an IQ packet and returns the response asynchronously.
+///
+/// \warning THIS API IS NOT FINALIZED YET!
+///
+/// \since QXmpp 1.5
+///
+QXmppTask<QXmppStream::IqResult> QXmppStream::sendIq(QXmppIq &&iq, const QString &to)
+{
+    using namespace QXmpp;
+
+    if (iq.id().isEmpty()) {
+        warning(QStringLiteral("QXmppStream::sendIq() error: ID is empty. Using random ID."));
+        iq.setId(QXmppUtils::generateStanzaUuid());
+    }
+    if (d->runningIqs.contains(iq.id())) {
+        warning(QStringLiteral("QXmppStream::sendIq() error:"
+                               "The IQ's ID (\"%1\") is already in use. Using random ID.")
+                    .arg(iq.id()));
+        iq.setId(QXmppUtils::generateStanzaUuid());
+    }
+
+    return sendIq(QXmppPacket(iq), iq.id(), to);
+}
+
+///
+/// Sends an IQ packet and returns the response asynchronously.
+///
+/// \warning THIS API IS NOT FINALIZED YET!
+///
+/// \since QXmpp 1.5
+///
+QXmppTask<QXmppStream::IqResult> QXmppStream::sendIq(QXmppPacket &&packet, const QString &id, const QString &to)
+{
+    using namespace QXmpp;
+
+    if (id.isEmpty() || d->runningIqs.contains(id)) {
+        return makeReadyTask<IqResult>(QXmppError {
+            QStringLiteral("Invalid IQ id: empty or in use."),
+            SendError::Disconnected });
+    }
+
+    if (to.isEmpty()) {
+        return makeReadyTask<IqResult>(QXmppError {
+            QStringLiteral("The 'to' address must be set so the stream can match the response."),
+            SendError::Disconnected });
+    }
+
+    auto sendFuture = send(std::move(packet));
+    if (sendFuture.isFinished()) {
+        if (std::holds_alternative<QXmppError>(sendFuture.result())) {
+            // early exit
+            return makeReadyTask<IqResult>(std::get<QXmppError>(sendFuture.takeResult()));
+        }
+    } else {
+        sendFuture.then(this, [this, id](SendResult result) {
+            if (std::holds_alternative<QXmppError>(result)) {
+                if (auto itr = d->runningIqs.find(id); itr != d->runningIqs.end()) {
+                    itr.value().interface.finish(std::get<QXmppError>(result));
+                    d->runningIqs.erase(itr);
+                }
+            }
+        });
+    }
+
+    IqState state { {}, to };
+    auto task = state.interface.task();
+    d->runningIqs.insert(id, std::move(state));
+    return task;
+}
+
+///
+/// Cancels all ongoing IQ requests and reports QXmpp::SendError::Disconnected.
+///
+/// \since QXmpp 1.5
+///
+void QXmppStream::cancelOngoingIqs()
+{
+    for (auto &state : d->runningIqs) {
+        state.interface.finish(QXmppError {
+            QStringLiteral("IQ has been cancelled."),
+            QXmpp::SendError::Disconnected });
+    }
+    d->runningIqs.clear();
+}
+
+///
+/// Returns whether the IQ ID is currently in use.
+///
+/// \since QXmpp 1.5
+///
+bool QXmppStream::hasIqId(const QString &id) const
+{
+    return d->runningIqs.contains(id);
 }
 
 ///
@@ -192,8 +324,9 @@ QSslSocket *QXmppStream::socket() const
 void QXmppStream::setSocket(QSslSocket *socket)
 {
     d->socket = socket;
-    if (!d->socket)
+    if (!d->socket) {
         return;
+    }
 
     // socket events
     connect(socket, &QAbstractSocket::connected, this, &QXmppStream::_q_socketConnected);
@@ -302,8 +435,9 @@ void QXmppStream::processData(const QString &data)
     // Try to parse the wrapped XML
     //
     QDomDocument doc;
-    if (!doc.setContent(wrappedStanzas, true))
+    if (!doc.setContent(wrappedStanzas, true)) {
         return;
+    }
 
     //
     // Success: We can clear the buffer and send a 'received' log message
@@ -321,8 +455,9 @@ void QXmppStream::processData(const QString &data)
     auto stanza = doc.documentElement().firstChildElement();
     for (; !stanza.isNull(); stanza = stanza.nextSiblingElement()) {
         // handle possible stream management packets first
-        if (d->streamManager.handleStanza(stanza))
+        if (d->streamManager.handleStanza(stanza) || handleIqResponse(stanza)) {
             continue;
+        }
 
         // process all other kinds of packets
         handleStanza(stanza);
@@ -334,6 +469,42 @@ void QXmppStream::processData(const QString &data)
     }
 }
 
+bool QXmppStream::handleIqResponse(const QDomElement &stanza)
+{
+    if (stanza.tagName() != QStringLiteral("iq")) {
+        return false;
+    }
+
+    // only accept "result" and "error" types
+    const auto iqType = stanza.attribute(QStringLiteral("type"));
+    if (iqType != QStringLiteral("result") && iqType != QStringLiteral("error")) {
+        return false;
+    }
+
+    const auto id = stanza.attribute(QStringLiteral("id"));
+    if (auto itr = d->runningIqs.find(id);
+        itr != d->runningIqs.end()) {
+        const auto expectedFrom = itr.value().jid;
+        // Check that the sender of the response matches the recipient of the request.
+        // Stanzas coming from the server on behalf of the user's account must have no "from"
+        // attribute or have it set to the user's bare JID.
+        // If 'from' is empty, the IQ has been sent by the server. In this case we don't need to
+        // do the check as we trust the server anyways.
+        if (const auto from = stanza.attribute("from"); !from.isEmpty() && from != expectedFrom) {
+            warning(QStringLiteral("Ignored received IQ response to request '%1' because of wrong sender '%2' instead of expected sender '%3'")
+                        .arg(id, from, expectedFrom));
+            return false;
+        }
+
+        itr.value().interface.finish(stanza);
+
+        d->runningIqs.erase(itr);
+        return true;
+    }
+
+    return false;
+}
+
 ///
 /// Enables Stream Management acks / reqs (\xep{0198}).
 ///
