@@ -1,25 +1,6 @@
-/*
- * Copyright (C) 2008-2021 The QXmpp developers
- *
- * Author:
- *  Jeremy Lainé
- *
- * Source:
- *  https://github.com/qxmpp-project/qxmpp
- *
- * This file is a part of QXmpp library.
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- */
+// SPDX-FileCopyrightText: 2010 Jeremy Lainé <jeremy.laine@m4x.org>
+//
+// SPDX-License-Identifier: LGPL-2.1-or-later
 
 #include "QXmppConstants_p.h"
 #include "QXmppStreamInitiationIq_p.h"
@@ -27,6 +8,7 @@
 
 #include <QDomElement>
 
+/// \cond
 QXmppDataForm QXmppStreamInitiationIq::featureForm() const
 {
     return m_featureForm;
@@ -77,7 +59,6 @@ void QXmppStreamInitiationIq::setSiId(const QString &id)
     m_siId = id;
 }
 
-/// \cond
 bool QXmppStreamInitiationIq::isStreamInitiationIq(const QDomElement &element)
 {
     QDomElement siElement = element.firstChildElement(QStringLiteral("si"));
@@ -89,10 +70,11 @@ void QXmppStreamInitiationIq::parseElementFromChild(const QDomElement &element)
     QDomElement siElement = element.firstChildElement(QStringLiteral("si"));
     m_siId = siElement.attribute(QStringLiteral("id"));
     m_mimeType = siElement.attribute(QStringLiteral("mime-type"));
-    if (siElement.attribute(QStringLiteral("profile")) == ns_stream_initiation_file_transfer)
+    if (siElement.attribute(QStringLiteral("profile")) == ns_stream_initiation_file_transfer) {
         m_profile = FileTransfer;
-    else
+    } else {
         m_profile = None;
+    }
 
     QDomElement itemElement = siElement.firstChildElement();
     while (!itemElement.isNull()) {
@@ -111,10 +93,12 @@ void QXmppStreamInitiationIq::toXmlElementFromChild(QXmlStreamWriter *writer) co
     writer->writeDefaultNamespace(ns_stream_initiation);
     helperToXmlAddAttribute(writer, QStringLiteral("id"), m_siId);
     helperToXmlAddAttribute(writer, QStringLiteral("mime-type"), m_mimeType);
-    if (m_profile == FileTransfer)
+    if (m_profile == FileTransfer) {
         helperToXmlAddAttribute(writer, QStringLiteral("profile"), ns_stream_initiation_file_transfer);
-    if (!m_fileInfo.isNull())
+    }
+    if (!m_fileInfo.isNull()) {
         m_fileInfo.toXml(writer);
+    }
     if (!m_featureForm.isNull()) {
         writer->writeStartElement(QStringLiteral("feature"));
         writer->writeDefaultNamespace(ns_feature_negotiation);
