@@ -1,30 +1,12 @@
-/*
- * Copyright (C) 2008-2021 The QXmpp developers
- *
- * Authors:
- *  Manjeet Dahiya
- *  Jeremy Lainé
- *
- * Source:
- *  https://github.com/qxmpp-project/qxmpp
- *
- * This file is a part of QXmpp library.
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- */
+// SPDX-FileCopyrightText: 2009 Manjeet Dahiya <manjeetdahiya@gmail.com>
+// SPDX-FileCopyrightText: 2010 Jeremy Lainé <jeremy.laine@m4x.org>
+//
+// SPDX-License-Identifier: LGPL-2.1-or-later
 
 #include "QXmppUtils.h"
 
 #include "QXmppLogger.h"
+#include "QXmppUtils_p.h"
 
 #include <QBuffer>
 #include <QByteArray>
@@ -126,8 +108,9 @@ QDateTime QXmppUtils::datetimeFromString(const QString &str)
 ///
 QString QXmppUtils::datetimeToString(const QDateTime &dt)
 {
-    if (dt.time().msec())
+    if (dt.time().msec()) {
         return dt.toUTC().toString(Qt::ISODateWithMs);
+    }
     return dt.toUTC().toString(Qt::ISODate);
 }
 
@@ -140,19 +123,22 @@ int QXmppUtils::timezoneOffsetFromString(const QString &str)
     static const QRegularExpression timezoneRegex(QStringLiteral("(Z|([+-])([0-9]{2}):([0-9]{2}))"));
 
     const auto match = timezoneRegex.match(str);
-    if (!match.hasMatch())
+    if (!match.hasMatch()) {
         return 0;
+    }
 
     // No offset from UTC
-    if (match.captured(1) == u'Z')
+    if (match.captured(1) == QChar(u'Z')) {
         return 0;
+    }
 
     // Calculate offset
     const int offset = match.captured(3).toInt() * 3600 +
         match.captured(4).toInt() * 60;
 
-    if (match.captured(2) == u'-')
+    if (match.captured(2) == QChar(u'-')) {
         return -offset;
+    }
     return offset;
 }
 
@@ -162,8 +148,9 @@ int QXmppUtils::timezoneOffsetFromString(const QString &str)
 ///
 QString QXmppUtils::timezoneOffsetToString(int secs)
 {
-    if (!secs)
+    if (!secs) {
         return QStringLiteral("Z");
+    }
 
     const QTime tzoTime = QTime(0, 0, 0).addSecs(qAbs(secs));
     return (secs < 0 ? QStringLiteral("-") : QStringLiteral("+")) + tzoTime.toString(QStringLiteral("hh:mm"));
@@ -181,8 +168,9 @@ QString QXmppUtils::jidToDomain(const QString &jid)
 QString QXmppUtils::jidToResource(const QString &jid)
 {
     const int pos = jid.indexOf(QChar('/'));
-    if (pos < 0)
+    if (pos < 0) {
         return QString();
+    }
     return jid.mid(pos + 1);
 }
 
@@ -191,8 +179,9 @@ QString QXmppUtils::jidToResource(const QString &jid)
 QString QXmppUtils::jidToUser(const QString &jid)
 {
     const int pos = jid.indexOf(QChar('@'));
-    if (pos < 0)
+    if (pos < 0) {
         return QString();
+    }
     return jid.left(pos);
 }
 
@@ -201,8 +190,9 @@ QString QXmppUtils::jidToUser(const QString &jid)
 QString QXmppUtils::jidToBareJid(const QString &jid)
 {
     const int pos = jid.indexOf(QChar('/'));
-    if (pos < 0)
+    if (pos < 0) {
         return jid;
+    }
     return jid.left(pos);
 }
 
@@ -211,8 +201,9 @@ QString QXmppUtils::jidToBareJid(const QString &jid)
 quint32 QXmppUtils::generateCrc32(const QByteArray &in)
 {
     quint32 result = 0xffffffff;
-    for (char n : in)
+    for (char n : in) {
         result = (result >> 8) ^ (crctable[(result & 0xff) ^ (quint8)n]);
+    }
     return result ^= 0xffffffff;
 }
 
@@ -224,12 +215,14 @@ static QByteArray generateHmac(QCryptographicHash::Algorithm algorithm, const QB
     QByteArray kpad = key + QByteArray(B - key.size(), 0);
 
     QByteArray ba;
-    for (int i = 0; i < B; ++i)
+    for (int i = 0; i < B; ++i) {
         ba += kpad[i] ^ 0x5c;
+    }
 
     QByteArray tmp;
-    for (int i = 0; i < B; ++i)
+    for (int i = 0; i < B; ++i) {
         tmp += kpad[i] ^ 0x36;
+    }
     hasher.addData(tmp);
     hasher.addData(text);
     ba += hasher.result();
@@ -278,8 +271,9 @@ int QXmppUtils::generateRandomInteger(int N)
 QByteArray QXmppUtils::generateRandomBytes(int length)
 {
     QByteArray bytes(length, 'm');
-    for (int i = 0; i < length; ++i)
+    for (int i = 0; i < length; ++i) {
         bytes[i] = (char)generateRandomInteger(256);
+    }
     return bytes;
 }
 
@@ -314,29 +308,110 @@ QString QXmppUtils::generateStanzaUuid()
 ///
 QString QXmppUtils::generateStanzaHash(int length)
 {
-    if (length == 36)
+    if (length == 36) {
         return QXmppUtils::generateStanzaUuid();
+    }
 
     const QString somechars = QStringLiteral("1234567890abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ");
     const int N = somechars.size();
     QString hashResult;
-    for (int idx = 0; idx < length; ++idx)
+    for (int idx = 0; idx < length; ++idx) {
         hashResult += somechars[generateRandomInteger(N)];
+    }
     return hashResult;
 }
 
 void helperToXmlAddAttribute(QXmlStreamWriter *stream, const QString &name,
                              const QString &value)
 {
-    if (!value.isEmpty())
+    if (!value.isEmpty()) {
         stream->writeAttribute(name, value);
+    }
 }
 
 void helperToXmlAddTextElement(QXmlStreamWriter *stream, const QString &name,
                                const QString &value)
 {
-    if (!value.isEmpty())
+    if (!value.isEmpty()) {
         stream->writeTextElement(name, value);
-    else
+    } else {
         stream->writeEmptyElement(name);
+    }
 }
+
+/// \cond
+
+//
+// Generates a random count of random bytes.
+//
+// \param minimumByteCount minimum count of bytes to generate
+// \param maximumByteCount maximum count of bytes to generate
+//
+// \return the generated bytes
+//
+QByteArray QXmpp::Private::generateRandomBytes(uint32_t minimumByteCount, uint32_t maximumByteCount)
+{
+#if QT_VERSION >= QT_VERSION_CHECK(5, 10, 0)
+    const auto byteCount = QRandomGenerator::system()->bounded(minimumByteCount, maximumByteCount);
+#else
+    const auto byteCount = (qrand() % (maximumByteCount - minimumByteCount)) + minimumByteCount;
+#endif
+    QByteArray bytes;
+    bytes.resize(byteCount);
+    generateRandomBytes(reinterpret_cast<uint8_t *>(bytes.data()), byteCount);
+
+    return bytes;
+}
+
+//
+// Generates random bytes.
+//
+// \param bytes generated bytes
+// \param byteCount count of bytes to generate
+//
+void QXmpp::Private::generateRandomBytes(uint8_t *bytes, uint32_t byteCount)
+{
+    // QRandomGenerator does not provide a random generation of single bytes. Thus, this approach
+    // fills an array with unsigned integers until no additional integer fits into the array. If
+    // byteCount is no multiple of intSize, the remaining bytes need to be filled separately.
+    constexpr uint32_t intSize = sizeof(uint32_t);
+    auto intCount = byteCount / intSize;
+
+#if QT_VERSION >= QT_VERSION_CHECK(5, 10, 0)
+    auto *randomGenerator = QRandomGenerator::system();
+
+    // Fill the space with intCount unsigned integers.
+    if (intCount) {
+        randomGenerator->fillRange(reinterpret_cast<uint32_t *>(bytes), intCount);
+    }
+
+    // Fill the remaining space with single bytes.
+    for (size_t i = byteCount - byteCount % intSize; i < byteCount; i++) {
+        bytes[i] = randomGenerator->bounded(std::numeric_limits<uint8_t>::max() + 1);
+    }
+#else
+    // Fill the range with intCount unsigned integers.
+    for (size_t i = 0; i < intCount; i++) {
+        reinterpret_cast<int *>(bytes)[i] = qrand();
+    }
+
+    // Fill the remaining space with single bytes.
+    for (size_t i = byteCount - byteCount % intSize; i < byteCount; i++) {
+        auto rand = qrand();
+        bytes[i] = *reinterpret_cast<uint *>(&rand) % (std::numeric_limits<uint8_t>::max() + 1);
+    }
+#endif
+}
+
+float QXmpp::Private::calculateProgress(qint64 transferred, qint64 total)
+{
+    if (total > 0) {
+        if (transferred > total) {
+            return 1;
+        }
+        return float(transferred) / total;
+    }
+
+    return 0;
+}
+/// \endcond
