@@ -1,25 +1,6 @@
-/*
- * Copyright (C) 2008-2021 The QXmpp developers
- *
- * Author:
- *  Jeremy Lainé
- *
- * Source:
- *  https://github.com/qxmpp-project/qxmpp
- *
- * This file is a part of QXmpp library.
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- */
+// SPDX-FileCopyrightText: 2010 Jeremy Lainé <jeremy.laine@m4x.org>
+//
+// SPDX-License-Identifier: LGPL-2.1-or-later
 
 #include "QXmppVersionIq.h"
 
@@ -86,6 +67,11 @@ bool QXmppVersionIq::isVersionIq(const QDomElement &element)
     return queryElement.namespaceURI() == ns_version;
 }
 
+bool QXmppVersionIq::checkIqType(const QString &tagName, const QString &xmlNamespace)
+{
+    return tagName == "query" && xmlNamespace == ns_version;
+}
+
 void QXmppVersionIq::parseElementFromChild(const QDomElement &element)
 {
     QDomElement queryElement = element.firstChildElement(QStringLiteral("query"));
@@ -99,14 +85,17 @@ void QXmppVersionIq::toXmlElementFromChild(QXmlStreamWriter *writer) const
     writer->writeStartElement(QStringLiteral("query"));
     writer->writeDefaultNamespace(ns_version);
 
-    if (!m_name.isEmpty())
+    if (!m_name.isEmpty()) {
         helperToXmlAddTextElement(writer, QStringLiteral("name"), m_name);
+    }
 
-    if (!m_os.isEmpty())
+    if (!m_os.isEmpty()) {
         helperToXmlAddTextElement(writer, QStringLiteral("os"), m_os);
+    }
 
-    if (!m_version.isEmpty())
+    if (!m_version.isEmpty()) {
         helperToXmlAddTextElement(writer, QStringLiteral("version"), m_version);
+    }
 
     writer->writeEndElement();
 }
