@@ -1,25 +1,6 @@
-/*
- * Copyright (C) 2008-2021 The QXmpp developers
- *
- * Author:
- *  Jeremy Lainé
- *
- * Source:
- *  https://github.com/qxmpp-project/qxmpp
- *
- * This file is a part of QXmpp library.
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- */
+// SPDX-FileCopyrightText: 2012 Jeremy Lainé <jeremy.laine@m4x.org>
+//
+// SPDX-License-Identifier: LGPL-2.1-or-later
 
 #include "QXmppBookmarkManager.h"
 
@@ -92,6 +73,7 @@ public:
     bool bookmarksReceived;
 };
 
+///
 /// Constructs a new bookmark manager.
 ///
 QXmppBookmarkManager::QXmppBookmarkManager()
@@ -100,12 +82,7 @@ QXmppBookmarkManager::QXmppBookmarkManager()
     d->bookmarksReceived = false;
 }
 
-/// Destroys a bookmark manager.
-///
-QXmppBookmarkManager::~QXmppBookmarkManager()
-{
-    delete d;
-}
+QXmppBookmarkManager::~QXmppBookmarkManager() = default;
 
 /// Returns true if the bookmarks have been received from the server,
 /// false otherwise.
@@ -135,8 +112,9 @@ bool QXmppBookmarkManager::setBookmarks(const QXmppBookmarkSet &bookmarks)
     QXmppPrivateStorageIq iq;
     iq.setType(QXmppIq::Set);
     iq.setBookmarks(bookmarks);
-    if (!client()->sendPacket(iq))
+    if (!client()->sendPacket(iq)) {
         return false;
+    }
 
     d->pendingBookmarks = bookmarks;
     d->pendingId = iq.id();
@@ -166,7 +144,7 @@ bool QXmppBookmarkManager::handleStanza(const QDomElement &stanza)
             if (iq.type() == QXmppIq::Result) {
                 d->bookmarks = iq.bookmarks();
                 d->bookmarksReceived = true;
-                emit bookmarksReceived(d->bookmarks);
+                Q_EMIT bookmarksReceived(d->bookmarks);
             }
             return true;
         } else if (!d->pendingId.isEmpty() && stanza.attribute("id") == d->pendingId) {
@@ -174,7 +152,7 @@ bool QXmppBookmarkManager::handleStanza(const QDomElement &stanza)
             iq.parse(stanza);
             if (iq.type() == QXmppIq::Result) {
                 d->bookmarks = d->pendingBookmarks;
-                emit bookmarksReceived(d->bookmarks);
+                Q_EMIT bookmarksReceived(d->bookmarks);
             }
             d->pendingId = QString();
             return true;
