@@ -1,25 +1,6 @@
-/*
- * Copyright (C) 2008-2021 The QXmpp developers
- *
- * Author:
- *  Jeremy Lainé
- *
- * Source:
- *  https://github.com/qxmpp-project/qxmpp
- *
- * This file is a part of QXmpp library.
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- */
+// SPDX-FileCopyrightText: 2019 Jeremy Lainé <jeremy.laine@m4x.org>
+//
+// SPDX-License-Identifier: LGPL-2.1-or-later
 
 #ifndef QXMPPCALL_H
 #define QXMPPCALL_H
@@ -36,15 +17,14 @@ class QXmppCallPrivate;
 class QXmppCallManager;
 class QXmppCallManagerPrivate;
 
-/// \brief The QXmppCall class represents a Voice-Over-IP call to a remote party.
-///
-/// \note THIS API IS NOT FINALIZED YET
-
 class QXMPP_EXPORT QXmppCall : public QXmppLoggable
 {
     Q_OBJECT
+    /// The call's direction
     Q_PROPERTY(Direction direction READ direction CONSTANT)
+    /// The remote party's JID
     Q_PROPERTY(QString jid READ jid CONSTANT)
+    /// The call's state
     Q_PROPERTY(State state READ state NOTIFY stateChanged)
 
 public:
@@ -75,39 +55,36 @@ public:
     QXmppCallStream *audioStream() const;
     QXmppCallStream *videoStream() const;
 
-signals:
     /// \brief This signal is emitted when a call is connected.
     ///
     /// Once this signal is emitted, you can connect a QAudioOutput and
     /// QAudioInput to the call. You can determine the appropriate clockrate
     /// and the number of channels by calling payloadType().
-    void connected();
+    Q_SIGNAL void connected();
 
     /// \brief This signal is emitted when a call is finished.
     ///
     /// Note: Do not delete the call in the slot connected to this signal,
     /// instead use deleteLater().
-    void finished();
+    Q_SIGNAL void finished();
 
     /// \brief This signal is emitted when the remote party is ringing.
-    void ringing();
+    Q_SIGNAL void ringing();
 
     /// \brief This signal is emitted when the call state changes.
-    void stateChanged(QXmppCall::State state);
+    Q_SIGNAL void stateChanged(QXmppCall::State state);
 
     /// \brief This signal is emitted when a stream is created.
-    void streamCreated(QXmppCallStream *stream);
+    Q_SIGNAL void streamCreated(QXmppCallStream *stream);
 
-public slots:
-    void accept();
-    void hangup();
-    void addVideo();
-
-private slots:
-    void localCandidatesChanged();
-    void terminated();
+    Q_SLOT void accept();
+    Q_SLOT void hangup();
+    Q_SLOT void addVideo();
 
 private:
+    Q_SLOT void localCandidatesChanged();
+    Q_SLOT void terminated();
+
     QXmppCall(const QString &jid, QXmppCall::Direction direction, QXmppCallManager *parent);
 
     QXmppCallPrivate *d;
