@@ -1,25 +1,6 @@
-/*
- * Copyright (C) 2008-2021 The QXmpp developers
- *
- * Author:
- *  Jeremy Lainé
- *
- * Source:
- *  https://github.com/qxmpp-project/qxmpp
- *
- * This file is a part of QXmpp library.
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- */
+// SPDX-FileCopyrightText: 2010 Jeremy Lainé <jeremy.laine@m4x.org>
+//
+// SPDX-License-Identifier: LGPL-2.1-or-later
 
 #include "QXmppCallManager.h"
 
@@ -37,6 +18,7 @@
 #include <QDomElement>
 #include <QTimer>
 
+/// \cond
 QXmppCallManagerPrivate::QXmppCallManagerPrivate(QXmppCallManager *qq)
     : turnPort(0),
       q(qq)
@@ -47,31 +29,37 @@ QXmppCallManagerPrivate::QXmppCallManagerPrivate(QXmppCallManager *qq)
 
 QXmppCall *QXmppCallManagerPrivate::findCall(const QString &sid) const
 {
-    for (auto *call : calls)
-        if (call->sid() == sid)
+    for (auto *call : calls) {
+        if (call->sid() == sid) {
             return call;
+        }
+    }
     return nullptr;
 }
 
 QXmppCall *QXmppCallManagerPrivate::findCall(const QString &sid, QXmppCall::Direction direction) const
 {
-    for (auto *call : calls)
-        if (call->sid() == sid && call->direction() == direction)
+    for (auto *call : calls) {
+        if (call->sid() == sid && call->direction() == direction) {
             return call;
+        }
+    }
     return nullptr;
 }
+/// \endcond
 
+///
 /// Constructs a QXmppCallManager object to handle incoming and outgoing
 /// Voice-Over-IP calls.
 ///
-
 QXmppCallManager::QXmppCallManager()
 {
     d = new QXmppCallManagerPrivate(this);
 }
 
+///
 /// Destroys the QXmppCallManager object.
-
+///
 QXmppCallManager::~QXmppCallManager()
 {
     delete d;
@@ -80,12 +68,13 @@ QXmppCallManager::~QXmppCallManager()
 /// \cond
 QStringList QXmppCallManager::discoveryFeatures() const
 {
-    return QStringList()
-        << ns_jingle      // XEP-0166 : Jingle
-        << ns_jingle_rtp  // XEP-0167 : Jingle RTP Sessions
-        << ns_jingle_rtp_audio
-        << ns_jingle_rtp_video
-        << ns_jingle_ice_udp;  // XEP-0176 : Jingle ICE-UDP Transport Method
+    return {
+        ns_jingle,      // XEP-0166 : Jingle
+        ns_jingle_rtp,  // XEP-0167 : Jingle RTP Sessions
+        ns_jingle_rtp_audio,
+        ns_jingle_rtp_video,
+        ns_jingle_ice_udp,  // XEP-0176 : Jingle ICE-UDP Transport Method
+    };
 }
 
 bool QXmppCallManager::handleStanza(const QDomElement &element)
@@ -105,7 +94,6 @@ bool QXmppCallManager::handleStanza(const QDomElement &element)
 
 void QXmppCallManager::setClient(QXmppClient *client)
 {
-
     QXmppClientExtension::setClient(client);
 
     connect(client, &QXmppClient::disconnected,
@@ -119,13 +107,13 @@ void QXmppCallManager::setClient(QXmppClient *client)
 }
 /// \endcond
 
+///
 /// Initiates a new outgoing call to the specified recipient.
 ///
 /// \param jid
-
+///
 QXmppCall *QXmppCallManager::call(const QString &jid)
 {
-
     if (jid.isEmpty()) {
         warning("Refusing to call an empty jid");
         return nullptr;
@@ -145,13 +133,14 @@ QXmppCall *QXmppCallManager::call(const QString &jid)
     d->calls << call;
     connect(call, &QObject::destroyed,
             this, &QXmppCallManager::_q_callDestroyed);
-    emit callStarted(call);
+    Q_EMIT callStarted(call);
 
     call->d->sendInvite();
 
     return call;
 }
 
+///
 /// Sets multiple STUN servers to use to determine server-reflexive addresses
 /// and ports.
 ///
@@ -160,12 +149,13 @@ QXmppCall *QXmppCallManager::call(const QString &jid)
 /// \param servers List of the STUN servers.
 ///
 /// \since QXmpp 1.3
-
+///
 void QXmppCallManager::setStunServers(const QList<QPair<QHostAddress, quint16>> &servers)
 {
     d->stunServers = servers;
 }
 
+///
 /// Sets a single STUN server to use to determine server-reflexive addresses
 /// and ports.
 ///
@@ -173,88 +163,100 @@ void QXmppCallManager::setStunServers(const QList<QPair<QHostAddress, quint16>>
 ///
 /// \param host The address of the STUN server.
 /// \param port The port of the STUN server.
-
+///
 void QXmppCallManager::setStunServer(const QHostAddress &host, quint16 port)
 {
     d->stunServers.clear();
-    d->stunServers.push_back(QPair<QHostAddress, quint16>(host, port));
+    d->stunServers.push_back(qMakePair(host, port));
 }
 
+///
 /// Sets the TURN server to use to relay packets in double-NAT configurations.
 ///
 /// \param host The address of the TURN server.
 /// \param port The port of the TURN server.
-
+///
 void QXmppCallManager::setTurnServer(const QHostAddress &host, quint16 port)
 {
     d->turnHost = host;
     d->turnPort = port;
 }
 
+///
 /// Sets the \a user used for authentication with the TURN server.
 ///
 /// \param user
-
+///
 void QXmppCallManager::setTurnUser(const QString &user)
 {
     d->turnUser = user;
 }
 
+///
 /// Sets the \a password used for authentication with the TURN server.
 ///
 /// \param password
-
+///
 void QXmppCallManager::setTurnPassword(const QString &password)
 {
     d->turnPassword = password;
 }
 
+///
 /// Handles call destruction.
-
+///
 void QXmppCallManager::_q_callDestroyed(QObject *object)
 {
     d->calls.removeAll(static_cast<QXmppCall *>(object));
 }
 
+///
 /// Handles disconnection from server.
-
+///
 void QXmppCallManager::_q_disconnected()
 {
-    for (auto *call : d->calls)
+    for (auto *call : std::as_const(d->calls)) {
         call->d->terminate(QXmppJingleIq::Reason::Gone);
+    }
 }
 
+///
 /// Handles acknowledgements.
 ///
-
 void QXmppCallManager::_q_iqReceived(const QXmppIq &ack)
 {
-    if (ack.type() != QXmppIq::Result)
+    if (ack.type() != QXmppIq::Result) {
         return;
+    }
 
     // find request
-    for (auto *call : d->calls)
+    for (auto *call : std::as_const(d->calls)) {
         call->d->handleAck(ack);
+    }
 }
 
+///
 /// Handles a Jingle IQ.
 ///
-
 void QXmppCallManager::_q_jingleIqReceived(const QXmppJingleIq &iq)
 {
 
-    if (iq.type() != QXmppIq::Set)
+    if (iq.type() != QXmppIq::Set) {
         return;
+    }
 
     if (iq.action() == QXmppJingleIq::SessionInitiate) {
         // build call
         QXmppCall *call = new QXmppCall(iq.from(), QXmppCall::IncomingDirection, this);
         call->d->sid = iq.sid();
 
-        const QXmppJingleIq::Content content = iq.contents().isEmpty() ? QXmppJingleIq::Content() : iq.contents().first();
-        QXmppCallStream *stream = call->d->createStream(content.descriptionMedia(), content.creator(), content.name());
-        if (!stream)
+        const auto content = iq.contents().isEmpty() ? QXmppJingleIq::Content()
+                                                     : iq.contents().constFirst();
+        auto *stream = call->d->createStream(content.descriptionMedia(), content.creator(), content.name());
+        if (!stream) {
+            // FIXME: delete call here?
             return;
+        }
         call->d->streams << stream;
 
         // send ack
@@ -280,13 +282,12 @@ void QXmppCallManager::_q_jingleIqReceived(const QXmppJingleIq &iq)
         QXmppJingleIq ringing;
         ringing.setTo(call->jid());
         ringing.setType(QXmppIq::Set);
-        ringing.setAction(QXmppJingleIq::SessionInfo);
         ringing.setSid(call->sid());
-        ringing.setRinging(true);
+        ringing.setRtpSessionState(QXmppJingleIq::RtpSessionStateRinging());
         call->d->sendRequest(ringing);
 
         // notify user
-        emit callReceived(call);
+        Q_EMIT callReceived(call);
         return;
 
     } else {
@@ -301,14 +302,16 @@ void QXmppCallManager::_q_jingleIqReceived(const QXmppJingleIq &iq)
     }
 }
 
+///
 /// Handles a presence.
-
+///
 void QXmppCallManager::_q_presenceReceived(const QXmppPresence &presence)
 {
-    if (presence.type() != QXmppPresence::Unavailable)
+    if (presence.type() != QXmppPresence::Unavailable) {
         return;
+    }
 
-    for (auto *call : d->calls) {
+    for (auto *call : std::as_const(d->calls)) {
         if (presence.from() == call->jid()) {
             // the remote party has gone away, terminate call
             call->d->terminate(QXmppJingleIq::Reason::Gone);
