@@ -1,25 +1,6 @@
-/*
- * Copyright (C) 2020 The QXmpp developers
- *
- * Author:
- *  Niels Ole Salscheider
- *
- * Source:
- *  https://github.com/qxmpp-project/qxmpp
- *
- * This file is a part of QXmpp library.
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- */
+// SPDX-FileCopyrightText: 2019 Niels Ole Salscheider <niels_ole@salscheider-online.de>
+//
+// SPDX-License-Identifier: LGPL-2.1-or-later
 
 #include "QXmppCallStream.h"
 
@@ -32,9 +13,9 @@
 #endif
 
 #include <cstring>
-
 #include <gst/gst.h>
 
+/// \cond
 QXmppCallStreamPrivate::QXmppCallStreamPrivate(QXmppCallStream *parent, GstElement *pipeline_,
                                                GstElement *rtpbin_, QString media_, QString creator_,
                                                QString name_, int id_)
@@ -48,9 +29,9 @@ QXmppCallStreamPrivate::QXmppCallStreamPrivate(QXmppCallStream *parent, GstEleme
       decoderBin(nullptr),
       sendPadCB(nullptr),
       receivePadCB(nullptr),
-      media(media_),
-      creator(creator_),
-      name(name_),
+      media(std::move(media_)),
+      creator(std::move(creator_)),
+      name(std::move(name_)),
       id(id_)
 {
 #if QT_VERSION >= QT_VERSION_CHECK(5, 10, 0)
@@ -222,7 +203,7 @@ void QXmppCallStreamPrivate::addEncoder(QXmppCallPrivate::GstCodec &codec)
         qFatal("Failed to create encoder");
         return;
     }
-    for (auto &encProp : codec.encProps) {
+    for (auto &encProp : std::as_const(codec.encProps)) {
         g_object_set(encoder, encProp.name.toLatin1().data(), encProp.value, nullptr);
     }
 
@@ -245,7 +226,11 @@ void QXmppCallStreamPrivate::addEncoder(QXmppCallPrivate::GstCodec &codec)
 
     gst_element_sync_state_with_parent(encoderBin);
 
+#if GST_CHECK_VERSION(1, 20, 0)
+    addRtcpSender(gst_element_request_pad_simple(rtpbin, QStringLiteral("send_rtcp_src_%1").arg(id).toLatin1().data()));
+#else
     addRtcpSender(gst_element_get_request_pad(rtpbin, QStringLiteral("send_rtcp_src_%1").arg(id).toLatin1().data()));
+#endif
 }
 
 void QXmppCallStreamPrivate::addDecoder(GstPad *pad, QXmppCallPrivate::GstCodec &codec)
@@ -326,44 +311,79 @@ void QXmppCallStreamPrivate::addRtcpSender(GstPad *pad)
         qFatal("Failed to link rtcp pads");
     }
 }
+/// \endcond
+
+///
+/// \class QXmppCallStream
+///
+/// The QXmppCallStream class represents an RTP stream in a VoIP call.
+///
+/// \note THIS API IS NOT FINALIZED YET
+///
+/// \since QXmpp 1.3
+///
 
 QXmppCallStream::QXmppCallStream(GstElement *pipeline, GstElement *rtpbin,
                                  QString media, QString creator, QString name, int id)
+    : d(new QXmppCallStreamPrivate(this, pipeline, rtpbin, std::move(media), std::move(creator), std::move(name), id))
 {
-    d = new QXmppCallStreamPrivate(this, pipeline, rtpbin, media, creator, name, id);
 }
 
+///
+/// Returns the JID of the creator of the call stream.
+///
 QString QXmppCallStream::creator() const
 {
     return d->creator;
 }
 
+///
+/// Returns the media type of the stream, "audio" or "video".
+///
 QString QXmppCallStream::media() const
 {
     return d->media;
 }
 
+///
+/// Returns the name of the stream (e.g. "webcam" or "voice").
+///
+/// There is no defined format and there are no predefined values for this.
+///
 QString QXmppCallStream::name() const
 {
     return d->name;
 }
 
+///
+/// Returns the local ID of the stream.
+///
 int QXmppCallStream::id() const
 {
     return d->id;
 }
 
+///
+/// Sets a gstreamer receive pad callback.
+///
+/// Can be used to process or display the received data.
+///
 void QXmppCallStream::setReceivePadCallback(std::function<void(GstPad *)> cb)
 {
-    d->receivePadCB = cb;
+    d->receivePadCB = std::move(cb);
     if (d->receivePad) {
         d->receivePadCB(d->receivePad);
     }
 }
 
+///
+/// Sets a gstreamer send pad callback.
+///
+/// Can be used to send the stream input.
+///
 void QXmppCallStream::setSendPadCallback(std::function<void(GstPad *)> cb)
 {
-    d->sendPadCB = cb;
+    d->sendPadCB = std::move(cb);
     if (d->sendPad) {
         d->sendPadCB(d->sendPad);
     }
