@@ -1,25 +1,6 @@
-/*
- * Copyright (C) 2008-2021 The QXmpp developers
- *
- * Author:
- *  Manjeet Dahiya
- *
- * Source:
- *  https://github.com/qxmpp-project/qxmpp
- *
- * This file is a part of QXmpp library.
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- */
+// SPDX-FileCopyrightText: 2009 Manjeet Dahiya <manjeetdahiya@gmail.com>
+//
+// SPDX-License-Identifier: LGPL-2.1-or-later
 
 #ifndef QXMPPCLIENT_H
 #define QXMPPCLIENT_H
@@ -27,11 +8,20 @@
 #include "QXmppConfiguration.h"
 #include "QXmppLogger.h"
 #include "QXmppPresence.h"
+#include "QXmppSendResult.h"
+#include "QXmppSendStanzaParams.h"
+
+#include <memory>
+#include <variant>
 
 #include <QAbstractSocket>
 #include <QObject>
 #include <QSslError>
 
+template<typename T>
+class QXmppTask;
+
+class QXmppE2eeExtension;
 class QXmppClientExtension;
 class QXmppClientPrivate;
 class QXmppPresence;
@@ -100,6 +90,9 @@ class QXMPP_EXPORT QXmppClient : public QXmppLoggable
     Q_PROPERTY(State state READ state NOTIFY stateChanged)
 
 public:
+    using IqResult = std::variant<QDomElement, QXmppError>;
+    using EmptyResult = std::variant<QXmpp::Success, QXmppError>;
+
     /// An enumeration for type of error.
     /// Error could come due a TCP socket or XML stream or due to various stanzas.
     enum Error {
@@ -132,8 +125,18 @@ public:
     ~QXmppClient() override;
 
     bool addExtension(QXmppClientExtension *extension);
+    template<typename T, typename... Args>
+    T *addNewExtension(Args... args)
+    {
+        // it's impossible that addExtension() returns false: ext is a new object
+        auto *ext = new T(args...);
+        addExtension(ext);
+        return ext;
+    }
     bool insertExtension(int index, QXmppClientExtension *extension);
     bool removeExtension(QXmppClientExtension *extension);
+    QXmppE2eeExtension *encryptionExtension() const;
+    void setEncryptionExtension(QXmppE2eeExtension *);
 
     QList<QXmppClientExtension *> extensions();
 
@@ -156,8 +159,9 @@ public:
         const QList<QXmppClientExtension *> list = extensions();
         for (auto ext : list) {
             T *extension = qobject_cast<T *>(ext);
-            if (extension)
+            if (extension) {
                 return extension;
+            }
         }
         return nullptr;
     }
@@ -182,8 +186,9 @@ public:
     {
         auto list = extensions();
         for (int i = 0; i < list.size(); ++i) {
-            if (qobject_cast<T *>(list.at(i)) != nullptr)
+            if (qobject_cast<T *>(list.at(i)) != nullptr) {
                 return i;
+            }
         }
         return -1;
     }
@@ -214,6 +219,13 @@ public:
     State state() const;
     QXmppStanza::Error::Condition xmppStreamError();
 
+    QXmppTask<QXmpp::SendResult> sendSensitive(QXmppStanza &&, const std::optional<QXmppSendStanzaParams> & = {});
+    QXmppTask<QXmpp::SendResult> send(QXmppStanza &&, const std::optional<QXmppSendStanzaParams> & = {});
+    QXmppTask<QXmpp::SendResult> reply(QXmppStanza &&stanza, const std::optional<QXmppE2eeMetadata> &e2eeMetadata, const std::optional<QXmppSendStanzaParams> & = {});
+    QXmppTask<IqResult> sendIq(QXmppIq &&, const std::optional<QXmppSendStanzaParams> & = {});
+    QXmppTask<IqResult> sendSensitiveIq(QXmppIq &&, const std::optional<QXmppSendStanzaParams> & = {});
+    QXmppTask<EmptyResult> sendGenericIq(QXmppIq &&, const std::optional<QXmppSendStanzaParams> & = {});
+
 #if QXMPP_DEPRECATED_SINCE(1, 1)
     QT_DEPRECATED_X("Use QXmppClient::findExtension<QXmppRosterManager>() instead")
     QXmppRosterManager &rosterManager();
@@ -296,9 +308,13 @@ public Q_SLOTS:
     void connectToServer(const QString &jid,
                          const QString &password);
     void disconnectFromServer();
-    bool sendPacket(const QXmppStanza &);
+    bool sendPacket(const QXmppNonza &);
     void sendMessage(const QString &bareJid, const QString &message);
 
+private:
+    void injectIq(const QDomElement &element, const std::optional<QXmppE2eeMetadata> &e2eeMetadata);
+    bool injectMessage(QXmppMessage &&message);
+
 private Q_SLOTS:
     void _q_elementReceived(const QDomElement &element, bool &handled);
     void _q_reconnect();
@@ -308,9 +324,11 @@ private Q_SLOTS:
     void _q_streamError(QXmppClient::Error error);
 
 private:
-    QXmppClientPrivate *const d;
+    const std::unique_ptr<QXmppClientPrivate> d;
 
+    friend class QXmppClientExtension;
     friend class QXmppInternalClientExtension;
+    friend class TestClient;
 };
 
 #endif  // QXMPPCLIENT_H
