@@ -1,26 +1,7 @@
-/*
- * Copyright (C) 2008-2021 The QXmpp developers
- *
- * Author:
- *  Manjeet Dahiya
- *  Linus Jahn
- *
- * Source:
- *  https://github.com/qxmpp-project/qxmpp
- *
- * This file is a part of QXmpp library.
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- */
+// SPDX-FileCopyrightText: 2020 Manjeet Dahiya <manjeetdahiya@gmail.com>
+// SPDX-FileCopyrightText: 2020 Linus Jahn <lnj@kaidan.im>
+//
+// SPDX-License-Identifier: LGPL-2.1-or-later
 
 //
 //  W A R N I N G
@@ -41,6 +22,7 @@
 
 class QXmppClient;
 class QXmppClientExtension;
+class QXmppE2eeExtension;
 class QXmppLogger;
 class QXmppOutgoingClient;
 class QTimer;
@@ -57,6 +39,8 @@ public:
     /// Pointer to the XMPP stream
     QXmppOutgoingClient *stream;
 
+    QXmppE2eeExtension *encryptionExtension;
+
     // reconnection
     bool receivedConflict;
     int reconnectionTries;
