@@ -1,25 +1,6 @@
-/*
- * Copyright (C) 2008-2021 The QXmpp developers
- *
- * Author:
- *  Manjeet Dahiya
- *
- * Source:
- *  https://github.com/qxmpp-project/qxmpp
- *
- * This file is a part of QXmpp library.
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- */
+// SPDX-FileCopyrightText: 2009 Manjeet Dahiya <manjeetdahiya@gmail.com>
+//
+// SPDX-License-Identifier: LGPL-2.1-or-later
 
 #include "QXmppConfiguration.h"
 
@@ -91,7 +72,7 @@ QXmppConfiguration::QXmppConfiguration()
 
 /// Creates a copy of \a other.
 
-QXmppConfiguration::QXmppConfiguration(const QXmppConfiguration& other)
+QXmppConfiguration::QXmppConfiguration(const QXmppConfiguration &other)
     : d(other.d)
 {
 }
@@ -105,7 +86,7 @@ QXmppConfiguration::~QXmppConfiguration()
 
 /// Assigns \a other to this QXmppConfiguration.
 
-QXmppConfiguration& QXmppConfiguration::operator=(const QXmppConfiguration& other)
+QXmppConfiguration &QXmppConfiguration::operator=(const QXmppConfiguration &other)
 {
     d = other.d;
     return *this;
@@ -118,7 +99,7 @@ QXmppConfiguration& QXmppConfiguration::operator=(const QXmppConfiguration& othe
 /// the form of a string (e.g. "192.168.1.25").
 ///
 
-void QXmppConfiguration::setHost(const QString& host)
+void QXmppConfiguration::setHost(const QString &host)
 {
     d->host = host;
 }
@@ -130,7 +111,7 @@ void QXmppConfiguration::setHost(const QString& host)
 /// domain name is gmail.com and host name is talk.google.com
 ///
 
-void QXmppConfiguration::setDomain(const QString& domain)
+void QXmppConfiguration::setDomain(const QString &domain)
 {
     d->domain = domain;
 }
@@ -153,7 +134,7 @@ void QXmppConfiguration::setPort(int port)
 /// "qxmpp.test1@gmail.com"
 ///
 
-void QXmppConfiguration::setUser(const QString& user)
+void QXmppConfiguration::setUser(const QString &user)
 {
     d->user = user;
 }
@@ -163,7 +144,7 @@ void QXmppConfiguration::setUser(const QString& user)
 /// \param password Password for the specified username
 ///
 
-void QXmppConfiguration::setPassword(const QString& password)
+void QXmppConfiguration::setPassword(const QString &password)
 {
     d->password = password;
 }
@@ -179,7 +160,7 @@ void QXmppConfiguration::setPassword(const QString& password)
 ///
 /// \param resource Resource identifier of the client in connection.
 
-void QXmppConfiguration::setResource(const QString& resource)
+void QXmppConfiguration::setResource(const QString &resource)
 {
     d->resource = resource;
 }
@@ -190,87 +171,89 @@ void QXmppConfiguration::setResource(const QString& resource)
 ///
 /// \param jid
 
-void QXmppConfiguration::setJid(const QString& jid)
+void QXmppConfiguration::setJid(const QString &jid)
 {
     d->user = QXmppUtils::jidToUser(jid);
     d->domain = QXmppUtils::jidToDomain(jid);
     const QString resource = QXmppUtils::jidToResource(jid);
-    if (!resource.isEmpty())
+    if (!resource.isEmpty()) {
         d->resource = resource;
+    }
 }
 
-/// Returns the host name.
 ///
-/// \return host name
+/// Returns the custom hostname to connect to.
+///
+/// \return hostname
 ///
-
 QString QXmppConfiguration::host() const
 {
     return d->host;
 }
 
-/// Returns the domain name.
+///
+/// Returns the domain part of the JID.
 ///
 /// \return domain name
 ///
-
 QString QXmppConfiguration::domain() const
 {
     return d->domain;
 }
 
+///
 /// Returns the port number.
 ///
 /// \return port number
 ///
-
 int QXmppConfiguration::port() const
 {
     return d->port;
 }
 
-/// Returns the username.
+///
+/// Returns the localpart of the JID.
 ///
 /// \return username
 ///
-
 QString QXmppConfiguration::user() const
 {
     return d->user;
 }
 
+///
 /// Returns the password.
 ///
 /// \return password
 ///
-
 QString QXmppConfiguration::password() const
 {
     return d->password;
 }
 
+///
 /// Returns the resource identifier.
 ///
 /// \return resource identifier
 ///
-
 QString QXmppConfiguration::resource() const
 {
     return d->resource;
 }
 
-/// Returns the jabber id (jid).
 ///
-/// \return jabber id (jid)
+/// Returns the Jabber-ID (JID).
+///
+/// \return Jabber-ID (JID)
 /// (e.g. "qxmpp.test1@gmail.com/resource" or qxmpptest@jabber.org/QXmpp156)
 ///
-
 QString QXmppConfiguration::jid() const
 {
-    if (d->user.isEmpty())
+    if (d->user.isEmpty()) {
         return d->domain;
-    else
+    } else {
         return jidBare() + "/" + d->resource;
+    }
 }
 
 /// Returns the bare jabber id (jid), without the resource identifier.
@@ -281,10 +264,11 @@ QString QXmppConfiguration::jid() const
 
 QString QXmppConfiguration::jidBare() const
 {
-    if (d->user.isEmpty())
+    if (d->user.isEmpty()) {
         return d->domain;
-    else
+    } else {
         return d->user + "@" + d->domain;
+    }
 }
 
 /// Returns the access token used for X-FACEBOOK-PLATFORM authentication.
@@ -301,7 +285,7 @@ QString QXmppConfiguration::facebookAccessToken() const
 ///
 /// \param accessToken
 
-void QXmppConfiguration::setFacebookAccessToken(const QString& accessToken)
+void QXmppConfiguration::setFacebookAccessToken(const QString &accessToken)
 {
     d->facebookAccessToken = accessToken;
 }
@@ -317,7 +301,7 @@ QString QXmppConfiguration::facebookAppId() const
 ///
 /// \param appId
 
-void QXmppConfiguration::setFacebookAppId(const QString& appId)
+void QXmppConfiguration::setFacebookAppId(const QString &appId)
 {
     d->facebookAppId = appId;
 }
@@ -336,7 +320,7 @@ QString QXmppConfiguration::googleAccessToken() const
 ///
 /// \param accessToken
 
-void QXmppConfiguration::setGoogleAccessToken(const QString& accessToken)
+void QXmppConfiguration::setGoogleAccessToken(const QString &accessToken)
 {
     d->googleAccessToken = accessToken;
 }
@@ -355,7 +339,7 @@ QString QXmppConfiguration::windowsLiveAccessToken() const
 ///
 /// \param accessToken
 
-void QXmppConfiguration::setWindowsLiveAccessToken(const QString& accessToken)
+void QXmppConfiguration::setWindowsLiveAccessToken(const QString &accessToken)
 {
     d->windowsLiveAccessToken = accessToken;
 }
@@ -500,7 +484,7 @@ QString QXmppConfiguration::saslAuthMechanism() const
 /// Valid values: "SCRAM-SHA-256", "SCRAM-SHA-1", "DIGEST-MD5", "PLAIN", "ANONYMOUS",
 //                "X-FACEBOOK-PLATFORM", "X-MESSENGER-OAUTH2", "X-OAUTH2"
 
-void QXmppConfiguration::setSaslAuthMechanism(const QString& mechanism)
+void QXmppConfiguration::setSaslAuthMechanism(const QString &mechanism)
 {
     d->saslAuthMechanism = mechanism;
 }
@@ -511,7 +495,7 @@ void QXmppConfiguration::setSaslAuthMechanism(const QString& mechanism)
 /// QNetworkProxy::setApplicationProxy().
 /// \param proxy QNetworkProxy
 
-void QXmppConfiguration::setNetworkProxy(const QNetworkProxy& proxy)
+void QXmppConfiguration::setNetworkProxy(const QNetworkProxy &proxy)
 {
     d->networkProxy = proxy;
 }
@@ -572,7 +556,7 @@ int QXmppConfiguration::keepAliveTimeout() const
 
 /// Specifies a list of trusted CA certificates.
 
-void QXmppConfiguration::setCaCertificates(const QList<QSslCertificate>& caCertificates)
+void QXmppConfiguration::setCaCertificates(const QList<QSslCertificate> &caCertificates)
 {
     d->caCertificates = caCertificates;
 }
