@@ -1,25 +1,6 @@
-/*
- * Copyright (C) 2008-2021 The QXmpp developers
- *
- * Author:
- *  Manjeet Dahiya
- *
- * Source:
- *  https://github.com/qxmpp-project/qxmpp
- *
- * This file is a part of QXmpp library.
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- */
+// SPDX-FileCopyrightText: 2010 Manjeet Dahiya <manjeetdahiya@gmail.com>
+//
+// SPDX-License-Identifier: LGPL-2.1-or-later
 
 #include "QXmppDiscoveryManager.h"
 
@@ -28,12 +9,15 @@
 #include "QXmppConstants_p.h"
 #include "QXmppDataForm.h"
 #include "QXmppDiscoveryIq.h"
-#include "QXmppGlobal.h"
+#include "QXmppFutureUtils_p.h"
+#include "QXmppIqHandling.h"
 #include "QXmppStream.h"
 
 #include <QCoreApplication>
 #include <QDomElement>
 
+using namespace QXmpp::Private;
+
 class QXmppDiscoveryManagerPrivate
 {
 public:
@@ -44,6 +28,24 @@ public:
     QXmppDataForm clientInfoForm;
 };
 
+///
+/// \typedef QXmppDiscoveryManager::InfoResult
+///
+/// Contains the discovery information result in the form of an QXmppDiscoveryIq
+/// or (in case the request did not succeed) a QXmppStanza::Error.
+///
+/// \since QXmpp 1.5
+///
+
+///
+/// \typedef QXmppDiscoveryManager::ItemsResult
+///
+/// Contains a list of service discovery items or (in case the request did not
+/// succeed) a QXmppStanza::Error.
+///
+/// \since QXmpp 1.5
+///
+
 QXmppDiscoveryManager::QXmppDiscoveryManager()
     : d(new QXmppDiscoveryManagerPrivate)
 {
@@ -54,34 +56,34 @@ QXmppDiscoveryManager::QXmppDiscoveryManager()
 #else
     d->clientType = "pc";
 #endif
-    if (qApp->applicationName().isEmpty() && qApp->applicationVersion().isEmpty())
+    if (qApp->applicationName().isEmpty() && qApp->applicationVersion().isEmpty()) {
         d->clientName = QString("%1 %2").arg("Based on QXmpp", QXmppVersion());
-    else
+    } else {
         d->clientName = QString("%1 %2").arg(qApp->applicationName(), qApp->applicationVersion());
+    }
 }
 
-QXmppDiscoveryManager::~QXmppDiscoveryManager()
-{
-    delete d;
-}
+QXmppDiscoveryManager::~QXmppDiscoveryManager() = default;
 
 /// Requests information from the specified XMPP entity.
 ///
 /// \param jid  The target entity's JID.
 /// \param node The target node (optional).
 
-QString QXmppDiscoveryManager::requestInfo(const QString& jid, const QString& node)
+QString QXmppDiscoveryManager::requestInfo(const QString &jid, const QString &node)
 {
     QXmppDiscoveryIq request;
     request.setType(QXmppIq::Get);
     request.setQueryType(QXmppDiscoveryIq::InfoQuery);
     request.setTo(jid);
-    if (!node.isEmpty())
+    if (!node.isEmpty()) {
         request.setQueryNode(node);
-    if (client()->sendPacket(request))
+    }
+    if (client()->sendPacket(request)) {
         return request.id();
-    else
+    } else {
         return QString();
+    }
 }
 
 /// Requests items from the specified XMPP entity.
@@ -89,18 +91,68 @@ QString QXmppDiscoveryManager::requestInfo(const QString& jid, const QString& no
 /// \param jid  The target entity's JID.
 /// \param node The target node (optional).
 
-QString QXmppDiscoveryManager::requestItems(const QString& jid, const QString& node)
+QString QXmppDiscoveryManager::requestItems(const QString &jid, const QString &node)
 {
     QXmppDiscoveryIq request;
     request.setType(QXmppIq::Get);
     request.setQueryType(QXmppDiscoveryIq::ItemsQuery);
     request.setTo(jid);
-    if (!node.isEmpty())
+    if (!node.isEmpty()) {
         request.setQueryNode(node);
-    if (client()->sendPacket(request))
+    }
+    if (client()->sendPacket(request)) {
         return request.id();
-    else
+    } else {
         return QString();
+    }
+}
+
+///
+/// Requests information from the specified XMPP entity.
+///
+/// \param jid  The target entity's JID.
+/// \param node The target node (optional).
+///
+/// \warning THIS API IS NOT FINALIZED YET!
+///
+/// \since QXmpp 1.5
+///
+QXmppTask<QXmppDiscoveryManager::InfoResult> QXmppDiscoveryManager::requestDiscoInfo(const QString &jid, const QString &node)
+{
+    QXmppDiscoveryIq request;
+    request.setType(QXmppIq::Get);
+    request.setQueryType(QXmppDiscoveryIq::InfoQuery);
+    request.setTo(jid);
+    if (!node.isEmpty()) {
+        request.setQueryNode(node);
+    }
+
+    return chainIq<InfoResult>(client()->sendIq(std::move(request)), this);
+}
+
+///
+/// Requests items from the specified XMPP entity.
+///
+/// \param jid  The target entity's JID.
+/// \param node The target node (optional).
+///
+/// \warning THIS API IS NOT FINALIZED YET!
+///
+/// \since QXmpp 1.5
+///
+QXmppTask<QXmppDiscoveryManager::ItemsResult> QXmppDiscoveryManager::requestDiscoItems(const QString &jid, const QString &node)
+{
+    QXmppDiscoveryIq request;
+    request.setType(QXmppIq::Get);
+    request.setQueryType(QXmppDiscoveryIq::ItemsQuery);
+    request.setTo(jid);
+    if (!node.isEmpty()) {
+        request.setQueryNode(node);
+    }
+
+    return chainIq(client()->sendIq(std::move(request)), this, [](QXmppDiscoveryIq &&iq) -> ItemsResult {
+        return iq.items();
+    });
 }
 
 ///
@@ -118,10 +170,11 @@ QXmppDiscoveryIq QXmppDiscoveryManager::capabilities()
     features << QXmppClientPrivate::discoveryFeatures();
 
     // add features of all registered extensions
-    const QList<QXmppClientExtension *> extensions = client()->extensions();
-    for (auto* extension : extensions) {
-        if (extension)
+    const auto extensions = client()->extensions();
+    for (auto *extension : extensions) {
+        if (extension) {
             features << extension->discoveryFeatures();
+        }
     }
 
     iq.setFeatures(features);
@@ -135,16 +188,18 @@ QXmppDiscoveryIq QXmppDiscoveryManager::capabilities()
     identity.setName(clientName());
     identities << identity;
 
-    for (auto* extension : client()->extensions()) {
-        if (extension)
+    for (auto *extension : client()->extensions()) {
+        if (extension) {
             identities << extension->discoveryIdentities();
+        }
     }
 
     iq.setIdentities(identities);
 
     // extended information
-    if (!d->clientInfoForm.isNull())
+    if (!d->clientInfoForm.isNull()) {
         iq.setForm(d->clientInfoForm);
+    }
 
     return iq;
 }
@@ -153,7 +208,7 @@ QXmppDiscoveryIq QXmppDiscoveryManager::capabilities()
 ///
 /// \param node
 
-void QXmppDiscoveryManager::setClientCapabilitiesNode(const QString& node)
+void QXmppDiscoveryManager::setClientCapabilitiesNode(const QString &node)
 {
     d->clientCapabilitiesNode = node;
 }
@@ -165,7 +220,7 @@ void QXmppDiscoveryManager::setClientCapabilitiesNode(const QString& node)
 ///
 /// \param category
 
-void QXmppDiscoveryManager::setClientCategory(const QString& category)
+void QXmppDiscoveryManager::setClientCategory(const QString &category)
 {
     d->clientCategory = category;
 }
@@ -177,7 +232,7 @@ void QXmppDiscoveryManager::setClientCategory(const QString& category)
 ///
 /// \param type
 
-void QXmppDiscoveryManager::setClientType(const QString& type)
+void QXmppDiscoveryManager::setClientType(const QString &type)
 {
     d->clientType = type;
 }
@@ -186,7 +241,7 @@ void QXmppDiscoveryManager::setClientType(const QString& type)
 ///
 /// \param name
 
-void QXmppDiscoveryManager::setClientName(const QString& name)
+void QXmppDiscoveryManager::setClientName(const QString &name)
 {
     d->clientName = name;
 }
@@ -239,7 +294,7 @@ QXmppDataForm QXmppDiscoveryManager::clientInfoForm() const
 /// Sets the client's extended information form, as defined
 /// by \xep{0128}: Service Discovery Extensions.
 
-void QXmppDiscoveryManager::setClientInfoForm(const QXmppDataForm& form)
+void QXmppDiscoveryManager::setClientInfoForm(const QXmppDataForm &form)
 {
     d->clientInfoForm = form;
 }
@@ -250,37 +305,26 @@ QStringList QXmppDiscoveryManager::discoveryFeatures() const
     return QStringList() << ns_disco_info;
 }
 
-bool QXmppDiscoveryManager::handleStanza(const QDomElement& element)
+bool QXmppDiscoveryManager::handleStanza(const QDomElement &element)
 {
+    if (QXmpp::handleIqRequests<QXmppDiscoveryIq>(element, client(), this)) {
+        return true;
+    }
+
     if (element.tagName() == "iq" && QXmppDiscoveryIq::isDiscoveryIq(element)) {
         QXmppDiscoveryIq receivedIq;
         receivedIq.parse(element);
 
         switch (receivedIq.type()) {
         case QXmppIq::Get:
-            if (receivedIq.queryType() == QXmppDiscoveryIq::InfoQuery &&
-                (receivedIq.queryNode().isEmpty() ||
-                 receivedIq.queryNode().startsWith(d->clientCapabilitiesNode))) {
-
-                // respond to info queries for the client itself
-                QXmppDiscoveryIq qxmppFeatures = capabilities();
-                qxmppFeatures.setId(receivedIq.id());
-                qxmppFeatures.setTo(receivedIq.from());
-                qxmppFeatures.setQueryNode(receivedIq.queryNode());
-                client()->sendPacket(qxmppFeatures);
-                return true;
-            } else {
-                // let other managers handle other queries
-                return false;
-            }
-
+            break;
         case QXmppIq::Result:
         case QXmppIq::Error:
             // handle all replies
             if (receivedIq.queryType() == QXmppDiscoveryIq::InfoQuery) {
-                emit infoReceived(receivedIq);
+                Q_EMIT infoReceived(receivedIq);
             } else if (receivedIq.queryType() == QXmppDiscoveryIq::ItemsQuery) {
-                emit itemsReceived(receivedIq);
+                Q_EMIT itemsReceived(receivedIq);
             }
             return true;
 
@@ -291,4 +335,28 @@ bool QXmppDiscoveryManager::handleStanza(const QDomElement& element)
     }
     return false;
 }
+
+std::variant<QXmppDiscoveryIq, QXmppStanza::Error> QXmppDiscoveryManager::handleIq(QXmppDiscoveryIq &&iq)
+{
+    using Error = QXmppStanza::Error;
+
+    if (!iq.queryNode().isEmpty() && !iq.queryNode().startsWith(d->clientCapabilitiesNode)) {
+        return Error(Error::Cancel, Error::ItemNotFound, QStringLiteral("Unknown node."));
+    }
+
+    switch (iq.queryType()) {
+    case QXmppDiscoveryIq::InfoQuery: {
+        // respond to info queries for the client itself
+        QXmppDiscoveryIq features = capabilities();
+        features.setQueryNode(iq.queryNode());
+        return features;
+    }
+    case QXmppDiscoveryIq::ItemsQuery: {
+        QXmppDiscoveryIq reply;
+        reply.setQueryType(QXmppDiscoveryIq::ItemsQuery);
+        return reply;
+    }
+    }
+    Q_UNREACHABLE();
+}
 /// \endcond
