@@ -1,25 +1,6 @@
-/*
- * Copyright (C) 2008-2021 The QXmpp developers
- *
- * Authors:
- *  Ian Reinhart Geiser
- *
- * Source:
- *  https://github.com/qxmpp-project/qxmpp
- *
- * This file is a part of QXmpp library.
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- */
+// SPDX-FileCopyrightText: 2009 Ian Reinhart Geiser <geiseri@kde.org>
+//
+// SPDX-License-Identifier: LGPL-2.1-or-later
 
 #include "QXmppInvokable.h"
 
@@ -47,12 +28,14 @@ QVariant QXmppInvokable::dispatch(const QByteArray &method, const QList<QVariant
 {
     buildMethodHash();
 
-    if (!m_methodHash.contains(method))
+    if (!m_methodHash.contains(method)) {
         return QVariant();
+    }
 
     int idx = m_methodHash[method];
-    if (paramTypes(args) != metaObject()->method(idx).parameterTypes())
+    if (paramTypes(args) != metaObject()->method(idx).parameterTypes()) {
         return QVariant();
+    }
 
     const char *typeName = metaObject()->method(idx).typeName();
     int resultType = QMetaType::type(typeName);
@@ -96,16 +79,18 @@ QVariant QXmppInvokable::dispatch(const QByteArray &method, const QList<QVariant
 QList<QByteArray> QXmppInvokable::paramTypes(const QList<QVariant> &params)
 {
     QList<QByteArray> types;
-    for (const auto &variant : qAsConst(params))
+    for (const auto &variant : std::as_const(params)) {
         types << variant.typeName();
+    }
     return types;
 }
 
 void QXmppInvokable::buildMethodHash()
 {
     QWriteLocker locker(&m_lock);
-    if (m_methodHash.size() > 0)
+    if (m_methodHash.size() > 0) {
         return;
+    }
 
     int methodCount = metaObject()->methodCount();
     for (int idx = 0; idx < methodCount; ++idx) {
