@@ -1,32 +1,15 @@
-/*
- * Copyright (C) 2008-2021 The QXmpp developers
- *
- * Author:
- *  Georg Rudoy
- *  Jeremy Lainé
- *
- * Source:
- *  https://github.com/qxmpp-project/qxmpp
- *
- * This file is a part of QXmpp library.
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- */
+// SPDX-FileCopyrightText: 2012 Georg Rudoy <0xd34df00d@gmail.com>
+// SPDX-FileCopyrightText: 2012 Jeremy Lainé <jeremy.laine@m4x.org>
+//
+// SPDX-License-Identifier: LGPL-2.1-or-later
 
 #include "QXmppMessageReceiptManager.h"
 
 #include "QXmppClient.h"
 #include "QXmppConstants_p.h"
+#include "QXmppE2eeMetadata.h"
 #include "QXmppMessage.h"
+#include "QXmppTask.h"
 #include "QXmppUtils.h"
 
 #include <QDomElement>
@@ -45,23 +28,17 @@ QStringList QXmppMessageReceiptManager::discoveryFeatures() const
     return QStringList(ns_message_receipts);
 }
 
-bool QXmppMessageReceiptManager::handleStanza(const QDomElement &stanza)
+bool QXmppMessageReceiptManager::handleMessage(const QXmppMessage &message)
 {
-    if (stanza.tagName() != "message")
+    if (message.type() == QXmppMessage::Error) {
         return false;
-
-    QXmppMessage message;
-    message.parse(stanza);
-
-    if (message.type() == QXmppMessage::Error)
-        return false;
-
+    }
     // Handle receipts and cancel any further processing.
     if (!message.receiptId().isEmpty()) {
         // Buggy clients also mark carbon messages as received; to avoid this
         // we check whether sender and receiver have the same bare JID.
         if (QXmppUtils::jidToBareJid(message.from()) != QXmppUtils::jidToBareJid(message.to())) {
-            emit messageDelivered(message.from(), message.receiptId());
+            Q_EMIT messageDelivered(message.from(), message.receiptId());
         }
         return true;
     }
@@ -71,7 +48,7 @@ bool QXmppMessageReceiptManager::handleStanza(const QDomElement &stanza)
         QXmppMessage receipt;
         receipt.setTo(message.from());
         receipt.setReceiptId(message.id());
-        client()->sendPacket(receipt);
+        client()->reply(std::move(receipt), message.e2eeMetadata());
     }
 
     // Continue processing.
