@@ -1,25 +1,6 @@
-/*
- * Copyright (C) 2008-2021 The QXmpp developers
- *
- * Author:
- *  Jeremy Lainé
- *
- * Source:
- *  https://github.com/qxmpp-project/qxmpp
- *
- * This file is a part of QXmpp library.
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- */
+// SPDX-FileCopyrightText: 2010 Jeremy Lainé <jeremy.laine@m4x.org>
+//
+// SPDX-License-Identifier: LGPL-2.1-or-later
 
 #include "QXmppMucManager.h"
 
@@ -56,19 +37,15 @@ public:
     QString subject;
 };
 
+///
 /// Constructs a new QXmppMucManager.
-
+///
 QXmppMucManager::QXmppMucManager()
+    : d(std::make_unique<QXmppMucManagerPrivate>())
 {
-    d = new QXmppMucManagerPrivate;
 }
 
-/// Destroys a QXmppMucManager.
-
-QXmppMucManager::~QXmppMucManager()
-{
-    delete d;
-}
+QXmppMucManager::~QXmppMucManager() = default;
 
 /// Adds the given chat room to the set of managed rooms.
 ///
@@ -84,7 +61,7 @@ QXmppMucRoom *QXmppMucManager::addRoom(const QString &roomJid)
                 this, &QXmppMucManager::_q_roomDestroyed);
 
         // emit signal
-        emit roomAdded(room);
+        Q_EMIT roomAdded(room);
     }
     return room;
 }
@@ -115,13 +92,15 @@ bool QXmppMucManager::handleStanza(const QDomElement &element)
 
             QXmppMucRoom *room = d->rooms.value(iq.from());
             if (room && iq.type() == QXmppIq::Result && room->d->permissionsQueue.remove(iq.id())) {
-                for (const auto &item : iq.items()) {
+                const auto items = iq.items();
+                for (const auto &item : items) {
                     const QString jid = item.jid();
-                    if (!room->d->permissions.contains(jid))
+                    if (!room->d->permissions.contains(jid)) {
                         room->d->permissions.insert(jid, item);
+                    }
                 }
                 if (room->d->permissionsQueue.isEmpty()) {
-                    emit room->permissionsReceived(room->d->permissions.values());
+                    Q_EMIT room->permissionsReceived(room->d->permissions.values());
                 }
                 return true;
             }
@@ -131,7 +110,7 @@ bool QXmppMucManager::handleStanza(const QDomElement &element)
 
             QXmppMucRoom *room = d->rooms.value(iq.from());
             if (room && iq.type() == QXmppIq::Result && !iq.form().isNull()) {
-                emit room->configurationReceived(iq.form());
+                Q_EMIT room->configurationReceived(iq.form());
                 return true;
             }
         }
@@ -141,7 +120,6 @@ bool QXmppMucManager::handleStanza(const QDomElement &element)
 
 void QXmppMucManager::setClient(QXmppClient *client)
 {
-
     QXmppClientExtension::setClient(client);
 
     connect(client, &QXmppClient::messageReceived,
@@ -151,13 +129,14 @@ void QXmppMucManager::setClient(QXmppClient *client)
 
 void QXmppMucManager::_q_messageReceived(const QXmppMessage &msg)
 {
-    if (msg.type() != QXmppMessage::Normal)
+    if (msg.type() != QXmppMessage::Normal) {
         return;
+    }
 
     // process room invitations
     const QString roomJid = msg.mucInvitationJid();
     if (!roomJid.isEmpty() && (!d->rooms.contains(roomJid) || !d->rooms.value(roomJid)->isJoined())) {
-        emit invitationReceived(roomJid, msg.from(), msg.mucInvitationReason());
+        Q_EMIT invitationReceived(roomJid, msg.from(), msg.mucInvitationReason());
     }
 }
 
@@ -172,10 +151,9 @@ void QXmppMucManager::_q_roomDestroyed(QObject *object)
 /// \param parent
 
 QXmppMucRoom::QXmppMucRoom(QXmppClient *client, const QString &jid, QObject *parent)
-    : QObject(parent)
+    : QObject(parent),
+      d(std::make_unique<QXmppMucRoomPrivate>())
 {
-
-    d = new QXmppMucRoomPrivate;
     d->allowedActions = NoAction;
     d->client = client;
     d->discoManager = client->findExtension<QXmppDiscoveryManager>();
@@ -201,12 +179,7 @@ QXmppMucRoom::QXmppMucRoom(QXmppClient *client, const QString &jid, QObject *par
     connect(this, &QXmppMucRoom::left, this, &QXmppMucRoom::isJoinedChanged);
 }
 
-/// Destroys a QXmppMucRoom.
-
-QXmppMucRoom::~QXmppMucRoom()
-{
-    delete d;
-}
+QXmppMucRoom::~QXmppMucRoom() = default;
 
 QXmppMucRoom::Actions QXmppMucRoom::allowedActions() const
 {
@@ -255,8 +228,9 @@ QString QXmppMucRoom::jid() const
 
 bool QXmppMucRoom::join()
 {
-    if (isJoined() || d->nickName.isEmpty())
+    if (isJoined() || d->nickName.isEmpty()) {
         return false;
+    }
 
     // reflect our current presence in the chat room
     QXmppPresence packet = d->client->clientPresence();
@@ -330,10 +304,15 @@ bool QXmppMucRoom::sendInvitation(const QString &jid, const QString &reason)
     return d->client->sendPacket(message);
 }
 
+///
 /// Sends a message to the room.
 ///
+/// This is just a helper function, you can as well also send a message to the
+/// channel manually by setting the message type to 'groupchat' and addressing
+/// the JID of the MUC room.
+///
 /// \return true if the request was sent, false otherwise
-
+///
 bool QXmppMucRoom::sendMessage(const QString &text)
 {
     QXmppMessage msg;
@@ -351,8 +330,9 @@ bool QXmppMucRoom::sendMessage(const QString &text)
 
 void QXmppMucRoom::setNickName(const QString &nickName)
 {
-    if (nickName == d->nickName)
+    if (nickName == d->nickName) {
         return;
+    }
 
     // if we had already joined the room, request nickname change
     if (isJoined()) {
@@ -362,7 +342,7 @@ void QXmppMucRoom::setNickName(const QString &nickName)
         d->client->sendPacket(packet);
     } else {
         d->nickName = nickName;
-        emit nickNameChanged(nickName);
+        Q_EMIT nickNameChanged(nickName);
     }
 }
 
@@ -372,10 +352,11 @@ void QXmppMucRoom::setNickName(const QString &nickName)
 
 QString QXmppMucRoom::participantFullJid(const QString &jid) const
 {
-    if (d->participants.contains(jid))
+    if (d->participants.contains(jid)) {
         return d->participants.value(jid).mucItem().jid();
-    else
+    } else {
         return QString();
+    }
 }
 
 /// Returns the presence for the given participant.
@@ -384,8 +365,9 @@ QString QXmppMucRoom::participantFullJid(const QString &jid) const
 
 QXmppPresence QXmppMucRoom::participantPresence(const QString &jid) const
 {
-    if (d->participants.contains(jid))
+    if (d->participants.contains(jid)) {
         return d->participants.value(jid);
+    }
 
     QXmppPresence presence;
     presence.setFrom(jid);
@@ -474,15 +456,16 @@ bool QXmppMucRoom::requestPermissions()
 
     d->permissions.clear();
     d->permissionsQueue.clear();
-    for (const auto &affiliation : qAsConst(affiliations)) {
+    for (const auto &affiliation : std::as_const(affiliations)) {
         QXmppMucItem item;
         item.setAffiliation(affiliation);
 
         QXmppMucAdminIq iq;
         iq.setTo(d->jid);
         iq.setItems(QList<QXmppMucItem>() << item);
-        if (!d->client->sendPacket(iq))
+        if (!d->client->sendPacket(iq)) {
             return false;
+        }
         d->permissionsQueue += iq.id();
     }
     return true;
@@ -499,10 +482,11 @@ bool QXmppMucRoom::setPermissions(const QList<QXmppMucItem> &permissions)
     QList<QXmppMucItem> items;
 
     // Process changed members
-    for (const auto &item : qAsConst(permissions)) {
+    for (const auto &item : std::as_const(permissions)) {
         const QString jid = item.jid();
-        if (d->permissions.value(jid).affiliation() != item.affiliation())
+        if (d->permissions.value(jid).affiliation() != item.affiliation()) {
             items << item;
+        }
         d->permissions.remove(jid);
     }
 
@@ -517,8 +501,9 @@ bool QXmppMucRoom::setPermissions(const QList<QXmppMucItem> &permissions)
     }
 
     // Don't send request if there are no changes
-    if (items.isEmpty())
+    if (items.isEmpty()) {
         return false;
+    }
 
     QXmppMucAdminIq iq;
     iq.setTo(d->jid);
@@ -534,19 +519,21 @@ void QXmppMucRoom::_q_disconnected()
     // clear chat room participants
     const QStringList removed = d->participants.keys();
     d->participants.clear();
-    for (const auto &jid : removed)
-        emit participantRemoved(jid);
-    emit participantsChanged();
+    for (const auto &jid : removed) {
+        Q_EMIT participantRemoved(jid);
+    }
+    Q_EMIT participantsChanged();
 
     // update available actions
     if (d->allowedActions != NoAction) {
         d->allowedActions = NoAction;
-        emit allowedActionsChanged(d->allowedActions);
+        Q_EMIT allowedActionsChanged(d->allowedActions);
     }
 
     // emit "left" signal if we had joined the room
-    if (wasJoined)
-        emit left();
+    if (wasJoined) {
+        Q_EMIT left();
+    }
 }
 
 void QXmppMucRoom::_q_discoveryInfoReceived(const QXmppDiscoveryIq &iq)
@@ -563,24 +550,25 @@ void QXmppMucRoom::_q_discoveryInfoReceived(const QXmppDiscoveryIq &iq)
 
         if (name != d->name) {
             d->name = name;
-            emit nameChanged(name);
+            Q_EMIT nameChanged(name);
         }
     }
 }
 
 void QXmppMucRoom::_q_messageReceived(const QXmppMessage &message)
 {
-    if (QXmppUtils::jidToBareJid(message.from()) != d->jid)
+    if (QXmppUtils::jidToBareJid(message.from()) != d->jid) {
         return;
+    }
 
     // handle message subject
     const QString subject = message.subject();
     if (!subject.isEmpty()) {
         d->subject = subject;
-        emit subjectChanged(subject);
+        Q_EMIT subjectChanged(subject);
     }
 
-    emit messageReceived(message);
+    Q_EMIT messageReceived(message);
 }
 
 void QXmppMucRoom::_q_presenceReceived(const QXmppPresence &presence)
@@ -594,8 +582,9 @@ void QXmppMucRoom::_q_presenceReceived(const QXmppPresence &presence)
         d->client->sendPacket(packet);
     }
 
-    if (QXmppUtils::jidToBareJid(jid) != d->jid)
+    if (QXmppUtils::jidToBareJid(jid) != d->jid) {
         return;
+    }
 
     if (presence.type() == QXmppPresence::Available) {
         const bool added = !d->participants.contains(jid);
@@ -608,48 +597,51 @@ void QXmppMucRoom::_q_presenceReceived(const QXmppPresence &presence)
             Actions newActions = NoAction;
 
             // role
-            if (mucItem.role() == QXmppMucItem::ModeratorRole)
+            if (mucItem.role() == QXmppMucItem::ModeratorRole) {
                 newActions |= (KickAction | SubjectAction);
+            }
 
             // affiliation
-            if (mucItem.affiliation() == QXmppMucItem::OwnerAffiliation)
+            if (mucItem.affiliation() == QXmppMucItem::OwnerAffiliation) {
                 newActions |= (ConfigurationAction | PermissionsAction | SubjectAction);
-            else if (mucItem.affiliation() == QXmppMucItem::AdminAffiliation)
+            } else if (mucItem.affiliation() == QXmppMucItem::AdminAffiliation) {
                 newActions |= (PermissionsAction | SubjectAction);
+            }
 
             if (newActions != d->allowedActions) {
                 d->allowedActions = newActions;
-                emit allowedActionsChanged(d->allowedActions);
+                Q_EMIT allowedActionsChanged(d->allowedActions);
             }
         }
 
         if (added) {
-            emit participantAdded(jid);
-            emit participantsChanged();
+            Q_EMIT participantAdded(jid);
+            Q_EMIT participantsChanged();
             if (jid == d->ownJid()) {
                 // request room information
-                if (d->discoManager)
+                if (d->discoManager) {
                     d->discoManager->requestInfo(d->jid);
+                }
 
-                emit joined();
+                Q_EMIT joined();
             }
         } else {
-            emit participantChanged(jid);
+            Q_EMIT participantChanged(jid);
         }
     } else if (presence.type() == QXmppPresence::Unavailable) {
         if (d->participants.contains(jid)) {
             d->participants.insert(jid, presence);
 
-            emit participantRemoved(jid);
+            Q_EMIT participantRemoved(jid);
             d->participants.remove(jid);
-            emit participantsChanged();
+            Q_EMIT participantsChanged();
 
             // check whether this was our own presence
             if (jid == d->ownJid()) {
                 const QString newNick = presence.mucItem().nick();
                 if (!newNick.isEmpty() && newNick != d->nickName) {
                     d->nickName = newNick;
-                    emit nickNameChanged(newNick);
+                    Q_EMIT nickNameChanged(newNick);
                     return;
                 }
 
@@ -657,33 +649,34 @@ void QXmppMucRoom::_q_presenceReceived(const QXmppPresence &presence)
                 if (presence.mucStatusCodes().contains(307)) {
                     const QString actor = presence.mucItem().actor();
                     const QString reason = presence.mucItem().reason();
-                    emit kicked(actor, reason);
+                    Q_EMIT kicked(actor, reason);
                 }
 
                 // clear chat room participants
                 const QStringList removed = d->participants.keys();
                 d->participants.clear();
-                for (const auto &jid : removed)
-                    emit participantRemoved(jid);
-                emit participantsChanged();
+                for (const auto &jid : removed) {
+                    Q_EMIT participantRemoved(jid);
+                }
+                Q_EMIT participantsChanged();
 
                 // update available actions
                 if (d->allowedActions != NoAction) {
                     d->allowedActions = NoAction;
-                    emit allowedActionsChanged(d->allowedActions);
+                    Q_EMIT allowedActionsChanged(d->allowedActions);
                 }
 
                 // notify user we left the room
-                emit left();
+                Q_EMIT left();
             }
         }
     } else if (presence.type() == QXmppPresence::Error) {
         if (presence.isMucSupported()) {
             // emit error
-            emit error(presence.error());
+            Q_EMIT error(presence.error());
 
             // notify the user we left the room
-            emit left();
+            Q_EMIT left();
         }
     }
 }
