@@ -1,26 +1,7 @@
-/*
- * Copyright (C) 2008-2021 The QXmpp developers
- *
- * Authors:
- *  Manjeet Dahiya
- *  Jeremy Lainé
- *
- * Source:
- *  https://github.com/qxmpp-project/qxmpp
- *
- * This file is a part of QXmpp library.
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- */
+// SPDX-FileCopyrightText: 2010 Manjeet Dahiya <manjeetdahiya@gmail.com>
+// SPDX-FileCopyrightText: 2010 Jeremy Lainé <jeremy.laine@m4x.org>
+//
+// SPDX-License-Identifier: LGPL-2.1-or-later
 
 #include "QXmppOutgoingClient.h"
 
@@ -34,10 +15,12 @@
 #include "QXmppSasl_p.h"
 #include "QXmppStreamFeatures.h"
 #include "QXmppStreamManagement_p.h"
+#include "QXmppTask.h"
 #include "QXmppUtils.h"
 
 #include <QCryptographicHash>
 #include <QDnsLookup>
+#include <QFuture>
 #include <QNetworkProxy>
 #include <QSslConfiguration>
 #include <QSslSocket>
@@ -180,13 +163,12 @@ void QXmppOutgoingClientPrivate::connectToNextDNSHost()
         dns.serviceRecords().at(curIdx).port());
 }
 
+///
 /// Constructs an outgoing client stream.
 ///
-/// \param parent
-
 QXmppOutgoingClient::QXmppOutgoingClient(QObject *parent)
     : QXmppStream(parent),
-      d(new QXmppOutgoingClientPrivate(this))
+      d(std::make_unique<QXmppOutgoingClientPrivate>(this))
 {
     // initialise socket
     auto *socket = new QSslSocket(this);
@@ -213,14 +195,23 @@ QXmppOutgoingClient::QXmppOutgoingClient(QObject *parent)
 
     connect(this, &QXmppStream::connected, this, &QXmppOutgoingClient::pingStart);
     connect(this, &QXmppStream::disconnected, this, &QXmppOutgoingClient::pingStop);
+
+    // IQ response handling
+    connect(this, &QXmppStream::connected, this, [=]() {
+        if (!d->streamResumed) {
+            // we can't expect a response because this is a new stream
+            cancelOngoingIqs();
+        }
+    });
+    connect(this, &QXmppStream::disconnected, this, [=]() {
+        if (!d->canResume) {
+            // this stream can't be resumed; we can cancel all ongoing IQs
+            cancelOngoingIqs();
+        }
+    });
 }
 
-/// Destroys an outgoing client stream.
-
-QXmppOutgoingClient::~QXmppOutgoingClient()
-{
-    delete d;
-}
+QXmppOutgoingClient::~QXmppOutgoingClient() = default;
 
 /// Returns a reference to the stream's configuration.
 
@@ -327,6 +318,21 @@ bool QXmppOutgoingClient::isStreamResumed() const
     return d->streamResumed;
 }
 
+///
+/// Sends an IQ and reports the response asynchronously.
+///
+/// It makes sure that the to address is set so the stream can correctly check the reponse's
+/// sender.
+///
+/// \since QXmpp 1.5
+///
+QXmppTask<QXmppStream::IqResult> QXmppOutgoingClient::sendIq(QXmppIq &&iq)
+{
+    // If 'to' is empty the user's bare JID is meant implicitly (see RFC6120, section 10.3.3.).
+    auto to = iq.to();
+    return QXmppStream::sendIq(std::move(iq), to.isEmpty() ? d->config.jidBare() : to);
+}
+
 void QXmppOutgoingClient::_q_socketDisconnected()
 {
     debug("Socket disconnected");
@@ -336,7 +342,7 @@ void QXmppOutgoingClient::_q_socketDisconnected()
         d->redirectHost = QString();
         d->redirectPort = 0;
     } else {
-        emit disconnected();
+        Q_EMIT disconnected();
     }
 }
 
@@ -344,15 +350,17 @@ void QXmppOutgoingClient::socketSslErrors(const QList<QSslError> &errors)
 {
     // log errors
     warning("SSL errors");
-    for (int i = 0; i < errors.count(); ++i)
+    for (int i = 0; i < errors.count(); ++i) {
         warning(errors.at(i).errorString());
+    }
 
     // relay signal
-    emit sslErrors(errors);
+    Q_EMIT sslErrors(errors);
 
     // if configured, ignore the errors
-    if (configuration().ignoreSslErrors())
+    if (configuration().ignoreSslErrors()) {
         socket()->ignoreSslErrors();
+    }
 }
 
 void QXmppOutgoingClient::socketError(QAbstractSocket::SocketError socketError)
@@ -362,8 +370,9 @@ void QXmppOutgoingClient::socketError(QAbstractSocket::SocketError socketError)
         (d->dns.serviceRecords().count() > d->nextSrvRecordIdx)) {
         // some network error occurred during startup -> try next available SRV record server
         d->connectToNextDNSHost();
-    } else
-        emit error(QXmppClient::SocketError);
+    } else {
+        Q_EMIT error(QXmppClient::SocketError);
+    }
 }
 
 /// \cond
@@ -401,10 +410,12 @@ void QXmppOutgoingClient::handleStart()
 
 void QXmppOutgoingClient::handleStream(const QDomElement &streamElement)
 {
-    if (d->streamId.isEmpty())
+    if (d->streamId.isEmpty()) {
         d->streamId = streamElement.attribute("id");
-    if (d->streamFrom.isEmpty())
+    }
+    if (d->streamFrom.isEmpty()) {
         d->streamFrom = streamElement.attribute("from");
+    }
     if (d->streamVersion.isEmpty()) {
         d->streamVersion = streamElement.attribute("version");
 
@@ -425,16 +436,18 @@ void QXmppOutgoingClient::handleStanza(const QDomElement &nodeRecv)
 
     // give client opportunity to handle stanza
     bool handled = false;
-    emit elementReceived(nodeRecv, handled);
-    if (handled)
+    Q_EMIT elementReceived(nodeRecv, handled);
+    if (handled) {
         return;
+    }
 
     if (QXmppStreamFeatures::isStreamFeatures(nodeRecv)) {
         QXmppStreamFeatures features;
         features.parse(nodeRecv);
 
-        if (features.clientStateIndicationMode() == QXmppStreamFeatures::Enabled)
+        if (features.clientStateIndicationMode() == QXmppStreamFeatures::Enabled) {
             d->clientStateIndicationEnabled = true;
+        }
 
         // handle authentication
         const bool nonSaslAvailable = features.nonSaslAuthMode() != QXmppStreamFeatures::Disabled;
@@ -447,19 +460,23 @@ void QXmppOutgoingClient::handleStanza(const QDomElement &nodeRecv)
                 supportedMechanisms.removeAll(preferredMechanism);
                 supportedMechanisms.prepend(preferredMechanism);
             }
-            if (configuration().facebookAppId().isEmpty() || configuration().facebookAccessToken().isEmpty())
+            if (configuration().facebookAppId().isEmpty() || configuration().facebookAccessToken().isEmpty()) {
                 supportedMechanisms.removeAll("X-FACEBOOK-PLATFORM");
-            if (configuration().windowsLiveAccessToken().isEmpty())
+            }
+            if (configuration().windowsLiveAccessToken().isEmpty()) {
                 supportedMechanisms.removeAll("X-MESSENGER-OAUTH2");
-            if (configuration().googleAccessToken().isEmpty())
+            }
+            if (configuration().googleAccessToken().isEmpty()) {
                 supportedMechanisms.removeAll("X-OAUTH2");
+            }
 
             // determine SASL Authentication mechanism to use
             QStringList commonMechanisms;
             QString usedMechanism;
-            for (const auto &mechanism : qAsConst(supportedMechanisms)) {
-                if (features.authMechanisms().contains(mechanism))
+            for (const auto &mechanism : std::as_const(supportedMechanisms)) {
+                if (features.authMechanisms().contains(mechanism)) {
                     commonMechanisms << mechanism;
+                }
             }
             if (commonMechanisms.isEmpty()) {
                 warning("No supported SASL Authentication mechanism available");
@@ -510,7 +527,7 @@ void QXmppOutgoingClient::handleStanza(const QDomElement &nodeRecv)
         d->bindModeAvailable = (features.bindMode() != QXmppStreamFeatures::Disabled);
         d->streamManagementAvailable = (features.streamManagementMode() != QXmppStreamFeatures::Disabled);
 
-        // chech whether the stream can be resumed
+        // check whether the stream can be resumed
         if (d->streamManagementAvailable && d->canResume) {
             d->isResuming = true;
             QXmppStreamManagementResume streamManagementResume(lastIncomingSequenceNumber(), d->smId);
@@ -535,7 +552,7 @@ void QXmppOutgoingClient::handleStanza(const QDomElement &nodeRecv)
 
         // otherwise we are done
         d->sessionStarted = true;
-        emit connected();
+        Q_EMIT connected();
     } else if (ns == ns_stream && nodeRecv.tagName() == "error") {
         // handle redirects
         const auto otherHost = nodeRecv.firstChildElement("see-other-host");
@@ -544,13 +561,14 @@ void QXmppOutgoingClient::handleStanza(const QDomElement &nodeRecv)
             return;
         }
 
-        if (!nodeRecv.firstChildElement("conflict").isNull())
+        if (!nodeRecv.firstChildElement("conflict").isNull()) {
             d->xmppStreamError = QXmppStanza::Error::Conflict;
-        else if (!nodeRecv.firstChildElement("not-authorized").isNull())
+        } else if (!nodeRecv.firstChildElement("not-authorized").isNull()) {
             d->xmppStreamError = QXmppStanza::Error::NotAuthorized;
-        else
+        } else {
             d->xmppStreamError = QXmppStanza::Error::UndefinedCondition;
-        emit error(QXmppClient::XmppStreamError);
+        }
+        Q_EMIT error(QXmppClient::XmppStreamError);
     } else if (ns == ns_sasl) {
         if (!d->saslClient) {
             warning("SASL stanza received, but no mechanism selected");
@@ -578,11 +596,12 @@ void QXmppOutgoingClient::handleStanza(const QDomElement &nodeRecv)
             // RFC3920 defines the error condition as "not-authorized", but
             // some broken servers use "bad-auth" instead. We tolerate this
             // by remapping the error to "not-authorized".
-            if (failure.condition() == "not-authorized" || failure.condition() == "bad-auth")
+            if (failure.condition() == "not-authorized" || failure.condition() == "bad-auth") {
                 d->xmppStreamError = QXmppStanza::Error::NotAuthorized;
-            else
+            } else {
                 d->xmppStreamError = QXmppStanza::Error::UndefinedCondition;
-            emit error(QXmppClient::XmppStreamError);
+            }
+            Q_EMIT error(QXmppClient::XmppStreamError);
 
             warning("Authentication failure");
             disconnectFromHost();
@@ -593,8 +612,9 @@ void QXmppOutgoingClient::handleStanza(const QDomElement &nodeRecv)
             QDomElement element = nodeRecv.firstChildElement();
             QString id = nodeRecv.attribute("id");
             QString type = nodeRecv.attribute("type");
-            if (type.isEmpty())
+            if (type.isEmpty()) {
                 warning("QXmppStream: iq type can't be empty");
+            }
 
             if (id == d->sessionId) {
                 QXmppSessionIq session;
@@ -605,7 +625,7 @@ void QXmppOutgoingClient::handleStanza(const QDomElement &nodeRecv)
                     d->sendStreamManagementEnable();
                 } else {
                     // we are connected now
-                    emit connected();
+                    Q_EMIT connected();
                 }
             } else if (QXmppBindIq::isBindIq(nodeRecv) && id == d->bindId) {
                 QXmppBindIq bind;
@@ -634,12 +654,12 @@ void QXmppOutgoingClient::handleStanza(const QDomElement &nodeRecv)
                             d->sendStreamManagementEnable();
                         } else {
                             // we are connected now
-                            emit connected();
+                            Q_EMIT connected();
                         }
                     }
                 } else if (bind.type() == QXmppIq::Error) {
                     d->xmppStreamError = bind.error().condition();
-                    emit error(QXmppClient::XmppStreamError);
+                    Q_EMIT error(QXmppClient::XmppStreamError);
                     warning("Resource binding error received: " + bind.error().text());
                     disconnectFromHost();
                 }
@@ -654,7 +674,7 @@ void QXmppOutgoingClient::handleStanza(const QDomElement &nodeRecv)
 
                 // xmpp connection made
                 d->sessionStarted = true;
-                emit connected();
+                Q_EMIT connected();
             } else if (QXmppNonSASLAuthIq::isNonSASLAuthIq(nodeRecv)) {
                 if (type == "result") {
                     bool digest = !nodeRecv.firstChildElement("query").firstChildElement("digest").isNull();
@@ -663,15 +683,16 @@ void QXmppOutgoingClient::handleStanza(const QDomElement &nodeRecv)
 
                     if (plain && digest) {
                         if (configuration().nonSASLAuthMechanism() ==
-                            QXmppConfiguration::NonSASLDigest)
+                            QXmppConfiguration::NonSASLDigest) {
                             plainText = false;
-                        else
+                        } else {
                             plainText = true;
-                    } else if (plain)
+                        }
+                    } else if (plain) {
                         plainText = true;
-                    else if (digest)
+                    } else if (digest) {
                         plainText = false;
-                    else {
+                    } else {
                         warning("No supported Non-SASL Authentication mechanism available");
                         disconnectFromHost();
                         return;
@@ -703,7 +724,7 @@ void QXmppOutgoingClient::handleStanza(const QDomElement &nodeRecv)
                     iq.setError(error);
                     sendPacket(iq);
                 } else {
-                    emit iqReceived(iqPacket);
+                    Q_EMIT iqReceived(iqPacket);
                 }
             }
         } else if (nodeRecv.tagName() == "presence") {
@@ -711,13 +732,13 @@ void QXmppOutgoingClient::handleStanza(const QDomElement &nodeRecv)
             presence.parse(nodeRecv);
 
             // emit presence
-            emit presenceReceived(presence);
+            Q_EMIT presenceReceived(presence);
         } else if (nodeRecv.tagName() == "message") {
             QXmppMessage message;
             message.parse(nodeRecv);
 
             // emit message
-            emit messageReceived(message);
+            Q_EMIT messageReceived(message);
         }
     } else if (QXmppStreamManagementEnabled::isStreamManagementEnabled(nodeRecv)) {
         QXmppStreamManagementEnabled streamManagementEnabled;
@@ -731,7 +752,7 @@ void QXmppOutgoingClient::handleStanza(const QDomElement &nodeRecv)
         d->streamManagementEnabled = true;
         enableStreamManagement(true);
         // we are connected now
-        emit connected();
+        Q_EMIT connected();
     } else if (QXmppStreamManagementResumed::isStreamManagementResumed(nodeRecv)) {
         QXmppStreamManagementResumed streamManagementResumed;
         streamManagementResumed.parse(nodeRecv);
@@ -743,7 +764,7 @@ void QXmppOutgoingClient::handleStanza(const QDomElement &nodeRecv)
         enableStreamManagement(false);
         // we are connected now
         // TODO: The stream was resumed. Therefore, we should not send presence information or request the roster.
-        emit connected();
+        Q_EMIT connected();
     } else if (QXmppStreamManagementFailed::isStreamManagementFailed(nodeRecv)) {
         if (d->isResuming) {
             // resuming failed. We can try to bind a resource now.
@@ -763,10 +784,10 @@ void QXmppOutgoingClient::handleStanza(const QDomElement &nodeRecv)
 
             // otherwise we are done
             d->sessionStarted = true;
-            emit connected();
+            Q_EMIT connected();
         } else {
             // we are connected now, but stream management is disabled
-            emit connected();
+            Q_EMIT connected();
         }
     }
 }
@@ -808,7 +829,7 @@ void QXmppOutgoingClient::pingTimeout()
 {
     warning("Ping timeout");
     QXmppStream::disconnectFromHost();
-    emit error(QXmppClient::KeepAliveError);
+    Q_EMIT error(QXmppClient::KeepAliveError);
 }
 
 bool QXmppOutgoingClient::setResumeAddress(const QString &address)
@@ -844,10 +865,11 @@ void QXmppOutgoingClientPrivate::sendNonSASLAuth(bool plainText)
     QXmppNonSASLAuthIq authQuery;
     authQuery.setType(QXmppIq::Set);
     authQuery.setUsername(q->configuration().user());
-    if (plainText)
+    if (plainText) {
         authQuery.setPassword(q->configuration().password());
-    else
+    } else {
         authQuery.setDigest(streamId, q->configuration().password());
+    }
     authQuery.setResource(q->configuration().resource());
     nonSASLAuthId = authQuery.id();
     q->sendPacket(authQuery);
