@@ -1,26 +1,7 @@
-/*
- * Copyright (C) 2008-2021 The QXmpp developers
- *
- * Author:
- *  Melvin Keskin
- *  Linus Jahn
- *
- * Source:
- *  https://github.com/qxmpp-project/qxmpp
- *
- * This file is a part of QXmpp library.
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- */
+// SPDX-FileCopyrightText: 2020 Melvin Keskin <melvo@olomono.de>
+// SPDX-FileCopyrightText: 2019 Linus Jahn <lnj@kaidan.im>
+//
+// SPDX-License-Identifier: LGPL-2.1-or-later
 
 #include "QXmppRegistrationManager.h"
 
@@ -63,7 +44,7 @@ QXmppRegistrationManagerPrivate::QXmppRegistrationManagerPrivate()
 /// Default constructor.
 ///
 QXmppRegistrationManager::QXmppRegistrationManager()
-    : d(new QXmppRegistrationManagerPrivate)
+    : d(std::make_unique<QXmppRegistrationManagerPrivate>())
 {
 }
 
@@ -158,8 +139,10 @@ void QXmppRegistrationManager::setRegistrationFormToSend(const QXmppDataForm &da
 ///
 void QXmppRegistrationManager::sendCachedRegistrationForm()
 {
-    if (!d->registrationFormToSend.form().isNull())
-        d->registrationFormToSend.form().setType(QXmppDataForm::Submit);
+    if (auto form = d->registrationFormToSend.form(); !form.isNull()) {
+        form.setType(QXmppDataForm::Submit);
+        d->registrationFormToSend.setForm(form);
+    }
 
     d->registrationFormToSend.setType(QXmppIq::Set);
 
@@ -200,9 +183,9 @@ bool QXmppRegistrationManager::handleStanza(const QDomElement &stanza)
         if (features.registerMode() == QXmppStreamFeatures::Disabled) {
             warning(QStringLiteral("Could not request the registration form, because the server does not advertise the register stream feature."));
             client()->disconnectFromServer();
-            emit registrationFailed({ QXmppStanza::Error::Cancel,
-                                      QXmppStanza::Error::FeatureNotImplemented,
-                                      QStringLiteral("The server does not advertise the register stream feature.") });
+            Q_EMIT registrationFailed({ QXmppStanza::Error::Cancel,
+                                        QXmppStanza::Error::FeatureNotImplemented,
+                                        QStringLiteral("The server does not advertise the register stream feature.") });
             return true;
         }
 
@@ -227,11 +210,11 @@ bool QXmppRegistrationManager::handleStanza(const QDomElement &stanza)
             switch (iq.type()) {
             case QXmppIq::Result:
                 info(QStringLiteral("Successfully registered with the service."));
-                emit registrationSucceeded();
+                Q_EMIT registrationSucceeded();
                 break;
             case QXmppIq::Error:
                 warning(QStringLiteral("Registering with the service failed: ").append(iq.error().text()));
-                emit registrationFailed(iq.error());
+                Q_EMIT registrationFailed(iq.error());
                 break;
             default:
                 break;  // should never occur
@@ -247,11 +230,11 @@ bool QXmppRegistrationManager::handleStanza(const QDomElement &stanza)
             case QXmppIq::Result:
                 info(QStringLiteral("Changed password successfully."));
                 client()->configuration().setPassword(d->newPassword);
-                emit passwordChanged(d->newPassword);
+                Q_EMIT passwordChanged(d->newPassword);
                 break;
             case QXmppIq::Error:
                 warning(QStringLiteral("Failed to change password: ").append(iq.error().text()));
-                emit passwordChangeFailed(iq.error());
+                Q_EMIT passwordChangeFailed(iq.error());
                 break;
             default:
                 break;  // should never occur
@@ -267,12 +250,12 @@ bool QXmppRegistrationManager::handleStanza(const QDomElement &stanza)
             switch (iq.type()) {
             case QXmppIq::Result:
                 info(QStringLiteral("Account deleted successfully."));
-                emit accountDeleted();
+                Q_EMIT accountDeleted();
                 client()->disconnectFromServer();
                 break;
             case QXmppIq::Error:
                 warning(QStringLiteral("Failed to delete account: ").append(iq.error().text()));
-                emit accountDeletionFailed(iq.error());
+                Q_EMIT accountDeletionFailed(iq.error());
                 break;
             default:
                 break;  // should never occur
@@ -284,7 +267,7 @@ bool QXmppRegistrationManager::handleStanza(const QDomElement &stanza)
             QXmppRegisterIq iq;
             iq.parse(stanza);
 
-            emit registrationFormReceived(iq);
+            Q_EMIT registrationFormReceived(iq);
         }
     }
     return false;
@@ -300,7 +283,7 @@ void QXmppRegistrationManager::setClient(QXmppClient *client)
         connect(disco, &QXmppDiscoveryManager::infoReceived, this, &QXmppRegistrationManager::handleDiscoInfo);
     }
 
-    connect(client, &QXmppClient::disconnected, [=]() {
+    connect(client, &QXmppClient::disconnected, this, [this]() {
         setSupportedByServer(false);
     });
 }
@@ -309,8 +292,9 @@ void QXmppRegistrationManager::handleDiscoInfo(const QXmppDiscoveryIq &iq)
 {
     // check features of own server
     if (iq.from().isEmpty() || iq.from() == client()->configuration().domain()) {
-        if (iq.features().contains(ns_register))
+        if (iq.features().contains(ns_register)) {
             setSupportedByServer(true);
+        }
     }
 }
 
@@ -318,6 +302,6 @@ void QXmppRegistrationManager::setSupportedByServer(bool registrationSupported)
 {
     if (d->supportedByServer != registrationSupported) {
         d->supportedByServer = registrationSupported;
-        emit supportedByServerChanged();
+        Q_EMIT supportedByServerChanged();
     }
 }
