@@ -1,26 +1,7 @@
-/*
- * Copyright (C) 2008-2021 The QXmpp developers
- *
- * Author:
- *  Melvin Keskin
- *  Linus Jahn
- *
- * Source:
- *  https://github.com/qxmpp-project/qxmpp
- *
- * This file is a part of QXmpp library.
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- */
+// SPDX-FileCopyrightText: 2019 Melvin Keskin <melvo@olomono.de>
+// SPDX-FileCopyrightText: 2019 Linus Jahn <lnj@kaidan.im>
+//
+// SPDX-License-Identifier: LGPL-2.1-or-later
 
 #ifndef QXMPPREGISTRATIONMANAGER_H
 #define QXMPPREGISTRATIONMANAGER_H
@@ -28,8 +9,6 @@
 #include "QXmppClientExtension.h"
 #include "QXmppRegisterIq.h"
 
-#include <QScopedPointer>
-
 class QXmppRegistrationManagerPrivate;
 
 ///
@@ -367,7 +346,7 @@ private Q_SLOTS:
 private:
     void setSupportedByServer(bool supportedByServer);
 
-    QScopedPointer<QXmppRegistrationManagerPrivate> d;
+    const std::unique_ptr<QXmppRegistrationManagerPrivate> d;
 };
 
 #endif  // QXMPPREGISTRATIONMANAGER_H
