@@ -1,36 +1,38 @@
-/*
- * Copyright (C) 2008-2021 The QXmpp developers
- *
- * Authors:
- *  Manjeet Dahiya
- *  Jeremy Lainé
- *
- * Source:
- *  https://github.com/qxmpp-project/qxmpp
- *
- * This file is a part of QXmpp library.
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- */
+// SPDX-FileCopyrightText: 2010 Manjeet Dahiya <manjeetdahiya@gmail.com>
+// SPDX-FileCopyrightText: 2010 Jeremy Lainé <jeremy.laine@m4x.org>
+// SPDX-FileCopyrightText: 2020 Melvin Keskin <melvo@olomono.de>
+//
+// SPDX-License-Identifier: LGPL-2.1-or-later
 
 #include "QXmppRosterManager.h"
 
 #include "QXmppClient.h"
+#include "QXmppFutureUtils_p.h"
 #include "QXmppPresence.h"
 #include "QXmppRosterIq.h"
 #include "QXmppUtils.h"
 
 #include <QDomElement>
 
+using namespace QXmpp::Private;
+
+///
+/// \fn QXmppRosterManager::subscriptionRequestReceived
+///
+/// This signal is emitted when a JID asks to subscribe to the user's presence.
+///
+/// The user can either accept the request by calling acceptSubscription() or refuse it
+/// by calling refuseSubscription().
+///
+/// \note If QXmppConfiguration::autoAcceptSubscriptions() is set to true, this
+/// signal will not be emitted.
+///
+/// \param subscriberBareJid bare JID that wants to subscribe to the user's presence
+/// \param presence presence stanza containing the reason / message (presence.statusText())
+///
+/// \since QXmpp 1.5
+///
+
 class QXmppRosterManagerPrivate
 {
 public:
@@ -68,7 +70,7 @@ void QXmppRosterManagerPrivate::clear()
 /// Constructs a roster manager.
 ///
 QXmppRosterManager::QXmppRosterManager(QXmppClient *client)
-    : d(new QXmppRosterManagerPrivate())
+    : d(std::make_unique<QXmppRosterManagerPrivate>())
 {
     connect(client, &QXmppClient::connected,
             this, &QXmppRosterManager::_q_connected);
@@ -80,10 +82,7 @@ QXmppRosterManager::QXmppRosterManager(QXmppClient *client)
             this, &QXmppRosterManager::_q_presenceReceived);
 }
 
-QXmppRosterManager::~QXmppRosterManager()
-{
-    delete d;
-}
+QXmppRosterManager::~QXmppRosterManager() = default;
 
 ///
 /// Accepts an existing subscription request or pre-approves future subscription
@@ -126,8 +125,9 @@ void QXmppRosterManager::_q_connected()
         roster.setMixAnnotate(true);
 
         d->rosterReqId = roster.id();
-        if (client()->isAuthenticated())
+        if (client()->isAuthenticated()) {
             client()->sendPacket(roster);
+        }
     }
 }
 
@@ -142,21 +142,24 @@ void QXmppRosterManager::_q_disconnected()
 /// \cond
 bool QXmppRosterManager::handleStanza(const QDomElement &element)
 {
-    if (element.tagName() != "iq" || !QXmppRosterIq::isRosterIq(element))
+    if (element.tagName() != "iq" || !QXmppRosterIq::isRosterIq(element)) {
         return false;
+    }
 
     // Security check: only server should send this iq
     // from() should be either empty or bareJid of the user
     const auto fromJid = element.attribute("from");
-    if (!fromJid.isEmpty() && QXmppUtils::jidToBareJid(fromJid) != client()->configuration().jidBare())
+    if (!fromJid.isEmpty() && QXmppUtils::jidToBareJid(fromJid) != client()->configuration().jidBare()) {
         return false;
+    }
 
     QXmppRosterIq rosterIq;
     rosterIq.parse(element);
 
     bool isInitial = (d->rosterReqId == rosterIq.id());
-    if (isInitial)
+    if (isInitial) {
         d->rosterReqId.clear();
+    }
 
     switch (rosterIq.type()) {
     case QXmppIq::Set: {
@@ -172,17 +175,17 @@ bool QXmppRosterManager::handleStanza(const QDomElement &element)
             if (item.subscriptionType() == QXmppRosterIq::Item::Remove) {
                 if (d->entries.remove(bareJid)) {
                     // notify the user that the item was removed
-                    emit itemRemoved(bareJid);
+                    Q_EMIT itemRemoved(bareJid);
                 }
             } else {
                 const bool added = !d->entries.contains(bareJid);
                 d->entries.insert(bareJid, item);
                 if (added) {
                     // notify the user that the item was added
-                    emit itemAdded(bareJid);
+                    Q_EMIT itemAdded(bareJid);
                 } else {
                     // notify the user that the item changed
-                    emit itemChanged(bareJid);
+                    Q_EMIT itemChanged(bareJid);
                 }
             }
         }
@@ -195,7 +198,7 @@ bool QXmppRosterManager::handleStanza(const QDomElement &element)
         }
         if (isInitial) {
             d->isRosterReceived = true;
-            emit rosterReceived();
+            Q_EMIT rosterReceived();
         }
         break;
     }
@@ -213,17 +216,18 @@ void QXmppRosterManager::_q_presenceReceived(const QXmppPresence &presence)
     const auto bareJid = QXmppUtils::jidToBareJid(jid);
     const auto resource = QXmppUtils::jidToResource(jid);
 
-    if (bareJid.isEmpty())
+    if (bareJid.isEmpty()) {
         return;
+    }
 
     switch (presence.type()) {
     case QXmppPresence::Available:
         d->presences[bareJid][resource] = presence;
-        emit presenceChanged(bareJid, resource);
+        Q_EMIT presenceChanged(bareJid, resource);
         break;
     case QXmppPresence::Unavailable:
         d->presences[bareJid].remove(resource);
-        emit presenceChanged(bareJid, resource);
+        Q_EMIT presenceChanged(bareJid, resource);
         break;
     case QXmppPresence::Subscribe:
         if (client()->configuration().autoAcceptSubscriptions()) {
@@ -233,7 +237,8 @@ void QXmppRosterManager::_q_presenceReceived(const QXmppPresence &presence)
             // ask for reciprocal subscription
             subscribe(bareJid);
         } else {
-            emit subscriptionReceived(bareJid);
+            Q_EMIT subscriptionReceived(bareJid);
+            Q_EMIT subscriptionRequestReceived(bareJid, presence);
         }
         break;
     default:
@@ -241,6 +246,121 @@ void QXmppRosterManager::_q_presenceReceived(const QXmppPresence &presence)
     }
 }
 
+///
+/// Adds a new item to the roster without sending any subscription requests.
+///
+/// As a result, the server will initiate a roster push, causing the
+/// itemAdded() or itemChanged() signal to be emitted.
+///
+/// \param bareJid
+/// \param name Optional name for the item.
+/// \param groups Optional groups for the item.
+///
+/// \since QXmpp 1.5
+///
+QXmppTask<QXmppRosterManager::Result> QXmppRosterManager::addRosterItem(const QString &bareJid, const QString &name, const QSet<QString> &groups)
+{
+    QXmppRosterIq::Item item;
+    item.setBareJid(bareJid);
+    item.setName(name);
+    item.setGroups(groups);
+    item.setSubscriptionType(QXmppRosterIq::Item::NotSet);
+
+    QXmppRosterIq iq;
+    iq.setType(QXmppIq::Set);
+    iq.addItem(item);
+    return client()->sendGenericIq(std::move(iq));
+}
+
+///
+/// Removes a roster item and cancels subscriptions to and from the contact.
+///
+/// As a result, the server will initiate a roster push, causing the
+/// itemRemoved() signal to be emitted.
+///
+/// \param bareJid
+///
+/// \since QXmpp 1.5
+///
+QXmppTask<QXmppRosterManager::Result> QXmppRosterManager::removeRosterItem(const QString &bareJid)
+{
+    QXmppRosterIq::Item item;
+    item.setBareJid(bareJid);
+    item.setSubscriptionType(QXmppRosterIq::Item::Remove);
+
+    QXmppRosterIq iq;
+    iq.setType(QXmppIq::Set);
+    iq.addItem(item);
+    return client()->sendGenericIq(std::move(iq));
+}
+
+///
+/// Renames a roster item.
+///
+/// As a result, the server will initiate a roster push, causing the
+/// itemChanged() signal to be emitted.
+///
+/// \param bareJid
+/// \param name
+///
+/// \since QXmpp 1.5
+///
+QXmppTask<QXmppRosterManager::Result> QXmppRosterManager::renameRosterItem(const QString &bareJid, const QString &name)
+{
+    using Error = QXmppStanza::Error;
+    if (!d->entries.contains(bareJid)) {
+        return makeReadyTask<Result>(
+            QXmppError { QStringLiteral("The roster doesn't contain this user."), {} });
+    }
+
+    auto item = d->entries.value(bareJid);
+    item.setName(name);
+
+    // If there is a pending subscription, do not include the corresponding attribute in the stanza.
+    if (!item.subscriptionStatus().isEmpty()) {
+        item.setSubscriptionStatus({});
+    }
+
+    QXmppRosterIq iq;
+    iq.setType(QXmppIq::Set);
+    iq.addItem(item);
+    return client()->sendGenericIq(std::move(iq));
+}
+
+///
+/// Requests a subscription to the given contact.
+///
+/// As a result, the server will initiate a roster push, causing the
+/// itemAdded() or itemChanged() signal to be emitted.
+///
+/// \since QXmpp 1.5
+///
+QXmppTask<QXmpp::SendResult> QXmppRosterManager::subscribeTo(const QString &bareJid, const QString &reason)
+{
+    QXmppPresence packet;
+    packet.setTo(QXmppUtils::jidToBareJid(bareJid));
+    packet.setType(QXmppPresence::Subscribe);
+    packet.setStatusText(reason);
+    return client()->sendSensitive(std::move(packet));
+}
+
+///
+/// Removes a subscription to the given contact.
+///
+/// As a result, the server will initiate a roster push, causing the
+/// itemChanged() signal to be emitted.
+///
+/// \since QXmpp 1.5
+///
+QXmppTask<QXmpp::SendResult> QXmppRosterManager::unsubscribeFrom(const QString &bareJid, const QString &reason)
+{
+    QXmppPresence packet;
+    packet.setTo(QXmppUtils::jidToBareJid(bareJid));
+    packet.setType(QXmppPresence::Unsubscribe);
+    packet.setStatusText(reason);
+    return client()->sendSensitive(std::move(packet));
+}
+
 ///
 /// Refuses a subscription request.
 ///
@@ -256,13 +376,13 @@ bool QXmppRosterManager::refuseSubscription(const QString &bareJid, const QStrin
 }
 
 ///
-/// Adds a new item to the roster without sending any subscription requests.
+/// Adds a new item  the roster without sending any subscription requests.
 ///
 /// As a result, the server will initiate a roster push, causing the
 /// itemAdded() or itemChanged() signal to be emitted.
 ///
 /// \param bareJid
-/// \param name Optional name for the item.
+/// \param name Optotional name for the item.
 /// \param groups Optional groups for the item.
 ///
 bool QXmppRosterManager::addItem(const QString &bareJid, const QString &name, const QSet<QString> &groups)
@@ -310,15 +430,17 @@ bool QXmppRosterManager::removeItem(const QString &bareJid)
 ///
 bool QXmppRosterManager::renameItem(const QString &bareJid, const QString &name)
 {
-    if (!d->entries.contains(bareJid))
+    if (!d->entries.contains(bareJid)) {
         return false;
+    }
 
     auto item = d->entries.value(bareJid);
     item.setName(name);
 
     // If there is a pending subscription, do not include the corresponding attribute in the stanza.
-    if (!item.subscriptionStatus().isEmpty())
+    if (!item.subscriptionStatus().isEmpty()) {
         item.setSubscriptionStatus({});
+    }
 
     QXmppRosterIq iq;
     iq.setType(QXmppIq::Set);
@@ -376,8 +498,9 @@ QXmppRosterIq::Item QXmppRosterManager::getRosterEntry(
     const QString &bareJid) const
 {
     // will return blank entry if bareJid doesn't exist
-    if (d->entries.contains(bareJid))
+    if (d->entries.contains(bareJid)) {
         return d->entries.value(bareJid);
+    }
     return {};
 }
 
@@ -389,8 +512,9 @@ QXmppRosterIq::Item QXmppRosterManager::getRosterEntry(
 ///
 QStringList QXmppRosterManager::getResources(const QString &bareJid) const
 {
-    if (d->presences.contains(bareJid))
+    if (d->presences.contains(bareJid)) {
         return d->presences[bareJid].keys();
+    }
     return {};
 }
 
@@ -405,8 +529,9 @@ QStringList QXmppRosterManager::getResources(const QString &bareJid) const
 QMap<QString, QXmppPresence> QXmppRosterManager::getAllPresencesForBareJid(
     const QString &bareJid) const
 {
-    if (d->presences.contains(bareJid))
+    if (d->presences.contains(bareJid)) {
         return d->presences.value(bareJid);
+    }
     return {};
 }
 
