@@ -1,25 +1,6 @@
-/*
- * Copyright (C) 2008-2021 The QXmpp developers
- *
- * Author:
- *  Jeremy Lainé
- *
- * Source:
- *  https://github.com/qxmpp-project/qxmpp
- *
- * This file is a part of QXmpp library.
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- */
+// SPDX-FileCopyrightText: 2010 Jeremy Lainé <jeremy.laine@m4x.org>
+//
+// SPDX-License-Identifier: LGPL-2.1-or-later
 
 #include "QXmppTransferManager.h"
 
@@ -60,95 +41,124 @@ static QString streamHash(const QString &sid, const QString &initiatorJid, const
 class QXmppTransferFileInfoPrivate : public QSharedData
 {
 public:
-    QXmppTransferFileInfoPrivate();
-
     QDateTime date;
     QByteArray hash;
     QString name;
     QString description;
-    qint64 size;
+    qint64 size = 0;
 };
 
-QXmppTransferFileInfoPrivate::QXmppTransferFileInfoPrivate()
-    : size(0)
-{
-}
+///
+/// \class QXmppTransferFileInfo
+///
+/// Contains information about a file that is transferred using QXmppTransferJob.
+///
 
 QXmppTransferFileInfo::QXmppTransferFileInfo()
     : d(new QXmppTransferFileInfoPrivate)
 {
 }
 
-QXmppTransferFileInfo::QXmppTransferFileInfo(const QXmppTransferFileInfo &other)
-    : d(other.d)
-{
-}
+/// Default copy-constructor
+QXmppTransferFileInfo::QXmppTransferFileInfo(const QXmppTransferFileInfo &other) = default;
 
-QXmppTransferFileInfo::~QXmppTransferFileInfo()
-{
-}
+QXmppTransferFileInfo::~QXmppTransferFileInfo() = default;
 
+///
+/// Returns the last modification timestamp of the file.
+///
 QDateTime QXmppTransferFileInfo::date() const
 {
     return d->date;
 }
 
+///
+/// Sets the last modification timestamp of the file.
+///
 void QXmppTransferFileInfo::setDate(const QDateTime &date)
 {
     d->date = date;
 }
 
+///
+/// Returns the checksum of the file.
+///
 QByteArray QXmppTransferFileInfo::hash() const
 {
     return d->hash;
 }
 
+///
+/// Sets the checksum of the file.
+///
 void QXmppTransferFileInfo::setHash(const QByteArray &hash)
 {
     d->hash = hash;
 }
 
+///
+/// Returns the name of the file.
+///
 QString QXmppTransferFileInfo::name() const
 {
     return d->name;
 }
 
+///
+/// Sets the name of the file.
+///
 void QXmppTransferFileInfo::setName(const QString &name)
 {
     d->name = name;
 }
 
+///
+/// Returns a description of the file.
+///
 QString QXmppTransferFileInfo::description() const
 {
     return d->description;
 }
 
+///
+/// Sets a description of the file.
+///
 void QXmppTransferFileInfo::setDescription(const QString &description)
 {
     d->description = description;
 }
 
+///
+/// Returns the size of the file in bytes.
+///
 qint64 QXmppTransferFileInfo::size() const
 {
     return d->size;
 }
 
+///
+/// Sets the size of the file in bytes.
+///
 void QXmppTransferFileInfo::setSize(qint64 size)
 {
     d->size = size;
 }
 
+///
+/// Returns true if the file info has no valid data set.
+///
 bool QXmppTransferFileInfo::isNull() const
 {
     return d->date.isNull() && d->description.isEmpty() && d->hash.isEmpty() && d->name.isEmpty() && d->size == 0;
 }
 
-QXmppTransferFileInfo &QXmppTransferFileInfo::operator=(const QXmppTransferFileInfo &other)
-{
-    d = other.d;
-    return *this;
-}
+/// Default assignment operator
+QXmppTransferFileInfo &QXmppTransferFileInfo::operator=(const QXmppTransferFileInfo &other) = default;
 
+///
+/// Returns true if the content (size, hash and name) of the file info objects
+/// equals.
+///
 bool QXmppTransferFileInfo::operator==(const QXmppTransferFileInfo &other) const
 {
     return other.d->size == d->size &&
@@ -156,6 +166,7 @@ bool QXmppTransferFileInfo::operator==(const QXmppTransferFileInfo &other) const
         other.d->name == d->name;
 }
 
+/// \cond
 void QXmppTransferFileInfo::parse(const QDomElement &element)
 {
     d->date = QXmppUtils::datetimeFromString(element.attribute("date"));
@@ -169,18 +180,24 @@ void QXmppTransferFileInfo::toXml(QXmlStreamWriter *writer) const
 {
     writer->writeStartElement("file");
     writer->writeDefaultNamespace(ns_stream_initiation_file_transfer);
-    if (d->date.isValid())
+    if (d->date.isValid()) {
         writer->writeAttribute("date", QXmppUtils::datetimeToString(d->date));
-    if (!d->hash.isEmpty())
+    }
+    if (!d->hash.isEmpty()) {
         writer->writeAttribute("hash", d->hash.toHex());
-    if (!d->name.isEmpty())
+    }
+    if (!d->name.isEmpty()) {
         writer->writeAttribute("name", d->name);
-    if (d->size > 0)
+    }
+    if (d->size > 0) {
         writer->writeAttribute("size", QString::number(d->size));
-    if (!d->description.isEmpty())
+    }
+    if (!d->description.isEmpty()) {
         writer->writeTextElement("desc", d->description);
+    }
     writer->writeEndElement();
 }
+/// \endcond
 
 class QXmppTransferJobPrivate
 {
@@ -232,31 +249,36 @@ QXmppTransferJobPrivate::QXmppTransferJobPrivate()
 {
 }
 
+///
+/// \class QXmppTransferJob
+///
+/// The QXmppTransferJob class represents a single file transfer job.
+///
+/// \sa QXmppTransferManager
+///
+
 QXmppTransferJob::QXmppTransferJob(const QString &jid, QXmppTransferJob::Direction direction, QXmppClient *client, QObject *parent)
     : QXmppLoggable(parent),
-      d(new QXmppTransferJobPrivate)
+      d(std::make_unique<QXmppTransferJobPrivate>())
 {
     d->client = client;
     d->direction = direction;
     d->jid = jid;
 }
 
-QXmppTransferJob::~QXmppTransferJob()
-{
-    delete d;
-}
+QXmppTransferJob::~QXmppTransferJob() = default;
 
+///
 /// Call this method if you wish to abort on ongoing transfer job.
 ///
-
 void QXmppTransferJob::abort()
 {
     terminate(AbortError);
 }
 
+///
 /// Call this method if you wish to accept an incoming transfer job.
 ///
-
 void QXmppTransferJob::accept(const QString &filePath)
 {
     if (d->direction == IncomingDirection && d->state == OfferState && !d->iodevice) {
@@ -273,9 +295,9 @@ void QXmppTransferJob::accept(const QString &filePath)
     }
 }
 
+///
 /// Call this method if you wish to accept an incoming transfer job.
 ///
-
 void QXmppTransferJob::accept(QIODevice *iodevice)
 {
     if (d->direction == IncomingDirection && d->state == OfferState && !d->iodevice) {
@@ -307,22 +329,23 @@ QUrl QXmppTransferJob::localFileUrl() const
     return d->localFileUrl;
 }
 
+///
 /// Sets the local file URL.
 ///
 /// \note You do not need to call this method if you called accept()
 ///  with a file path.
-
+///
 void QXmppTransferJob::setLocalFileUrl(const QUrl &localFileUrl)
 {
     if (localFileUrl != d->localFileUrl) {
         d->localFileUrl = localFileUrl;
-        emit localFileUrlChanged(localFileUrl);
+        Q_EMIT localFileUrlChanged(localFileUrl);
     }
 }
 
+///
 /// Returns meta-data about the file being transferred.
 ///
-
 QXmppTransferFileInfo QXmppTransferJob::fileInfo() const
 {
     return d->fileInfo;
@@ -355,24 +378,25 @@ QXmppTransferJob::Method QXmppTransferJob::method() const
     return d->method;
 }
 
+///
 /// Returns the job's session identifier.
 ///
-
 QString QXmppTransferJob::sid() const
 {
     return d->sid;
 }
 
+///
 /// Returns the job's transfer speed in bytes per second.
 ///
 /// If the transfer has not started yet or is already finished, returns 0.
 ///
-
 qint64 QXmppTransferJob::speed() const
 {
     qint64 elapsed = d->transferStart.elapsed();
-    if (d->state != QXmppTransferJob::TransferState || !elapsed)
+    if (d->state != QXmppTransferJob::TransferState || !elapsed) {
         return 0;
+    }
     return (d->done * 1000.0) / elapsed;
 }
 
@@ -385,32 +409,36 @@ void QXmppTransferJob::setState(QXmppTransferJob::State state)
 {
     if (d->state != state) {
         d->state = state;
-        if (d->state == QXmppTransferJob::TransferState)
+        if (d->state == QXmppTransferJob::TransferState) {
             d->transferStart.start();
-        emit stateChanged(d->state);
+        }
+        Q_EMIT stateChanged(d->state);
     }
 }
 
 void QXmppTransferJob::_q_terminated()
 {
-    emit stateChanged(d->state);
-    if (d->error != NoError)
-        emit error(d->error);
-    emit finished();
+    Q_EMIT stateChanged(d->state);
+    if (d->error != NoError) {
+        Q_EMIT error(d->error);
+    }
+    Q_EMIT finished();
 }
 
 void QXmppTransferJob::terminate(QXmppTransferJob::Error cause)
 {
-    if (d->state == FinishedState)
+    if (d->state == FinishedState) {
         return;
+    }
 
     // change state
     d->error = cause;
     d->state = FinishedState;
 
     // close IO device
-    if (d->iodevice && d->deviceIsOwn)
+    if (d->iodevice && d->deviceIsOwn) {
         d->iodevice->close();
+    }
 
     // close socket
     if (d->socksSocket) {
@@ -419,22 +447,25 @@ void QXmppTransferJob::terminate(QXmppTransferJob::Error cause)
     }
 
     // emit signals later
-    QTimer::singleShot(0, this, SLOT(_q_terminated()));
+    QMetaObject::invokeMethod(this, "_q_terminated", Qt::QueuedConnection);
 }
 
 /// \cond
 QXmppTransferIncomingJob::QXmppTransferIncomingJob(const QString &jid, QXmppClient *client, QObject *parent)
-    : QXmppTransferJob(jid, IncomingDirection, client, parent), m_candidateClient(nullptr), m_candidateTimer(nullptr)
+    : QXmppTransferJob(jid, IncomingDirection, client, parent),
+      m_candidateClient(nullptr),
+      m_candidateTimer(nullptr)
 {
 }
 
 void QXmppTransferIncomingJob::checkData()
 {
     if ((d->fileInfo.size() && d->done != d->fileInfo.size()) ||
-        (!d->fileInfo.hash().isEmpty() && d->hash.result() != d->fileInfo.hash()))
+        (!d->fileInfo.hash().isEmpty() && d->hash.result() != d->fileInfo.hash())) {
         terminate(QXmppTransferJob::FileCorruptError);
-    else
+    } else {
         terminate(QXmppTransferJob::NoError);
+    }
 }
 
 void QXmppTransferIncomingJob::connectToNextHost()
@@ -480,7 +511,6 @@ void QXmppTransferIncomingJob::connectToNextHost()
 
 void QXmppTransferIncomingJob::connectToHosts(const QXmppByteStreamIq &iq)
 {
-
     m_streamCandidates = iq.streamHosts();
     m_streamOfferId = iq.id();
     m_streamOfferFrom = iq.from();
@@ -491,19 +521,22 @@ void QXmppTransferIncomingJob::connectToHosts(const QXmppByteStreamIq &iq)
 bool QXmppTransferIncomingJob::writeData(const QByteArray &data)
 {
     const qint64 written = d->iodevice->write(data);
-    if (written < 0)
+    if (written < 0) {
         return false;
+    }
     d->done += written;
-    if (!d->fileInfo.hash().isEmpty())
+    if (!d->fileInfo.hash().isEmpty()) {
         d->hash.addData(data);
-    progress(d->done, d->fileInfo.size());
+    }
+    Q_EMIT progress(d->done, d->fileInfo.size());
     return true;
 }
 
 void QXmppTransferIncomingJob::_q_candidateReady()
 {
-    if (!m_candidateClient)
+    if (!m_candidateClient) {
         return;
+    }
 
     info(QString("Connected to streamhost: %1 (%2 %3)").arg(m_candidateHost.jid(), m_candidateHost.host(), QString::number(m_candidateHost.port())));
 
@@ -527,8 +560,9 @@ void QXmppTransferIncomingJob::_q_candidateReady()
 
 void QXmppTransferIncomingJob::_q_candidateDisconnected()
 {
-    if (!m_candidateClient)
+    if (!m_candidateClient) {
         return;
+    }
 
     warning(QString("Failed to connect to streamhost: %1 (%2 %3)").arg(m_candidateHost.jid(), m_candidateHost.host(), QString::number(m_candidateHost.port())));
 
@@ -543,24 +577,27 @@ void QXmppTransferIncomingJob::_q_candidateDisconnected()
 
 void QXmppTransferIncomingJob::_q_disconnected()
 {
-    if (d->state == QXmppTransferJob::FinishedState)
+    if (d->state == QXmppTransferJob::FinishedState) {
         return;
+    }
 
     checkData();
 }
 
 void QXmppTransferIncomingJob::_q_receiveData()
 {
-    if (d->state != QXmppTransferJob::TransferState)
+    if (d->state != QXmppTransferJob::TransferState) {
         return;
+    }
 
     // receive data block
     if (d->direction == QXmppTransferJob::IncomingDirection) {
         writeData(d->socksSocket->readAll());
 
         // if we have received all the data, stop here
-        if (fileSize() && d->done >= fileSize())
+        if (fileSize() && d->done >= fileSize()) {
             checkData();
+        }
     }
 }
 
@@ -598,13 +635,15 @@ void QXmppTransferOutgoingJob::startSending()
 
 void QXmppTransferOutgoingJob::_q_disconnected()
 {
-    if (d->state == QXmppTransferJob::FinishedState)
+    if (d->state == QXmppTransferJob::FinishedState) {
         return;
+    }
 
-    if (fileSize() && d->done != fileSize())
+    if (fileSize() && d->done != fileSize()) {
         terminate(QXmppTransferJob::ProtocolError);
-    else
+    } else {
         terminate(QXmppTransferJob::NoError);
+    }
 }
 
 void QXmppTransferOutgoingJob::_q_proxyReady()
@@ -622,17 +661,20 @@ void QXmppTransferOutgoingJob::_q_proxyReady()
 
 void QXmppTransferOutgoingJob::_q_sendData()
 {
-    if (d->state != QXmppTransferJob::TransferState)
+    if (d->state != QXmppTransferJob::TransferState) {
         return;
+    }
 
     // don't saturate the outgoing socket
-    if (d->socksSocket->bytesToWrite() > 2 * d->blockSize)
+    if (d->socksSocket->bytesToWrite() > 2 * d->blockSize) {
         return;
+    }
 
     // check whether we have written the whole file
     if (d->fileInfo.size() && d->done >= d->fileInfo.size()) {
-        if (!d->socksSocket->bytesToWrite())
+        if (!d->socksSocket->bytesToWrite()) {
             terminate(QXmppTransferJob::NoError);
+        }
         return;
     }
 
@@ -646,7 +688,7 @@ void QXmppTransferOutgoingJob::_q_sendData()
         d->socksSocket->write(buffer, length);
         delete[] buffer;
         d->done += length;
-        emit progress(d->done, fileSize());
+        Q_EMIT progress(d->done, fileSize());
     }
 }
 /// \endcond
@@ -654,7 +696,7 @@ void QXmppTransferOutgoingJob::_q_sendData()
 class QXmppTransferManagerPrivate
 {
 public:
-    QXmppTransferManagerPrivate(QXmppTransferManager *qq);
+    QXmppTransferManagerPrivate();
 
     QXmppTransferIncomingJob *getIncomingJobByRequestId(const QString &jid, const QString &id);
     QXmppTransferIncomingJob *getIncomingJobBySid(const QString &jid, const QString &sid);
@@ -669,21 +711,24 @@ public:
 
 private:
     QXmppTransferJob *getJobByRequestId(QXmppTransferJob::Direction direction, const QString &jid, const QString &id);
-    QXmppTransferManager *q;
 };
 
-QXmppTransferManagerPrivate::QXmppTransferManagerPrivate(QXmppTransferManager *qq)
-    : ibbBlockSize(4096), proxyOnly(false), socksServer(nullptr), supportedMethods(QXmppTransferJob::AnyMethod), q(qq)
+QXmppTransferManagerPrivate::QXmppTransferManagerPrivate()
+    : ibbBlockSize(4096),
+      proxyOnly(false),
+      socksServer(nullptr),
+      supportedMethods(QXmppTransferJob::AnyMethod)
 {
 }
 
 QXmppTransferJob *QXmppTransferManagerPrivate::getJobByRequestId(QXmppTransferJob::Direction direction, const QString &jid, const QString &id)
 {
-    for (auto *job : jobs) {
+    for (auto *job : std::as_const(jobs)) {
         if (job->d->direction == direction &&
             job->d->jid == jid &&
-            job->d->requestId == id)
+            job->d->requestId == id) {
             return job;
+        }
     }
     return nullptr;
 }
@@ -695,11 +740,12 @@ QXmppTransferIncomingJob *QXmppTransferManagerPrivate::getIncomingJobByRequestId
 
 QXmppTransferIncomingJob *QXmppTransferManagerPrivate::getIncomingJobBySid(const QString &jid, const QString &sid)
 {
-    for (auto *job : jobs) {
+    for (auto *job : std::as_const(jobs)) {
         if (job->d->direction == QXmppTransferJob::IncomingDirection &&
             job->d->jid == jid &&
-            job->d->sid == sid)
+            job->d->sid == sid) {
             return static_cast<QXmppTransferIncomingJob *>(job);
+        }
     }
     return nullptr;
 }
@@ -709,13 +755,35 @@ QXmppTransferOutgoingJob *QXmppTransferManagerPrivate::getOutgoingJobByRequestId
     return static_cast<QXmppTransferOutgoingJob *>(getJobByRequestId(QXmppTransferJob::OutgoingDirection, jid, id));
 }
 
+///
+/// \class QXmppTransferManager
+///
+/// The QXmppTransferManager class provides support for sending and receiving
+/// files.
+///
+/// Stream initiation is performed as described in \xep{0095, Stream Initiation}
+/// and \xep{0096, SI File Transfer}. The actual file transfer is then performed
+/// using either \xep{0065, SOCKS5 Bytestreams} or \xep{0047, In-Band
+/// Bytestreams}.
+///
+/// To make use of this manager, you need to instantiate it and load it into the
+/// QXmppClient instance as follows:
+///
+/// \code
+/// auto *manager = new QXmppTransferManager;
+/// client->addExtension(manager);
+/// \endcode
+///
+/// \ingroup Managers
+///
+
+///
 /// Constructs a QXmppTransferManager to handle incoming and outgoing
 /// file transfers.
-
+///
 QXmppTransferManager::QXmppTransferManager()
+    : d(std::make_unique<QXmppTransferManagerPrivate>())
 {
-    d = new QXmppTransferManagerPrivate(this);
-
     // start SOCKS server
     d->socksServer = new QXmppSocksServer(this);
     connect(d->socksServer, &QXmppSocksServer::newConnection, this, &QXmppTransferManager::_q_socksServerConnected);
@@ -725,53 +793,58 @@ QXmppTransferManager::QXmppTransferManager()
     }
 }
 
-QXmppTransferManager::~QXmppTransferManager()
-{
-    delete d;
-}
+QXmppTransferManager::~QXmppTransferManager() = default;
 
 void QXmppTransferManager::byteStreamIqReceived(const QXmppByteStreamIq &iq)
 {
     // handle IQ from proxy
-    for (auto *job : d->jobs) {
+    for (auto *job : std::as_const(d->jobs)) {
         if (job->d->socksProxy.jid() == iq.from() && job->d->requestId == iq.id()) {
             if (iq.type() == QXmppIq::Result && iq.streamHosts().size() > 0) {
-                job->d->socksProxy = iq.streamHosts().first();
+                job->d->socksProxy = iq.streamHosts().constFirst();
                 socksServerSendOffer(job);
                 return;
             }
         }
     }
 
-    if (iq.type() == QXmppIq::Result)
+    if (iq.type() == QXmppIq::Result) {
         byteStreamResultReceived(iq);
-    else if (iq.type() == QXmppIq::Set)
+    } else if (iq.type() == QXmppIq::Set) {
         byteStreamSetReceived(iq);
+    }
 }
 
+///
 /// Handle a response to a bystream set, i.e. after we informed the remote party
 /// that we connected to a stream host.
+///
 void QXmppTransferManager::byteStreamResponseReceived(const QXmppIq &iq)
 {
     QXmppTransferJob *job = d->getIncomingJobByRequestId(iq.from(), iq.id());
     if (!job ||
         job->method() != QXmppTransferJob::SocksMethod ||
-        job->state() != QXmppTransferJob::StartState)
+        job->state() != QXmppTransferJob::StartState) {
         return;
+    }
 
-    if (iq.type() == QXmppIq::Error)
+    if (iq.type() == QXmppIq::Error) {
         job->terminate(QXmppTransferJob::ProtocolError);
+    }
 }
 
+///
 /// Handle a bytestream result, i.e. after the remote party has connected to
 /// a stream host.
+///
 void QXmppTransferManager::byteStreamResultReceived(const QXmppByteStreamIq &iq)
 {
-    QXmppTransferOutgoingJob *job = d->getOutgoingJobByRequestId(iq.from(), iq.id());
+    auto *job = d->getOutgoingJobByRequestId(iq.from(), iq.id());
     if (!job ||
         job->method() != QXmppTransferJob::SocksMethod ||
-        job->state() != QXmppTransferJob::StartState)
+        job->state() != QXmppTransferJob::StartState) {
         return;
+    }
 
     // check the stream host
     if (iq.streamHostUsed() == job->d->socksProxy.jid()) {
@@ -790,16 +863,17 @@ void QXmppTransferManager::byteStreamResultReceived(const QXmppByteStreamIq &iq)
     job->startSending();
 }
 
+///
 /// Handle a bytestream set, i.e. an invitation from the remote party to connect
 /// to a stream host.
+///
 void QXmppTransferManager::byteStreamSetReceived(const QXmppByteStreamIq &iq)
 {
-
     QXmppIq response;
     response.setId(iq.id());
     response.setTo(iq.from());
 
-    QXmppTransferIncomingJob *job = d->getIncomingJobBySid(iq.from(), iq.sid());
+    auto *job = d->getIncomingJobBySid(iq.from(), iq.sid());
     if (!job ||
         job->method() != QXmppTransferJob::SocksMethod ||
         job->state() != QXmppTransferJob::StartState) {
@@ -818,17 +892,19 @@ void QXmppTransferManager::byteStreamSetReceived(const QXmppByteStreamIq &iq)
 /// \cond
 QStringList QXmppTransferManager::discoveryFeatures() const
 {
-    return QStringList()
-        << ns_ibb                               // XEP-0047: In-Band Bytestreams
-        << ns_bytestreams                       // XEP-0065: SOCKS5 Bytestreams
-        << ns_stream_initiation                 // XEP-0095: Stream Initiation
-        << ns_stream_initiation_file_transfer;  // XEP-0096: SI File Transfer
+    return {
+        ns_ibb,                              // XEP-0047: In-Band Bytestreams
+        ns_bytestreams,                      // XEP-0065: SOCKS5 Bytestreams
+        ns_stream_initiation,                // XEP-0095: Stream Initiation
+        ns_stream_initiation_file_transfer,  // XEP-0096: SI File Transfer
+    };
 }
 
 bool QXmppTransferManager::handleStanza(const QDomElement &element)
 {
-    if (element.tagName() != "iq")
+    if (element.tagName() != "iq") {
         return false;
+    }
 
     // XEP-0047 In-Band Bytestreams
     if (QXmppIbbCloseIq::isIbbCloseIq(element)) {
@@ -880,7 +956,7 @@ void QXmppTransferManager::ibbCloseIqReceived(const QXmppIbbCloseIq &iq)
     response.setTo(iq.from());
     response.setId(iq.id());
 
-    QXmppTransferIncomingJob *job = d->getIncomingJobBySid(iq.from(), iq.sid());
+    auto *job = d->getIncomingJobBySid(iq.from(), iq.sid());
     if (!job ||
         job->method() != QXmppTransferJob::InBandMethod) {
         // the job is unknown, cancel it
@@ -905,7 +981,7 @@ void QXmppTransferManager::ibbDataIqReceived(const QXmppIbbDataIq &iq)
     response.setTo(iq.from());
     response.setId(iq.id());
 
-    QXmppTransferIncomingJob *job = d->getIncomingJobBySid(iq.from(), iq.sid());
+    auto *job = d->getIncomingJobBySid(iq.from(), iq.sid());
     if (!job ||
         job->method() != QXmppTransferJob::InBandMethod ||
         job->state() != QXmppTransferJob::TransferState) {
@@ -941,7 +1017,7 @@ void QXmppTransferManager::ibbOpenIqReceived(const QXmppIbbOpenIq &iq)
     response.setTo(iq.from());
     response.setId(iq.id());
 
-    QXmppTransferJob *job = d->getIncomingJobBySid(iq.from(), iq.sid());
+    auto *job = d->getIncomingJobBySid(iq.from(), iq.sid());
     if (!job ||
         job->method() != QXmppTransferJob::InBandMethod) {
         // the job is unknown, cancel it
@@ -971,15 +1047,17 @@ void QXmppTransferManager::ibbOpenIqReceived(const QXmppIbbOpenIq &iq)
 
 void QXmppTransferManager::ibbResponseReceived(const QXmppIq &iq)
 {
-    QXmppTransferJob *job = d->getOutgoingJobByRequestId(iq.from(), iq.id());
+    auto *job = d->getOutgoingJobByRequestId(iq.from(), iq.id());
     if (!job ||
         job->method() != QXmppTransferJob::InBandMethod ||
-        job->state() == QXmppTransferJob::FinishedState)
+        job->state() == QXmppTransferJob::FinishedState) {
         return;
+    }
 
     // if the IO device is closed, do nothing
-    if (!job->d->iodevice->isOpen())
+    if (!job->d->iodevice->isOpen()) {
         return;
+    }
 
     if (iq.type() == QXmppIq::Result) {
         const QByteArray buffer = job->d->iodevice->read(job->d->blockSize);
@@ -995,7 +1073,7 @@ void QXmppTransferManager::ibbResponseReceived(const QXmppIq &iq)
             client()->sendPacket(dataIq);
 
             job->d->done += buffer.size();
-            job->progress(job->d->done, job->fileSize());
+            Q_EMIT job->progress(job->d->done, job->fileSize());
         } else {
             // close the bytestream
             QXmppIbbCloseIq closeIq;
@@ -1020,8 +1098,7 @@ void QXmppTransferManager::ibbResponseReceived(const QXmppIq &iq)
 
 void QXmppTransferManager::_q_iqReceived(const QXmppIq &iq)
 {
-
-    for (auto *ptr : d->jobs) {
+    for (auto *ptr : std::as_const(d->jobs)) {
         // handle IQ from proxy
         if (ptr->direction() == QXmppTransferJob::OutgoingDirection && ptr->d->socksProxy.jid() == iq.from() && ptr->d->requestId == iq.id()) {
             auto *job = static_cast<QXmppTransferOutgoingJob *>(ptr);
@@ -1037,15 +1114,16 @@ void QXmppTransferManager::_q_iqReceived(const QXmppIq &iq)
                 }
             } else {
                 // we could not get host/port from proxy, proceed without a proxy
-                if (iq.type() == QXmppIq::Error)
+                if (iq.type() == QXmppIq::Error) {
                     socksServerSendOffer(job);
+                }
             }
             return;
         }
 
         // handle IQ from peer
         else if (ptr->d->jid == iq.from() && ptr->d->requestId == iq.id()) {
-            QXmppTransferJob *job = ptr;
+            auto *job = ptr;
             if (job->direction() == QXmppTransferJob::OutgoingDirection &&
                 job->method() == QXmppTransferJob::InBandMethod) {
                 ibbResponseReceived(iq);
@@ -1072,8 +1150,9 @@ void QXmppTransferManager::_q_jobDestroyed(QObject *object)
 void QXmppTransferManager::_q_jobError(QXmppTransferJob::Error error)
 {
     auto *job = qobject_cast<QXmppTransferJob *>(sender());
-    if (!job || !d->jobs.contains(job))
+    if (!job || !d->jobs.contains(job)) {
         return;
+    }
 
     if (job->direction() == QXmppTransferJob::OutgoingDirection &&
         job->method() == QXmppTransferJob::InBandMethod &&
@@ -1090,20 +1169,23 @@ void QXmppTransferManager::_q_jobError(QXmppTransferJob::Error error)
 void QXmppTransferManager::_q_jobFinished()
 {
     auto *job = qobject_cast<QXmppTransferJob *>(sender());
-    if (!job || !d->jobs.contains(job))
+    if (!job || !d->jobs.contains(job)) {
         return;
+    }
 
-    emit jobFinished(job);
+    Q_EMIT jobFinished(job);
 }
 
 void QXmppTransferManager::_q_jobStateChanged(QXmppTransferJob::State state)
 {
     auto *job = qobject_cast<QXmppTransferJob *>(sender());
-    if (!job || !d->jobs.contains(job))
+    if (!job || !d->jobs.contains(job)) {
         return;
+    }
 
-    if (job->direction() != QXmppTransferJob::IncomingDirection)
+    if (job->direction() != QXmppTransferJob::IncomingDirection) {
         return;
+    }
 
     // disconnect from the signal
     disconnect(job, &QXmppTransferJob::stateChanged,
@@ -1133,10 +1215,11 @@ void QXmppTransferManager::_q_jobStateChanged(QXmppTransferJob::State state)
 
     QXmppDataForm::Field methodField(QXmppDataForm::Field::ListSingleField);
     methodField.setKey("stream-method");
-    if (job->method() == QXmppTransferJob::InBandMethod)
+    if (job->method() == QXmppTransferJob::InBandMethod) {
         methodField.setValue(ns_ibb);
-    else if (job->method() == QXmppTransferJob::SocksMethod)
+    } else if (job->method() == QXmppTransferJob::SocksMethod) {
         methodField.setValue(ns_bytestreams);
+    }
     form.setFields(QList<QXmppDataForm::Field>() << methodField);
 
     QXmppStreamInitiationIq response;
@@ -1149,18 +1232,20 @@ void QXmppTransferManager::_q_jobStateChanged(QXmppTransferJob::State state)
     client()->sendPacket(response);
 
     // notify user
-    emit jobStarted(job);
+    Q_EMIT jobStarted(job);
 }
 
+///
 /// Sends the file at \a filePath to a remote party.
 ///
 /// The remote party will be given the choice to accept or refuse the transfer.
 ///
-/// Returns 0 if the \a jid is not valid or if the file at \a filePath cannot be read.
+/// Returns 0 if the \a jid is not valid or if the file at \a filePath cannot be
+/// read.
 ///
-/// \note The recipient's \a jid must be a full JID with a resource, for instance "user@host/resource".
+/// \note The recipient's \a jid must be a full JID with a resource, for
+/// instance "user@host/resource".
 ///
-
 QXmppTransferJob *QXmppTransferManager::sendFile(const QString &jid, const QString &filePath, const QString &description)
 {
     if (QXmppUtils::jidToResource(jid).isEmpty()) {
@@ -1203,16 +1288,17 @@ QXmppTransferJob *QXmppTransferManager::sendFile(const QString &jid, const QStri
     return job;
 }
 
+///
 /// Sends the file in \a device to a remote party.
 ///
 /// The remote party will be given the choice to accept or refuse the transfer.
 ///
 /// Returns 0 if the \a jid is not valid.
 ///
-/// \note The recipient's \a jid must be a full JID with a resource, for instance "user@host/resource".
+/// \note The recipient's \a jid must be a full JID with a resource, for
+/// instance "user@host/resource".
 /// \note The ownership of the \a device should be managed by the caller.
 ///
-
 QXmppTransferJob *QXmppTransferManager::sendFile(const QString &jid, QIODevice *device, const QXmppTransferFileInfo &fileInfo, const QString &sid)
 {
     if (QXmppUtils::jidToResource(jid).isEmpty()) {
@@ -1221,10 +1307,7 @@ QXmppTransferJob *QXmppTransferManager::sendFile(const QString &jid, QIODevice *
     }
 
     auto *job = new QXmppTransferOutgoingJob(jid, client(), this);
-    if (sid.isEmpty())
-        job->d->sid = QXmppUtils::generateStanzaHash();
-    else
-        job->d->sid = sid;
+    job->d->sid = sid.isEmpty() ? QXmppUtils::generateStanzaHash() : sid;
     job->d->fileInfo = fileInfo;
     job->d->iodevice = device;
 
@@ -1246,10 +1329,12 @@ QXmppTransferJob *QXmppTransferManager::sendFile(const QString &jid, QIODevice *
 
     QXmppDataForm::Field methodField(QXmppDataForm::Field::ListSingleField);
     methodField.setKey("stream-method");
-    if (d->supportedMethods & QXmppTransferJob::InBandMethod)
+    if (d->supportedMethods & QXmppTransferJob::InBandMethod) {
         methodField.setOptions(methodField.options() << qMakePair(QString(), QString::fromLatin1(ns_ibb)));
-    if (d->supportedMethods & QXmppTransferJob::SocksMethod)
+    }
+    if (d->supportedMethods & QXmppTransferJob::SocksMethod) {
         methodField.setOptions(methodField.options() << qMakePair(QString(), QString::fromLatin1(ns_bytestreams)));
+    }
     form.setFields(QList<QXmppDataForm::Field>() << methodField);
 
     // start job
@@ -1270,7 +1355,7 @@ QXmppTransferJob *QXmppTransferManager::sendFile(const QString &jid, QIODevice *
     client()->sendPacket(request);
 
     // notify user
-    emit jobStarted(job);
+    Q_EMIT jobStarted(job);
 
     return job;
 }
@@ -1278,7 +1363,7 @@ QXmppTransferJob *QXmppTransferManager::sendFile(const QString &jid, QIODevice *
 void QXmppTransferManager::_q_socksServerConnected(QTcpSocket *socket, const QString &hostName, quint16 port)
 {
     const QString ownJid = client()->configuration().jid();
-    for (auto *job : d->jobs) {
+    for (auto *job : std::as_const(d->jobs)) {
         if (hostName == streamHash(job->d->sid, ownJid, job->jid()) && port == 0) {
             job->d->socksSocket = socket;
             return;
@@ -1290,7 +1375,7 @@ void QXmppTransferManager::_q_socksServerConnected(QTcpSocket *socket, const QSt
 
 void QXmppTransferManager::socksServerSendOffer(QXmppTransferJob *job)
 {
-    const QString ownJid = client()->configuration().jid();
+    const auto ownJid = client()->configuration().jid();
     QList<QXmppByteStreamIq::StreamHost> streamHosts;
 
     // discover local IPs
@@ -1306,8 +1391,9 @@ void QXmppTransferManager::socksServerSendOffer(QXmppTransferJob *job)
     }
 
     // add proxy
-    if (!job->d->socksProxy.jid().isEmpty())
+    if (!job->d->socksProxy.jid().isEmpty()) {
         streamHosts.append(job->d->socksProxy);
+    }
 
     // check we have some stream hosts
     if (!streamHosts.size()) {
@@ -1328,19 +1414,21 @@ void QXmppTransferManager::socksServerSendOffer(QXmppTransferJob *job)
 
 void QXmppTransferManager::streamInitiationIqReceived(const QXmppStreamInitiationIq &iq)
 {
-    if (iq.type() == QXmppIq::Result)
+    if (iq.type() == QXmppIq::Result) {
         streamInitiationResultReceived(iq);
-    else if (iq.type() == QXmppIq::Set)
+    } else if (iq.type() == QXmppIq::Set) {
         streamInitiationSetReceived(iq);
+    }
 }
 
 // The remote party has accepted an outgoing transfer.
 void QXmppTransferManager::streamInitiationResultReceived(const QXmppStreamInitiationIq &iq)
 {
-    QXmppTransferJob *job = d->getOutgoingJobByRequestId(iq.from(), iq.id());
+    auto *job = d->getOutgoingJobByRequestId(iq.from(), iq.id());
     if (!job ||
-        job->state() != QXmppTransferJob::OfferState)
+        job->state() != QXmppTransferJob::OfferState) {
         return;
+    }
 
     const auto &form = iq.featureForm();
     const auto &fields = form.fields();
@@ -1348,11 +1436,12 @@ void QXmppTransferManager::streamInitiationResultReceived(const QXmppStreamIniti
     for (const auto &field : fields) {
         if (field.key() == "stream-method") {
             if ((field.value().toString() == ns_ibb) &&
-                (d->supportedMethods & QXmppTransferJob::InBandMethod))
+                (d->supportedMethods & QXmppTransferJob::InBandMethod)) {
                 job->d->method = QXmppTransferJob::InBandMethod;
-            else if ((field.value().toString() == ns_bytestreams) &&
-                     (d->supportedMethods & QXmppTransferJob::SocksMethod))
+            } else if ((field.value().toString() == ns_bytestreams) &&
+                       (d->supportedMethods & QXmppTransferJob::SocksMethod)) {
                 job->d->method = QXmppTransferJob::SocksMethod;
+            }
         }
     }
 
@@ -1419,13 +1508,13 @@ void QXmppTransferManager::streamInitiationSetReceived(const QXmppStreamInitiati
     }
 
     // check the stream type
-    QXmppTransferIncomingJob *job = new QXmppTransferIncomingJob(iq.from(), client(), this);
+    auto *job = new QXmppTransferIncomingJob(iq.from(), client(), this);
     int offeredMethods = QXmppTransferJob::NoMethod;
     job->d->offerId = iq.id();
     job->d->sid = iq.siId();
     job->d->mimeType = iq.mimeType();
     job->d->fileInfo = iq.fileInfo();
-    
+
     const auto &form = iq.featureForm();
     const auto &fields = form.fields();
     for (const auto &field : fields) {
@@ -1433,21 +1522,22 @@ void QXmppTransferManager::streamInitiationSetReceived(const QXmppStreamInitiati
             QPair<QString, QString> option;
             const auto &options = field.options();
             for (const auto &option : options) {
-                if (option.second == ns_ibb)
+                if (option.second == ns_ibb) {
                     offeredMethods = offeredMethods | QXmppTransferJob::InBandMethod;
-                else if (option.second == ns_bytestreams)
+                } else if (option.second == ns_bytestreams) {
                     offeredMethods = offeredMethods | QXmppTransferJob::SocksMethod;
+                }
             }
         }
     }
 
     // select a method supported by both parties
     int sharedMethods = (offeredMethods & d->supportedMethods);
-    if (sharedMethods & QXmppTransferJob::SocksMethod)
+    if (sharedMethods & QXmppTransferJob::SocksMethod) {
         job->d->method = QXmppTransferJob::SocksMethod;
-    else if (sharedMethods & QXmppTransferJob::InBandMethod)
+    } else if (sharedMethods & QXmppTransferJob::InBandMethod) {
         job->d->method = QXmppTransferJob::InBandMethod;
-    else {
+    } else {
         // FIXME : we should add:
         // <no-valid-streams xmlns='http://jabber.org/protocol/si'/>
         QXmppStanza::Error error(QXmppStanza::Error::Cancel, QXmppStanza::Error::BadRequest);
@@ -1469,7 +1559,7 @@ void QXmppTransferManager::streamInitiationSetReceived(const QXmppStreamInitiati
     connect(job, &QXmppTransferJob::stateChanged, this, &QXmppTransferManager::_q_jobStateChanged);
 
     // allow user to accept or decline the job
-    emit fileReceived(job);
+    Q_EMIT fileReceived(job);
 }
 
 QString QXmppTransferManager::proxy() const
@@ -1477,6 +1567,7 @@ QString QXmppTransferManager::proxy() const
     return d->proxy;
 }
 
+///
 /// Set the JID of the SOCKS5 bytestream proxy to use for
 /// outgoing transfers.
 ///
@@ -1484,7 +1575,6 @@ QString QXmppTransferManager::proxy() const
 /// be offered to the recipient in addition to your own IP
 /// addresses.
 ///
-
 void QXmppTransferManager::setProxy(const QString &proxyJid)
 {
     d->proxy = proxyJid;
@@ -1495,13 +1585,13 @@ bool QXmppTransferManager::proxyOnly() const
     return d->proxyOnly;
 }
 
+///
 /// Set whether the proxy should systematically be used for
 /// outgoing SOCKS5 bytestream transfers.
 ///
 /// \note If you set this to true and do not provide a proxy
 /// using setProxy(), your outgoing transfers will fail!
 ///
-
 void QXmppTransferManager::setProxyOnly(bool proxyOnly)
 {
     d->proxyOnly = proxyOnly;
@@ -1512,13 +1602,13 @@ QXmppTransferJob::Methods QXmppTransferManager::supportedMethods() const
     return d->supportedMethods;
 }
 
+///
 /// Set the supported stream methods. This allows you to selectively
 /// enable or disable stream methods (In-Band or SOCKS5 bytestreams).
 ///
 /// The methods argument is a combination of zero or more
 /// QXmppTransferJob::Method.
 ///
-
 void QXmppTransferManager::setSupportedMethods(QXmppTransferJob::Methods methods)
 {
     d->supportedMethods = methods;
