@@ -1,25 +1,6 @@
-/*
- * Copyright (C) 2008-2021 The QXmpp developers
- *
- * Author:
- *  Jeremy Lainé
- *
- * Source:
- *  https://github.com/qxmpp-project/qxmpp
- *
- * This file is a part of QXmpp library.
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- */
+// SPDX-FileCopyrightText: 2010 Jeremy Lainé <jeremy.laine@m4x.org>
+//
+// SPDX-License-Identifier: LGPL-2.1-or-later
 
 #ifndef QXMPPTRANSFERMANAGER_H
 #define QXMPPTRANSFERMANAGER_H
@@ -78,11 +59,6 @@ private:
     QSharedDataPointer<QXmppTransferFileInfoPrivate> d;
 };
 
-/// \brief The QXmppTransferJob class represents a single file transfer job.
-///
-/// \sa QXmppTransferManager
-///
-
 class QXMPP_EXPORT QXmppTransferJob : public QXmppLoggable
 {
     Q_OBJECT
@@ -206,31 +182,13 @@ private:
     void setState(QXmppTransferJob::State state);
     void terminate(QXmppTransferJob::Error error);
 
-    QXmppTransferJobPrivate *const d;
+    const std::unique_ptr<QXmppTransferJobPrivate> d;
     friend class QXmppTransferManager;
     friend class QXmppTransferManagerPrivate;
     friend class QXmppTransferIncomingJob;
     friend class QXmppTransferOutgoingJob;
 };
 
-///
-/// \brief The QXmppTransferManager class provides support for sending and
-/// receiving files.
-///
-/// Stream initiation is performed as described in \xep{0095}: Stream Initiation
-/// and \xep{0096}: SI File Transfer. The actual file transfer is then performed
-/// using either \xep{0065}: SOCKS5 Bytestreams or \xep{0047}: In-Band Bytestreams.
-///
-/// To make use of this manager, you need to instantiate it and load it into
-/// the QXmppClient instance as follows:
-///
-/// \code
-/// QXmppTransferManager *manager = new QXmppTransferManager;
-/// client->addExtension(manager);
-/// \endcode
-///
-/// \ingroup Managers
-///
 class QXMPP_EXPORT QXmppTransferManager : public QXmppClientExtension
 {
     Q_OBJECT
@@ -302,7 +260,7 @@ private Q_SLOTS:
     void _q_socksServerConnected(QTcpSocket *socket, const QString &hostName, quint16 port);
 
 private:
-    QXmppTransferManagerPrivate *d;
+    const std::unique_ptr<QXmppTransferManagerPrivate> d;
 
     void byteStreamIqReceived(const QXmppByteStreamIq &);
     void byteStreamResponseReceived(const QXmppIq &);
