@@ -1,25 +1,6 @@
-/*
- * Copyright (C) 2008-2021 The QXmpp developers
- *
- * Author:
- *  Linus Jahn
- *
- * Source:
- *  https://github.com/qxmpp-project/qxmpp
- *
- * This file is a part of QXmpp library.
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- */
+// SPDX-FileCopyrightText: 2019 Linus Jahn <lnj@kaidan.im>
+//
+// SPDX-License-Identifier: LGPL-2.1-or-later
 
 #include "QXmppUploadRequestManager.h"
 
@@ -28,11 +9,15 @@
 #include "QXmppDataForm.h"
 #include "QXmppDiscoveryIq.h"
 #include "QXmppDiscoveryManager.h"
+#include "QXmppFutureUtils_p.h"
 #include "QXmppHttpUploadIq.h"
 
+#include <QDomElement>
 #include <QFileInfo>
 #include <QMimeDatabase>
 
+using namespace QXmpp::Private;
+
 class QXmppUploadServicePrivate : public QSharedData
 {
 public:
@@ -93,8 +78,17 @@ public:
     QVector<QXmppUploadService> uploadServices;
 };
 
+///
+/// \typedef QXmppUploadRequestManager::SlotResult
+///
+/// Contains the requested upload slot from the service or a QXmppStanza::Error
+/// in case the request failed.
+///
+/// \since QXmpp 1.5
+///
+
 QXmppUploadRequestManager::QXmppUploadRequestManager()
-    : d(new QXmppUploadRequestManagerPrivate)
+    : d(std::make_unique<QXmppUploadRequestManagerPrivate>())
 {
 }
 
@@ -157,24 +151,109 @@ QString QXmppUploadRequestManager::requestUploadSlot(const QString &fileName,
                                                      const QMimeType &mimeType,
                                                      const QString &uploadService)
 {
-    if (!serviceFound() && uploadService.isEmpty())
+    if (!serviceFound() && uploadService.isEmpty()) {
         return {};
+    }
 
     QXmppHttpUploadRequestIq iq;
-    if (uploadService.isEmpty())
+    if (uploadService.isEmpty()) {
         iq.setTo(d->uploadServices.first().jid());
-    else
+    } else {
         iq.setTo(uploadService);
+    }
     iq.setType(QXmppIq::Get);
     iq.setFileName(fileName);
     iq.setSize(fileSize);
     iq.setContentType(mimeType);
 
-    if (client()->sendPacket(iq))
+    if (client()->sendPacket(iq)) {
         return iq.id();
+    }
     return {};
 }
 
+///
+/// Requests an upload slot from the server.
+///
+/// \param file The info of the file to be uploaded.
+/// \param uploadService The HTTP File Upload service that is used to request
+///                      the upload slot. If this is empty, the first
+///                      discovered one is used.
+///
+/// \warning THIS API IS NOT FINALIZED YET!
+///
+/// \since QXmpp 1.5
+///
+auto QXmppUploadRequestManager::requestSlot(const QFileInfo &file,
+                                            const QString &uploadService) -> QXmppTask<SlotResult>
+{
+    return requestSlot(file, file.fileName(), uploadService);
+}
+
+///
+/// Requests an upload slot from the server.
+///
+/// \param file The info of the file to be uploaded.
+/// \param customFileName This name is used instead of the file's actual name
+///                       for requesting the upload slot.
+/// \param uploadService The HTTP File Upload service that is used to request
+///                      the upload slot. If this is empty, the first
+///                      discovered one is used.
+///
+/// \warning THIS API IS NOT FINALIZED YET!
+///
+/// \since QXmpp 1.5
+///
+auto QXmppUploadRequestManager::requestSlot(const QFileInfo &file,
+                                            const QString &customFileName,
+                                            const QString &uploadService) -> QXmppTask<SlotResult>
+{
+    return requestSlot(customFileName, file.size(),
+                       QMimeDatabase().mimeTypeForFile(file),
+                       uploadService);
+}
+
+///
+/// Requests an upload slot from the server.
+///
+/// \param fileName The name of the file to be uploaded. This may be used by
+///                 the server to generate the URL.
+/// \param fileSize The size of the file to be uploaded. The server may reject
+///                 too large files.
+/// \param mimeType The content-type of the file. This can be used by the
+///                 server to set the HTTP MIME-type of the URL.
+/// \param uploadService The HTTP File Upload service that is used to request
+///                      the upload slot. If this is empty, the first
+///                      discovered one is used.
+///
+/// \warning THIS API IS NOT FINALIZED YET!
+///
+/// \since QXmpp 1.5
+///
+auto QXmppUploadRequestManager::requestSlot(const QString &fileName,
+                                            qint64 fileSize,
+                                            const QMimeType &mimeType,
+                                            const QString &uploadService) -> QXmppTask<SlotResult>
+{
+    if (!serviceFound() && uploadService.isEmpty()) {
+        return makeReadyTask(SlotResult(QXmppError {
+            QStringLiteral("Couldn't request upload slot: No service found."), {} }));
+    }
+
+    QXmppHttpUploadRequestIq iq;
+    if (uploadService.isEmpty()) {
+        iq.setTo(d->uploadServices.first().jid());
+    } else {
+        iq.setTo(uploadService);
+    }
+    iq.setType(QXmppIq::Get);
+    iq.setFileName(fileName);
+    iq.setSize(fileSize);
+    iq.setContentType(mimeType);
+
+    return chainIq<SlotResult>(client()->sendIq(std::move(iq)), this);
+}
+
 /// Returns true if an HTTP File Upload service has been discovered.
 
 bool QXmppUploadRequestManager::serviceFound() const
@@ -195,13 +274,13 @@ bool QXmppUploadRequestManager::handleStanza(const QDomElement &element)
         QXmppHttpUploadSlotIq slot;
         slot.parse(element);
 
-        emit slotReceived(slot);
+        Q_EMIT slotReceived(slot);
         return true;
     } else if (QXmppHttpUploadRequestIq::isHttpUploadRequestIq(element)) {
         QXmppHttpUploadRequestIq requestError;
         requestError.parse(element);
 
-        emit requestFailed(requestError);
+        Q_EMIT requestFailed(requestError);
         return true;
     }
     return false;
@@ -209,10 +288,12 @@ bool QXmppUploadRequestManager::handleStanza(const QDomElement &element)
 
 void QXmppUploadRequestManager::handleDiscoInfo(const QXmppDiscoveryIq &iq)
 {
-    if (!iq.features().contains(ns_http_upload))
+    if (!iq.features().contains(ns_http_upload)) {
         return;
+    }
 
-    for (const QXmppDiscoveryIq::Identity &identity : iq.identities()) {
+    const auto identities = iq.identities();
+    for (const QXmppDiscoveryIq::Identity &identity : identities) {
         if (identity.category() == QStringLiteral("store") &&
             identity.type() == QStringLiteral("file")) {
             QXmppUploadService service;
@@ -220,7 +301,8 @@ void QXmppUploadRequestManager::handleDiscoInfo(const QXmppDiscoveryIq &iq)
 
             // get size limit
             bool isFormNsCorrect = false;
-            for (const QXmppDataForm::Field &field : iq.form().fields()) {
+            const auto fields = iq.form().fields();
+            for (const QXmppDataForm::Field &field : fields) {
                 if (field.key() == QStringLiteral("FORM_TYPE")) {
                     isFormNsCorrect = field.value() == ns_http_upload;
                 } else if (isFormNsCorrect && field.key() == QStringLiteral("max-file-size")) {
@@ -229,7 +311,7 @@ void QXmppUploadRequestManager::handleDiscoInfo(const QXmppDiscoveryIq &iq)
             }
 
             d->uploadServices.append(service);
-            emit serviceFoundChanged();
+            Q_EMIT serviceFoundChanged();
         }
     }
     return;
@@ -246,9 +328,9 @@ void QXmppUploadRequestManager::setClient(QXmppClient *client)
                 this, &QXmppUploadRequestManager::handleDiscoInfo);
 
         // on client disconnect remove all upload services
-        connect(client, &QXmppClient::disconnected, [=]() {
+        connect(client, &QXmppClient::disconnected, this, [this]() {
             d->uploadServices.clear();
-            emit serviceFoundChanged();
+            Q_EMIT serviceFoundChanged();
         });
     }
 }
