@@ -1,44 +1,31 @@
-/*
- * Copyright (C) 2008-2021 The QXmpp developers
- *
- * Author:
- *  Linus Jahn
- *
- * Source:
- *  https://github.com/qxmpp-project/qxmpp
- *
- * This file is a part of QXmpp library.
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- */
+// SPDX-FileCopyrightText: 2019 Linus Jahn <lnj@kaidan.im>
+//
+// SPDX-License-Identifier: LGPL-2.1-or-later
 
 #ifndef QXMPPUPLOADREQUESTMANAGER_H
 #define QXMPPUPLOADREQUESTMANAGER_H
 
-#include <QXmppClientExtension.h>
+#include "QXmppClientExtension.h"
+#include "QXmppError.h"
+
+#include <variant>
 
 #include <QSharedDataPointer>
 
 class QFileInfo;
+template<typename T>
+class QXmppTask;
 class QMimeType;
 class QXmppHttpUploadRequestIq;
 class QXmppHttpUploadSlotIq;
 class QXmppUploadServicePrivate;
 class QXmppUploadRequestManagerPrivate;
 
+///
 /// \brief QXmppUploadService represents an HTTP File Upload service.
 ///
 /// It is used to store the JID and maximum file size for uploads.
-
+///
 class QXMPP_EXPORT QXmppUploadService
 {
 public:
@@ -112,6 +99,17 @@ public:
                               const QMimeType &mimeType,
                               const QString &uploadService = QString());
 
+    using SlotResult = std::variant<QXmppHttpUploadSlotIq, QXmppError>;
+    QXmppTask<SlotResult> requestSlot(const QFileInfo &file,
+                                      const QString &uploadService = {});
+    QXmppTask<SlotResult> requestSlot(const QFileInfo &file,
+                                      const QString &customFileName,
+                                      const QString &uploadService = {});
+    QXmppTask<SlotResult> requestSlot(const QString &fileName,
+                                      qint64 fileSize,
+                                      const QMimeType &mimeType,
+                                      const QString &uploadService = {});
+
     bool serviceFound() const;
 
     QVector<QXmppUploadService> uploadServices() const;
@@ -136,7 +134,7 @@ protected:
 private:
     void handleDiscoInfo(const QXmppDiscoveryIq &iq);
 
-    QSharedDataPointer<QXmppUploadRequestManagerPrivate> d;
+    const std::unique_ptr<QXmppUploadRequestManagerPrivate> d;
 };
 
 #endif  // QXMPPUPLOADREQUESTMANAGER_H
