@@ -1,25 +1,6 @@
-/*
- * Copyright (C) 2008-2021 The QXmpp developers
- *
- * Author:
- *  Manjeet Dahiya
- *
- * Source:
- *  https://github.com/qxmpp-project/qxmpp
- *
- * This file is a part of QXmpp library.
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- */
+// SPDX-FileCopyrightText: 2009 Manjeet Dahiya <manjeetdahiya@gmail.com>
+//
+// SPDX-License-Identifier: LGPL-2.1-or-later
 
 #include "QXmppVCardManager.h"
 
@@ -36,35 +17,33 @@ public:
 };
 
 QXmppVCardManager::QXmppVCardManager()
-    : d(new QXmppVCardManagerPrivate)
+    : d(std::make_unique<QXmppVCardManagerPrivate>())
 {
     d->isClientVCardReceived = false;
 }
 
-QXmppVCardManager::~QXmppVCardManager()
-{
-    delete d;
-}
+QXmppVCardManager::~QXmppVCardManager() = default;
 
 /// This function requests the server for vCard of the specified jid.
 /// Once received the signal vCardReceived() is emitted.
 ///
 /// \param jid Jid of the specific entry in the roster
 ///
-QString QXmppVCardManager::requestVCard(const QString& jid)
+QString QXmppVCardManager::requestVCard(const QString &jid)
 {
     QXmppVCardIq request(jid);
-    if (client()->sendPacket(request))
+    if (client()->sendPacket(request)) {
         return request.id();
-    else
+    } else {
         return QString();
+    }
 }
 
 /// Returns the vCard of the connected client.
 ///
 /// \return QXmppVCard
 ///
-const QXmppVCardIq& QXmppVCardManager::clientVCard() const
+const QXmppVCardIq &QXmppVCardManager::clientVCard() const
 {
     return d->clientVCard;
 }
@@ -73,7 +52,7 @@ const QXmppVCardIq& QXmppVCardManager::clientVCard() const
 ///
 /// \param clientVCard QXmppVCard
 ///
-void QXmppVCardManager::setClientVCard(const QXmppVCardIq& clientVCard)
+void QXmppVCardManager::setClientVCard(const QXmppVCardIq &clientVCard)
 {
     d->clientVCard = clientVCard;
     d->clientVCard.setTo("");
@@ -107,7 +86,7 @@ QStringList QXmppVCardManager::discoveryFeatures() const
     return QStringList() << ns_vcard;
 }
 
-bool QXmppVCardManager::handleStanza(const QDomElement& element)
+bool QXmppVCardManager::handleStanza(const QDomElement &element)
 {
     if (element.tagName() == "iq" && QXmppVCardIq::isVCard(element)) {
         QXmppVCardIq vCardIq;
@@ -116,10 +95,10 @@ bool QXmppVCardManager::handleStanza(const QDomElement& element)
         if (vCardIq.from().isEmpty() || vCardIq.from() == client()->configuration().jidBare()) {
             d->clientVCard = vCardIq;
             d->isClientVCardReceived = true;
-            emit clientVCardReceived();
+            Q_EMIT clientVCardReceived();
         }
 
-        emit vCardReceived(vCardIq);
+        Q_EMIT vCardReceived(vCardIq);
 
         return true;
     }
