@@ -1,37 +1,20 @@
-/*
- * Copyright (C) 2008-2021 The QXmpp developers
- *
- * Author:
- *  Manjeet Dahiya
- *
- * Source:
- *  https://github.com/qxmpp-project/qxmpp
- *
- * This file is a part of QXmpp library.
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- */
+// SPDX-FileCopyrightText: 2010 Manjeet Dahiya <manjeetdahiya@gmail.com>
+//
+// SPDX-License-Identifier: LGPL-2.1-or-later
 
 #include "QXmppVersionManager.h"
 
 #include "QXmppClient.h"
 #include "QXmppConstants_p.h"
-#include "QXmppGlobal.h"
+#include "QXmppIqHandling.h"
 #include "QXmppVersionIq.h"
 
 #include <QCoreApplication>
 #include <QDomElement>
 #include <QSysInfo>
 
+using namespace QXmpp;
+
 class QXmppVersionManagerPrivate
 {
 public:
@@ -41,43 +24,43 @@ public:
 };
 
 QXmppVersionManager::QXmppVersionManager()
-    : d(new QXmppVersionManagerPrivate)
+    : d(std::make_unique<QXmppVersionManagerPrivate>())
 {
     d->clientName = qApp->applicationName();
-    if (d->clientName.isEmpty())
+    if (d->clientName.isEmpty()) {
         d->clientName = "Based on QXmpp";
+    }
 
     d->clientOs = QSysInfo::prettyProductName();
     d->clientVersion = qApp->applicationVersion();
-    if (d->clientVersion.isEmpty())
+    if (d->clientVersion.isEmpty()) {
         d->clientVersion = QXmppVersion();
+    }
 }
 
-QXmppVersionManager::~QXmppVersionManager()
-{
-    delete d;
-}
+QXmppVersionManager::~QXmppVersionManager() = default;
 
 /// Request version information from the specified XMPP entity.
 ///
 /// \param jid
 
-QString QXmppVersionManager::requestVersion(const QString& jid)
+QString QXmppVersionManager::requestVersion(const QString &jid)
 {
     QXmppVersionIq request;
     request.setType(QXmppIq::Get);
     request.setTo(jid);
-    if (client()->sendPacket(request))
+    if (client()->sendPacket(request)) {
         return request.id();
-    else
+    } else {
         return QString();
+    }
 }
 
 /// Sets the local XMPP client's name.
 ///
 /// \param name
 
-void QXmppVersionManager::setClientName(const QString& name)
+void QXmppVersionManager::setClientName(const QString &name)
 {
     d->clientName = name;
 }
@@ -86,7 +69,7 @@ void QXmppVersionManager::setClientName(const QString& name)
 ///
 /// \param version
 
-void QXmppVersionManager::setClientVersion(const QString& version)
+void QXmppVersionManager::setClientVersion(const QString &version)
 {
     d->clientVersion = version;
 }
@@ -95,7 +78,7 @@ void QXmppVersionManager::setClientVersion(const QString& version)
 ///
 /// \param os
 
-void QXmppVersionManager::setClientOs(const QString& os)
+void QXmppVersionManager::setClientOs(const QString &os)
 {
     d->clientOs = os;
 }
@@ -137,27 +120,19 @@ QStringList QXmppVersionManager::discoveryFeatures() const
     return QStringList() << ns_version;
 }
 
-bool QXmppVersionManager::handleStanza(const QDomElement& element)
+bool QXmppVersionManager::handleStanza(const QDomElement &element)
 {
+    if (QXmpp::handleIqRequests<QXmppVersionIq>(element, client(), this)) {
+        return true;
+    }
+
     if (element.tagName() == "iq" && QXmppVersionIq::isVersionIq(element)) {
         QXmppVersionIq versionIq;
         versionIq.parse(element);
 
-        if (versionIq.type() == QXmppIq::Get) {
-            // respond to query
-            QXmppVersionIq responseIq;
-            responseIq.setType(QXmppIq::Result);
-            responseIq.setId(versionIq.id());
-            responseIq.setTo(versionIq.from());
-
-            responseIq.setName(clientName());
-            responseIq.setVersion(clientVersion());
-            responseIq.setOs(clientOs());
-
-            client()->sendPacket(responseIq);
-        } else if (versionIq.type() == QXmppIq::Result) {
+        if (versionIq.type() == QXmppIq::Result) {
             // emit response
-            emit versionReceived(versionIq);
+            Q_EMIT versionReceived(versionIq);
         }
 
         return true;
@@ -165,4 +140,14 @@ bool QXmppVersionManager::handleStanza(const QDomElement& element)
 
     return false;
 }
+
+QXmppVersionIq QXmppVersionManager::handleIq(QXmppVersionIq &&iq)
+{
+    QXmppVersionIq response;
+    response.setType(QXmppIq::Result);
+    response.setName(clientName());
+    response.setVersion(clientVersion());
+    response.setOs(clientOs());
+    return response;
+}
 /// \endcond
