@@ -1,25 +1,6 @@
-/*
- * Copyright (C) 2008-2021 The QXmpp developers
- *
- * Author:
- *	Jeremy Lainé
- *
- * Source:
- *	https://github.com/qxmpp-project/qxmpp
- *
- * This file is a part of QXmpp library.
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- */
+// SPDX-FileCopyrightText: 2010 Jeremy Lainé <jeremy.laine@m4x.org>
+//
+// SPDX-License-Identifier: LGPL-2.1-or-later
 
 #include "QXmppDialback.h"
 
@@ -94,26 +75,29 @@ bool QXmppDialback::isDialback(const QDomElement &element)
 void QXmppDialback::parse(const QDomElement &element)
 {
     QXmppStanza::parse(element);
-    if (element.tagName() == QLatin1String("result"))
+    if (element.tagName() == QLatin1String("result")) {
         m_command = Result;
-    else
+    } else {
         m_command = Verify;
+    }
     m_type = element.attribute("type");
     m_key = element.text();
 }
 
 void QXmppDialback::toXml(QXmlStreamWriter *xmlWriter) const
 {
-    if (m_command == Result)
+    if (m_command == Result) {
         xmlWriter->writeStartElement("db:result");
-    else
+    } else {
         xmlWriter->writeStartElement("db:verify");
+    }
     helperToXmlAddAttribute(xmlWriter, "id", id());
     helperToXmlAddAttribute(xmlWriter, "to", to());
     helperToXmlAddAttribute(xmlWriter, "from", from());
     helperToXmlAddAttribute(xmlWriter, "type", m_type);
-    if (!m_key.isEmpty())
+    if (!m_key.isEmpty()) {
         xmlWriter->writeCharacters(m_key);
+    }
     xmlWriter->writeEndElement();
 }
 /// \endcond
