@@ -1,25 +1,6 @@
-/*
- * Copyright (C) 2008-2021 The QXmpp developers
- *
- * Author:
- *  Jeremy Lainé
- *
- * Source:
- *  https://github.com/qxmpp-project/qxmpp
- *
- * This file is a part of QXmpp library.
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- */
+// SPDX-FileCopyrightText: 2010 Jeremy Lainé <jeremy.laine@m4x.org>
+//
+// SPDX-License-Identifier: LGPL-2.1-or-later
 
 #include "QXmppIncomingClient.h"
 
@@ -89,10 +70,11 @@ void QXmppIncomingClientPrivate::checkCredentials(const QByteArray &response)
 QString QXmppIncomingClientPrivate::origin() const
 {
     QSslSocket *socket = q->socket();
-    if (socket)
+    if (socket) {
         return socket->peerAddress().toString() + " " + QString::number(socket->peerPort());
-    else
+    } else {
         return "<unknown>";
+    }
 }
 
 /// Constructs a new incoming client stream.
@@ -159,8 +141,9 @@ void QXmppIncomingClient::setInactivityTimeout(int secs)
 {
     d->idleTimer->stop();
     d->idleTimer->setInterval(secs * 1000);
-    if (d->idleTimer->interval())
+    if (d->idleTimer->interval()) {
         d->idleTimer->start();
+    }
 }
 
 /// Sets the password checker used to verify client credentials.
@@ -176,8 +159,9 @@ void QXmppIncomingClient::setPasswordChecker(QXmppPasswordChecker *checker)
 /// \cond
 void QXmppIncomingClient::handleStream(const QDomElement &streamElement)
 {
-    if (d->idleTimer->interval())
+    if (d->idleTimer->interval()) {
         d->idleTimer->start();
+    }
     if (d->saslServer != nullptr) {
         delete d->saslServer;
         d->saslServer = nullptr;
@@ -211,16 +195,18 @@ void QXmppIncomingClient::handleStream(const QDomElement &streamElement)
 
     // send stream features
     QXmppStreamFeatures features;
-    if (socket() && !socket()->isEncrypted() && !socket()->localCertificate().isNull() && !socket()->privateKey().isNull())
+    if (socket() && !socket()->isEncrypted() && !socket()->localCertificate().isNull() && !socket()->privateKey().isNull()) {
         features.setTlsMode(QXmppStreamFeatures::Enabled);
+    }
     if (!d->jid.isEmpty()) {
         features.setBindMode(QXmppStreamFeatures::Required);
         features.setSessionMode(QXmppStreamFeatures::Enabled);
     } else if (d->passwordChecker) {
         QStringList mechanisms;
         mechanisms << "PLAIN";
-        if (d->passwordChecker->hasGetPassword())
+        if (d->passwordChecker->hasGetPassword()) {
             mechanisms << "DIGEST-MD5";
+        }
         features.setAuthMechanisms(mechanisms);
     }
     sendPacket(features);
@@ -230,8 +216,9 @@ void QXmppIncomingClient::handleStanza(const QDomElement &nodeRecv)
 {
     const QString ns = nodeRecv.namespaceURI();
 
-    if (d->idleTimer->interval())
+    if (d->idleTimer->interval()) {
         d->idleTimer->start();
+    }
 
     if (QXmppStartTlsPacket::isStartTlsPacket(nodeRecv, QXmppStartTlsPacket::StartTls)) {
         sendPacket(QXmppStartTlsPacket(QXmppStartTlsPacket::Proceed));
@@ -293,7 +280,7 @@ void QXmppIncomingClient::handleStanza(const QDomElement &nodeRecv)
                 // authentication succeeded
                 d->jid = QString("%1@%2").arg(d->saslServer->username(), d->domain);
                 info(QString("Authentication succeeded for '%1' from %2").arg(d->jid, d->origin()));
-                updateCounter("incoming-client.auth.success");
+                Q_EMIT updateCounter("incoming-client.auth.success");
                 sendPacket(QXmppSaslSuccess());
                 handleStart();
             } else {
@@ -309,8 +296,9 @@ void QXmppIncomingClient::handleStanza(const QDomElement &nodeRecv)
                 QXmppBindIq bindSet;
                 bindSet.parse(nodeRecv);
                 d->resource = bindSet.resource().trimmed();
-                if (d->resource.isEmpty())
+                if (d->resource.isEmpty()) {
                     d->resource = QXmppUtils::generateStanzaHash();
+                }
                 d->jid = QString("%1/%2").arg(QXmppUtils::jidToBareJid(d->jid), d->resource);
 
                 QXmppBindIq bindResult;
@@ -320,7 +308,7 @@ void QXmppIncomingClient::handleStanza(const QDomElement &nodeRecv)
                 sendPacket(bindResult);
 
                 // bound
-                emit connected();
+                Q_EMIT connected();
                 return;
             } else if (QXmppSessionIq::isSessionIq(nodeRecv) && type == QLatin1String("set")) {
                 QXmppSessionIq sessionSet;
@@ -352,18 +340,20 @@ void QXmppIncomingClient::handleStanza(const QDomElement &nodeRecv)
             if (nodeFull.attribute("from").isEmpty()) {
                 if (nodeFull.tagName() == QLatin1String("presence") &&
                     (nodeFull.attribute("type") == QLatin1String("subscribe") ||
-                     nodeFull.attribute("type") == QLatin1String("subscribed")))
+                     nodeFull.attribute("type") == QLatin1String("subscribed"))) {
                     nodeFull.setAttribute("from", QXmppUtils::jidToBareJid(d->jid));
-                else
+                } else {
                     nodeFull.setAttribute("from", d->jid);
+                }
             }
 
             // if the recipient is empty, set it to the local domain
-            if (nodeFull.attribute("to").isEmpty())
+            if (nodeFull.attribute("to").isEmpty()) {
                 nodeFull.setAttribute("to", d->domain);
+            }
 
             // emit stanza for processing by server
-            emit elementReceived(nodeFull);
+            Q_EMIT elementReceived(nodeFull);
         }
     }
 }
@@ -372,13 +362,14 @@ void QXmppIncomingClient::handleStanza(const QDomElement &nodeRecv)
 void QXmppIncomingClient::onDigestReply()
 {
     auto *reply = qobject_cast<QXmppPasswordReply *>(sender());
-    if (!reply)
+    if (!reply) {
         return;
+    }
     reply->deleteLater();
 
     if (reply->error() == QXmppPasswordReply::TemporaryError) {
         warning(QString("Temporary authentication failure for '%1' from %2").arg(d->saslServer->username(), d->origin()));
-        updateCounter("incoming-client.auth.temporary-auth-failure");
+        Q_EMIT updateCounter("incoming-client.auth.temporary-auth-failure");
         sendPacket(QXmppSaslFailure("temporary-auth-failure"));
         disconnectFromHost();
         return;
@@ -390,7 +381,7 @@ void QXmppIncomingClient::onDigestReply()
     QXmppSaslServer::Response result = d->saslServer->respond(reply->property("__sasl_raw").toByteArray(), challenge);
     if (result != QXmppSaslServer::Challenge) {
         warning(QString("Authentication failed for '%1' from %2").arg(d->saslServer->username(), d->origin()));
-        updateCounter("incoming-client.auth.not-authorized");
+        Q_EMIT updateCounter("incoming-client.auth.not-authorized");
         sendPacket(QXmppSaslFailure("not-authorized"));
         disconnectFromHost();
         return;
@@ -403,8 +394,9 @@ void QXmppIncomingClient::onDigestReply()
 void QXmppIncomingClient::onPasswordReply()
 {
     auto *reply = qobject_cast<QXmppPasswordReply *>(sender());
-    if (!reply)
+    if (!reply) {
         return;
+    }
     reply->deleteLater();
 
     const QString jid = QString("%1@%2").arg(d->saslServer->username(), d->domain);
@@ -412,19 +404,19 @@ void QXmppIncomingClient::onPasswordReply()
     case QXmppPasswordReply::NoError:
         d->jid = jid;
         info(QString("Authentication succeeded for '%1' from %2").arg(d->jid, d->origin()));
-        updateCounter("incoming-client.auth.success");
+        Q_EMIT updateCounter("incoming-client.auth.success");
         sendPacket(QXmppSaslSuccess());
         handleStart();
         break;
     case QXmppPasswordReply::AuthorizationError:
         warning(QString("Authentication failed for '%1' from %2").arg(jid, d->origin()));
-        updateCounter("incoming-client.auth.not-authorized");
+        Q_EMIT updateCounter("incoming-client.auth.not-authorized");
         sendPacket(QXmppSaslFailure("not-authorized"));
         disconnectFromHost();
         break;
     case QXmppPasswordReply::TemporaryError:
         warning(QString("Temporary authentication failure for '%1' from %2").arg(jid, d->origin()));
-        updateCounter("incoming-client.auth.temporary-auth-failure");
+        Q_EMIT updateCounter("incoming-client.auth.temporary-auth-failure");
         sendPacket(QXmppSaslFailure("temporary-auth-failure"));
         disconnectFromHost();
         break;
@@ -434,7 +426,7 @@ void QXmppIncomingClient::onPasswordReply()
 void QXmppIncomingClient::onSocketDisconnected()
 {
     info(QString("Socket disconnected for '%1' from %2").arg(d->jid, d->origin()));
-    emit disconnected();
+    Q_EMIT disconnected();
 }
 
 void QXmppIncomingClient::onTimeout()
