@@ -1,25 +1,6 @@
-/*
- * Copyright (C) 2008-2021 The QXmpp developers
- *
- * Author:
- *  Jeremy Lainé
- *
- * Source:
- *  https://github.com/qxmpp-project/qxmpp
- *
- * This file is a part of QXmpp library.
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- */
+// SPDX-FileCopyrightText: 2010 Jeremy Lainé <jeremy.laine@m4x.org>
+//
+// SPDX-License-Identifier: LGPL-2.1-or-later
 
 #include "QXmppIncomingServer.h"
 
@@ -57,10 +38,11 @@ QXmppIncomingServerPrivate::QXmppIncomingServerPrivate(QXmppIncomingServer *qq)
 QString QXmppIncomingServerPrivate::origin() const
 {
     QSslSocket *socket = q->socket();
-    if (socket)
+    if (socket) {
         return socket->peerAddress().toString() + " " + QString::number(socket->peerPort());
-    else
+    } else {
         return "<unknown>";
+    }
 }
 
 /// Constructs a new incoming server stream.
@@ -106,8 +88,9 @@ QString QXmppIncomingServer::localStreamId() const
 void QXmppIncomingServer::handleStream(const QDomElement &streamElement)
 {
     const QString from = streamElement.attribute("from");
-    if (!from.isEmpty())
+    if (!from.isEmpty()) {
         info(QString("Incoming server stream from %1 on %2").arg(from, d->origin()));
+    }
 
     // start stream
     d->localStreamId = QXmppUtils::generateStanzaHash().toLatin1();
@@ -123,15 +106,14 @@ void QXmppIncomingServer::handleStream(const QDomElement &streamElement)
 
     // send stream features
     QXmppStreamFeatures features;
-    if (!socket()->isEncrypted() && !socket()->localCertificate().isNull() && !socket()->privateKey().isNull())
+    if (!socket()->isEncrypted() && !socket()->localCertificate().isNull() && !socket()->privateKey().isNull()) {
         features.setTlsMode(QXmppStreamFeatures::Enabled);
+    }
     sendPacket(features);
 }
 
 void QXmppIncomingServer::handleStanza(const QDomElement &stanza)
 {
-    const QString ns = stanza.namespaceURI();
-
     if (QXmppStartTlsPacket::isStartTlsPacket(stanza, QXmppStartTlsPacket::StartTls)) {
         sendPacket(QXmppStartTlsPacket(QXmppStartTlsPacket::Proceed));
         socket()->flush();
@@ -161,12 +143,12 @@ void QXmppIncomingServer::handleStanza(const QDomElement &stanza)
             stream->connectToHost(domain);
         } else if (request.command() == QXmppDialback::Verify) {
             debug(QString("Received a dialback verify from '%1' on %2").arg(domain, d->origin()));
-            emit dialbackRequestReceived(request);
+            Q_EMIT dialbackRequestReceived(request);
         }
 
     } else if (d->authenticated.contains(QXmppUtils::jidToDomain(stanza.attribute("from")))) {
         // relay stanza if the remote party is authenticated
-        emit elementReceived(stanza);
+        Q_EMIT elementReceived(stanza);
     } else {
         warning(QString("Received an element from unverified domain '%1' on %2").arg(QXmppUtils::jidToDomain(stanza.attribute("from")), d->origin()));
         disconnectFromHost();
@@ -194,8 +176,9 @@ void QXmppIncomingServer::slotDialbackResponseReceived(const QXmppDialback &dial
     if (!stream ||
         dialback.command() != QXmppDialback::Verify ||
         dialback.id() != d->localStreamId ||
-        dialback.from() != stream->remoteDomain())
+        dialback.from() != stream->remoteDomain()) {
         return;
+    }
 
     // relay verify response
     QXmppDialback response;
@@ -210,8 +193,9 @@ void QXmppIncomingServer::slotDialbackResponseReceived(const QXmppDialback &dial
         info(QString("Verified incoming domain '%1' on %2").arg(dialback.from(), d->origin()));
         const bool wasConnected = !d->authenticated.isEmpty();
         d->authenticated.insert(dialback.from());
-        if (!wasConnected)
-            emit connected();
+        if (!wasConnected) {
+            Q_EMIT connected();
+        }
     } else {
         warning(QString("Failed to verify incoming domain '%1' on %2").arg(dialback.from(), d->origin()));
         disconnectFromHost();
@@ -225,5 +209,5 @@ void QXmppIncomingServer::slotDialbackResponseReceived(const QXmppDialback &dial
 void QXmppIncomingServer::slotSocketDisconnected()
 {
     info(QString("Socket disconnected from %1").arg(d->origin()));
-    emit disconnected();
+    Q_EMIT disconnected();
 }
