@@ -1,25 +1,6 @@
-/*
- * Copyright (C) 2008-2021 The QXmpp developers
- *
- * Author:
- *  Jeremy Lainé
- *
- * Source:
- *  https://github.com/qxmpp-project/qxmpp
- *
- * This file is a part of QXmpp library.
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- */
+// SPDX-FileCopyrightText: 2011 Jeremy Lainé <jeremy.laine@m4x.org>
+//
+// SPDX-License-Identifier: LGPL-2.1-or-later
 
 #include "QXmppPasswordChecker.h"
 
@@ -121,7 +102,7 @@ void QXmppPasswordReply::setError(QXmppPasswordReply::Error error)
 void QXmppPasswordReply::finish()
 {
     m_isFinished = true;
-    emit finished();
+    Q_EMIT finished();
 }
 
 /// Delay marking reply as finished.
@@ -167,8 +148,9 @@ QXmppPasswordReply *QXmppPasswordChecker::checkPassword(const QXmppPasswordReque
     QString secret;
     QXmppPasswordReply::Error error = getPassword(request, secret);
     if (error == QXmppPasswordReply::NoError) {
-        if (request.password() != secret)
+        if (request.password() != secret) {
             reply->setError(QXmppPasswordReply::AuthorizationError);
+        }
     } else {
         reply->setError(error);
     }
