@@ -1,25 +1,6 @@
-/*
- * Copyright (C) 2008-2021 The QXmpp developers
- *
- * Author:
- *  Jeremy Lainé
- *
- * Source:
- *  https://github.com/qxmpp-project/qxmpp
- *
- * This file is a part of QXmpp library.
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- */
+// SPDX-FileCopyrightText: 2010 Jeremy Lainé <jeremy.laine@m4x.org>
+//
+// SPDX-License-Identifier: LGPL-2.1-or-later
 
 #include "QXmppServer.h"
 
@@ -49,8 +30,9 @@ static void helperToXmlAddDomElement(QXmlStreamWriter *stream, const QDomElement
 
     /* attributes */
     QString xmlns = element.namespaceURI();
-    if (!xmlns.isEmpty() && !omitNamespaces.contains(xmlns))
+    if (!xmlns.isEmpty() && !omitNamespaces.contains(xmlns)) {
         stream->writeDefaultNamespace(xmlns);
+    }
     QDomNamedNodeMap attrs = element.attributes();
     for (int i = 0; i < attrs.size(); i++) {
         QDomAttr attr = attrs.item(i).toAttr();
@@ -128,31 +110,35 @@ bool QXmppServerPrivate::routeData(const QString &to, const QByteArray &data)
 {
     // refuse to route packets to empty destination, own domain or sub-domains
     const QString toDomain = QXmppUtils::jidToDomain(to);
-    if (to.isEmpty() || to == domain || toDomain.endsWith("." + domain))
+    if (to.isEmpty() || to == domain || toDomain.endsWith("." + domain)) {
         return false;
+    }
 
     if (toDomain == domain) {
         // look for a client connection
         QList<QXmppIncomingClient *> found;
         if (QXmppUtils::jidToResource(to).isEmpty()) {
             const auto &connections = incomingClientsByBareJid.value(to);
-            for (auto *conn : connections)
+            for (auto *conn : connections) {
                 found << conn;
+            }
         } else {
             QXmppIncomingClient *conn = incomingClientsByJid.value(to);
-            if (conn)
+            if (conn) {
                 found << conn;
+            }
         }
 
         // send data
-        for (auto *conn : found)
+        for (auto *conn : std::as_const(found)) {
             QMetaObject::invokeMethod(conn, "sendData", Q_ARG(QByteArray, data));
+        }
         return !found.isEmpty();
 
     } else if (!serversForServers.isEmpty()) {
 
         // look for an outgoing S2S connection
-        for (auto *conn : qAsConst(outgoingServers)) {
+        for (auto *conn : std::as_const(outgoingServers)) {
             if (conn->remoteDomain() == toDomain) {
                 // send or queue data
                 QMetaObject::invokeMethod(conn, "queueData", Q_ARG(QByteArray, data));
@@ -172,7 +158,7 @@ bool QXmppServerPrivate::routeData(const QString &to, const QByteArray &data)
 
         // add stream
         outgoingServers.insert(conn);
-        q->setGauge("outgoing-server.count", outgoingServers.size());
+        Q_EMIT q->setGauge("outgoing-server.count", outgoingServers.size());
 
         // queue data and connect to remote server
         QMetaObject::invokeMethod(conn, "queueData", Q_ARG(QByteArray, data));
@@ -196,9 +182,11 @@ static void handleStanza(QXmppServer *server, const QDomElement &element)
 {
     // try extensions
     const auto &extensions = server->extensions();
-    for (auto *extension : extensions)
-        if (extension->handleStanza(element))
+    for (auto *extension : extensions) {
+        if (extension->handleStanza(element)) {
             return;
+        }
+    }
 
     // default handlers
     const QString domain = server->domain();
@@ -242,14 +230,16 @@ static void handleStanza(QXmppServer *server, const QDomElement &element)
 
 void QXmppServerPrivate::info(const QString &message)
 {
-    if (logger)
+    if (logger) {
         logger->log(QXmppLogger::InformationMessage, message);
+    }
 }
 
 void QXmppServerPrivate::warning(const QString &message)
 {
-    if (logger)
+    if (logger) {
         logger->log(QXmppLogger::WarningMessage, message);
+    }
 }
 
 /// Load the server's extensions.
@@ -259,14 +249,17 @@ void QXmppServerPrivate::warning(const QString &message)
 void QXmppServerPrivate::loadExtensions(QXmppServer *server)
 {
     if (!loaded) {
-        for (auto *object : QPluginLoader::staticInstances()) {
+        const auto pluginLoaders = QPluginLoader::staticInstances();
+        for (auto *object : pluginLoaders) {
             auto *plugin = qobject_cast<QXmppServerPlugin *>(object);
-            if (!plugin)
+            if (!plugin) {
                 continue;
+            }
 
             const auto &keys = plugin->keys();
-            for (const auto &key : keys)
+            for (const auto &key : keys) {
                 server->addExtension(plugin->create(key));
+            }
         }
         loaded = true;
     }
@@ -277,9 +270,11 @@ void QXmppServerPrivate::loadExtensions(QXmppServer *server)
 void QXmppServerPrivate::startExtensions()
 {
     if (!started) {
-        for (auto *extension : extensions)
-            if (!extension->start())
+        for (auto *extension : std::as_const(extensions)) {
+            if (!extension->start()) {
                 warning(QString("Could not start extension %1").arg(extension->extensionName()));
+            }
+        }
         started = true;
     }
 }
@@ -290,8 +285,9 @@ void QXmppServerPrivate::startExtensions()
 void QXmppServerPrivate::stopExtensions()
 {
     if (started) {
-        for (int i = extensions.size() - 1; i >= 0; --i)
+        for (int i = extensions.size() - 1; i >= 0; --i) {
             extensions[i]->stop();
+        }
         started = false;
     }
 }
@@ -321,8 +317,9 @@ QXmppServer::~QXmppServer()
 
 void QXmppServer::addExtension(QXmppServerExtension *extension)
 {
-    if (!extension || d->extensions.contains(extension))
+    if (!extension || d->extensions.contains(extension)) {
         return;
+    }
     d->info(QString("Added extension %1").arg(extension->extensionName()));
     extension->setParent(this);
     extension->setServer(this);
@@ -395,7 +392,7 @@ void QXmppServer::setLogger(QXmppLogger *logger)
                     d->logger, &QXmppLogger::updateCounter);
         }
 
-        emit loggerChanged(d->logger);
+        Q_EMIT loggerChanged(d->logger);
     }
 }
 
@@ -446,8 +443,12 @@ void QXmppServer::addCaCertificates(const QString &path)
     }
 
     // reconfigure servers
-    for (auto *server : d->serversForClients + d->serversForServers)
+    for (auto *server : std::as_const(d->serversForClients)) {
         server->addCaCertificates(d->caCertificates);
+    }
+    for (auto *server : std::as_const(d->serversForServers)) {
+        server->addCaCertificates(d->caCertificates);
+    }
 }
 
 /// Sets the path for the local SSL certificate.
@@ -469,8 +470,12 @@ void QXmppServer::setLocalCertificate(const QString &path)
     }
 
     // reconfigure servers
-    for (auto *server : d->serversForClients + d->serversForServers)
+    for (auto *server : std::as_const(d->serversForClients)) {
         server->setLocalCertificate(d->localCertificate);
+    }
+    for (auto *server : std::as_const(d->serversForServers)) {
+        server->setLocalCertificate(d->localCertificate);
+    }
 }
 
 ///
@@ -485,8 +490,12 @@ void QXmppServer::setLocalCertificate(const QSslCertificate &certificate)
     d->localCertificate = certificate;
 
     // reconfigure servers
-    for (auto *server : d->serversForClients + d->serversForServers)
+    for (auto *server : std::as_const(d->serversForClients)) {
         server->setLocalCertificate(d->localCertificate);
+    }
+    for (auto *server : std::as_const(d->serversForServers)) {
+        server->setLocalCertificate(d->localCertificate);
+    }
 }
 
 /// Sets the path for the local SSL private key.
@@ -508,8 +517,12 @@ void QXmppServer::setPrivateKey(const QString &path)
     }
 
     // reconfigure servers
-    for (auto *server : d->serversForClients + d->serversForServers)
+    for (auto *server : std::as_const(d->serversForClients)) {
         server->setPrivateKey(d->privateKey);
+    }
+    for (auto *server : std::as_const(d->serversForServers)) {
+        server->setPrivateKey(d->privateKey);
+    }
 }
 
 ///
@@ -524,8 +537,12 @@ void QXmppServer::setPrivateKey(const QSslKey &key)
     d->privateKey = key;
 
     // reconfigure servers
-    for (auto *server : d->serversForClients + d->serversForServers)
+    for (auto *server : std::as_const(d->serversForClients)) {
         server->setPrivateKey(d->privateKey);
+    }
+    for (auto *server : std::as_const(d->serversForServers)) {
+        server->setPrivateKey(d->privateKey);
+    }
 }
 
 /// Listen for incoming XMPP client connections.
@@ -572,10 +589,14 @@ bool QXmppServer::listenForClients(const QHostAddress &address, quint16 port)
 void QXmppServer::close()
 {
     // prevent new connections
-    for (auto *server : d->serversForClients + d->serversForServers) {
+    for (auto *server : std::as_const(d->serversForClients)) {
         server->close();
-        delete server;
     }
+    for (auto *server : std::as_const(d->serversForServers)) {
+        server->close();
+    }
+    qDeleteAll(d->serversForClients);
+    qDeleteAll(d->serversForServers);
     d->serversForClients.clear();
     d->serversForServers.clear();
 
@@ -584,12 +605,15 @@ void QXmppServer::close()
 
     // close XMPP streams
     QSetIterator<QXmppIncomingClient *> itr(d->incomingClients);
-    while (itr.hasNext())
+    while (itr.hasNext()) {
         itr.next()->disconnectFromHost();
-    for (auto *stream : d->incomingServers)
+    }
+    for (auto *stream : std::as_const(d->incomingServers)) {
         stream->disconnectFromHost();
-    for (auto *stream : d->outgoingServers)
+    }
+    for (auto *stream : std::as_const(d->outgoingServers)) {
         stream->disconnectFromHost();
+    }
 }
 
 /// Listen for incoming XMPP server connections.
@@ -682,7 +706,7 @@ void QXmppServer::addIncomingClient(QXmppIncomingClient *stream)
 
     // add stream
     d->incomingClients.insert(stream);
-    setGauge("incoming-client.count", d->incomingClients.size());
+    Q_EMIT setGauge("incoming-client.count", d->incomingClients.size());
 }
 
 /// Handle a new incoming TCP connection from a client.
@@ -709,8 +733,9 @@ void QXmppServer::_q_clientConnection(QSslSocket *socket)
 void QXmppServer::_q_clientConnected()
 {
     auto *client = qobject_cast<QXmppIncomingClient *>(sender());
-    if (!client)
+    if (!client) {
         return;
+    }
 
     // FIXME: at this point the JID must contain a resource, assert it?
     const QString jid = client->jid();
@@ -725,7 +750,7 @@ void QXmppServer::_q_clientConnected()
     d->incomingClientsByBareJid[QXmppUtils::jidToBareJid(jid)].insert(client);
 
     // emit signal
-    emit clientConnected(jid);
+    Q_EMIT clientConnected(jid);
 }
 
 /// Handle a stream disconnection for a client.
@@ -733,20 +758,23 @@ void QXmppServer::_q_clientConnected()
 void QXmppServer::_q_clientDisconnected()
 {
     auto *client = qobject_cast<QXmppIncomingClient *>(sender());
-    if (!client)
+    if (!client) {
         return;
+    }
 
     if (d->incomingClients.remove(client)) {
         // remove stream from routing tables
         const QString jid = client->jid();
         if (!jid.isEmpty()) {
-            if (d->incomingClientsByJid.value(jid) == client)
+            if (d->incomingClientsByJid.value(jid) == client) {
                 d->incomingClientsByJid.remove(jid);
+            }
             const QString bareJid = QXmppUtils::jidToBareJid(jid);
             if (d->incomingClientsByBareJid.contains(bareJid)) {
                 d->incomingClientsByBareJid[bareJid].remove(client);
-                if (d->incomingClientsByBareJid[bareJid].isEmpty())
+                if (d->incomingClientsByBareJid[bareJid].isEmpty()) {
                     d->incomingClientsByBareJid.remove(bareJid);
+                }
             }
         }
 
@@ -754,25 +782,28 @@ void QXmppServer::_q_clientDisconnected()
         client->deleteLater();
 
         // emit signal
-        if (!jid.isEmpty())
-            emit clientDisconnected(jid);
+        if (!jid.isEmpty()) {
+            Q_EMIT clientDisconnected(jid);
+        }
 
         // update counter
-        setGauge("incoming-client.count", d->incomingClients.size());
+        Q_EMIT setGauge("incoming-client.count", d->incomingClients.size());
     }
 }
 
 void QXmppServer::_q_dialbackRequestReceived(const QXmppDialback &dialback)
 {
     auto *stream = qobject_cast<QXmppIncomingServer *>(sender());
-    if (!stream)
+    if (!stream) {
         return;
+    }
 
     if (dialback.command() == QXmppDialback::Verify) {
         // handle a verify request
-        for (auto *out : qAsConst(d->outgoingServers)) {
-            if (out->remoteDomain() != dialback.from())
+        for (auto *out : std::as_const(d->outgoingServers)) {
+            if (out->remoteDomain() != dialback.from()) {
                 continue;
+            }
 
             bool isValid = dialback.key() == out->localStreamKey();
             QXmppDialback verify;
@@ -799,12 +830,13 @@ void QXmppServer::handleElement(const QDomElement &element)
 void QXmppServer::_q_outgoingServerDisconnected()
 {
     auto *outgoing = qobject_cast<QXmppOutgoingServer *>(sender());
-    if (!outgoing)
+    if (!outgoing) {
         return;
+    }
 
     if (d->outgoingServers.remove(outgoing)) {
         outgoing->deleteLater();
-        setGauge("outgoing-server.count", d->outgoingServers.size());
+        Q_EMIT setGauge("outgoing-server.count", d->outgoingServers.size());
     }
 }
 
@@ -835,7 +867,7 @@ void QXmppServer::_q_serverConnection(QSslSocket *socket)
 
     // add stream
     d->incomingServers.insert(stream);
-    setGauge("incoming-server.count", d->incomingServers.size());
+    Q_EMIT setGauge("incoming-server.count", d->incomingServers.size());
 }
 
 /// Handle a stream disconnection for an incoming server.
@@ -843,12 +875,13 @@ void QXmppServer::_q_serverConnection(QSslSocket *socket)
 void QXmppServer::_q_serverDisconnected()
 {
     auto *incoming = qobject_cast<QXmppIncomingServer *>(sender());
-    if (!incoming)
+    if (!incoming) {
         return;
+    }
 
     if (d->incomingServers.remove(incoming)) {
         incoming->deleteLater();
-        setGauge("incoming-server.count", d->incomingServers.size());
+        Q_EMIT setGauge("incoming-server.count", d->incomingServers.size());
     }
 }
 
@@ -895,7 +928,7 @@ void QXmppSslServer::incomingConnection(qintptr socketDescriptor)
         socket->setLocalCertificate(d->localCertificate);
         socket->setPrivateKey(d->privateKey);
     }
-    emit newConnection(socket);
+    Q_EMIT newConnection(socket);
 }
 
 /// Adds the given certificates to the CA certificate database to be used
