@@ -1,53 +1,36 @@
-/*
- * Copyright (C) 2008-2021 The QXmpp developers
- *
- * Authors:
- *  Linus Jahn
- *
- * Source:
- *  https://github.com/qxmpp-project/qxmpp
- *
- * This file is a part of QXmpp library.
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- */
+// SPDX-FileCopyrightText: 2019 Linus Jahn <lnj@kaidan.im>
+//
+// SPDX-License-Identifier: LGPL-2.1-or-later
 
 #include "QXmppBitsOfBinaryContentId.h"
 
 #include "util.h"
 #include <QObject>
 
+Q_DECLARE_METATYPE(QCryptographicHash::Algorithm)
+
 class tst_QXmppBitsOfBinaryContentId : public QObject
 {
     Q_OBJECT
 
-private slots:
-    void testBasic();
+private:
+    Q_SLOT void testBasic();
 
-    void testFromContentId_data();
-    void testFromContentId();
+    Q_SLOT void testFromContentId_data();
+    Q_SLOT void testFromContentId();
 
-    void testFromCidUrl_data();
-    void testFromCidUrl();
+    Q_SLOT void testFromCidUrl_data();
+    Q_SLOT void testFromCidUrl();
 
-    void testEmpty();
+    Q_SLOT void testEmpty();
 
-    void testIsValid_data();
-    void testIsValid();
+    Q_SLOT void testIsValid_data();
+    Q_SLOT void testIsValid();
 
-    void testIsBobContentId_data();
-    void testIsBobContentId();
+    Q_SLOT void testIsBobContentId_data();
+    Q_SLOT void testIsBobContentId();
 
-    void testUnsupportedAlgorithm();
+    Q_SLOT void testUnsupportedAlgorithm();
 };
 
 void tst_QXmppBitsOfBinaryContentId::testBasic()
