@@ -1,27 +1,8 @@
-/*
- * Copyright (C) 2008-2021 The QXmpp developers
- *
- * Authors:
- *  Andrey Batyiev
- *  Jeremy Lainé
- *  Linus Jahn
- *
- * Source:
- *  https://github.com/qxmpp-project/qxmpp
- *
- * This file is a part of QXmpp library.
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- */
+// SPDX-FileCopyrightText: 2012 Andrey Batyiev
+// SPDX-FileCopyrightText: 2012 Jeremy Lainé <jeremy.laine@m4x.org>
+// SPDX-FileCopyrightText: 2019 Linus Jahn <lnj@kaidan.im>
+//
+// SPDX-License-Identifier: LGPL-2.1-or-later
 
 #include <QObject>
 #include <QtGlobal>
@@ -38,11 +19,12 @@ class tst_QXmppDataForm : public QObject
 {
     Q_OBJECT
 
-private slots:
-    void testSimple();
-    void testSubmit();
-    void testMedia();
-    void testMediaSource();
+private:
+    Q_SLOT void testSimple();
+    Q_SLOT void testSubmit();
+    Q_SLOT void testMedia();
+    Q_SLOT void testMediaSource();
+    Q_SLOT void testFormType();
 };
 
 void tst_QXmppDataForm::testSimple()
@@ -62,6 +44,7 @@ void tst_QXmppDataForm::testSimple()
     QCOMPARE(form.isNull(), false);
     QCOMPARE(form.title(), QLatin1String("Joggle Search"));
     QCOMPARE(form.instructions(), QLatin1String("Fill out this form to search for information!"));
+    QVERIFY(form.formType().isNull());
     QCOMPARE(form.fields().size(), 1);
     QCOMPARE(form.fields().at(0).type(), QXmppDataForm::Field::TextSingleField);
     QCOMPARE(form.fields().at(0).isRequired(), true);
@@ -211,5 +194,27 @@ void tst_QXmppDataForm::testMediaSource()
     QCOMPARE(source.contentType(), QMimeDatabase().mimeTypeForName("application/xml"));
 }
 
+void tst_QXmppDataForm::testFormType()
+{
+    const auto xml = QByteArrayLiteral(R"(<x xmlns='jabber:x:data' type='submit'>
+    <field var='FORM_TYPE' type='hidden'>
+        <value>http://jabber.org/protocol/pubsub#subscribe_options</value>
+    </field>
+    <field var='pubsub#deliver'><value>1</value></field>
+    <field var='pubsub#digest'><value>0</value></field>
+    <field var='pubsub#include_body'><value>false</value></field>
+    <field var='pubsub#show-values'>
+        <value>chat</value>
+        <value>online</value>
+        <value>away</value>
+    </field>
+</x>)");
+
+    QXmppDataForm form;
+    parsePacket(form, xml);
+
+    QCOMPARE(form.formType(), QStringLiteral("http://jabber.org/protocol/pubsub#subscribe_options"));
+}
+
 QTEST_MAIN(tst_QXmppDataForm)
 #include "tst_qxmppdataform.moc"
