@@ -1,25 +1,6 @@
-/*
- * Copyright (C) 2008-2021 The QXmpp developers
- *
- * Author:
- *  Linus Jahn <lnj@kaidan.im>
- *
- * Source:
- *  https://github.com/qxmpp-project/qxmpp
- *
- * This file is a part of QXmpp library.
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- */
+// SPDX-FileCopyrightText: 2019 Linus Jahn <lnj@kaidan.im>
+//
+// SPDX-License-Identifier: LGPL-2.1-or-later
 
 #include "QXmppHttpUploadIq.h"
 
@@ -30,13 +11,13 @@ class tst_QXmppHttpUploadIq : public QObject
 {
     Q_OBJECT
 
-private slots:
-    void testRequest();
-    void testIsRequest_data();
-    void testIsRequest();
-    void testSlot();
-    void testIsSlot_data();
-    void testIsSlot();
+private:
+    Q_SLOT void testRequest();
+    Q_SLOT void testIsRequest_data();
+    Q_SLOT void testIsRequest();
+    Q_SLOT void testSlot();
+    Q_SLOT void testIsSlot_data();
+    Q_SLOT void testIsSlot();
 };
 
 void tst_QXmppHttpUploadIq::testRequest()
@@ -93,7 +74,7 @@ void tst_QXmppHttpUploadIq::testIsRequest()
     QFETCH(bool, isRequest);
 
     QDomDocument doc;
-    QCOMPARE(doc.setContent(xml, true), true);
+    QVERIFY(doc.setContent(xml, true));
     QCOMPARE(QXmppHttpUploadRequestIq::isHttpUploadRequestIq(doc.documentElement()), isRequest);
 }
 
@@ -162,7 +143,7 @@ void tst_QXmppHttpUploadIq::testIsSlot()
     QFETCH(bool, isSlot);
 
     QDomDocument doc;
-    QCOMPARE(doc.setContent(xml, true), true);
+    QVERIFY(doc.setContent(xml, true));
     QCOMPARE(QXmppHttpUploadSlotIq::isHttpUploadSlotIq(doc.documentElement()), isSlot);
 }
 
