@@ -1,25 +1,6 @@
-/*
- * Copyright (C) 2008-2021 The QXmpp developers
- *
- * Author:
- *  Jeremy Lainé
- *
- * Source:
- *  https://github.com/qxmpp-project/qxmpp
- *
- * This file is a part of QXmpp library.
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- */
+// SPDX-FileCopyrightText: 2015 Jeremy Lainé <jeremy.laine@m4x.org>
+//
+// SPDX-License-Identifier: LGPL-2.1-or-later
 
 #include "QXmppStun.h"
 
@@ -30,10 +11,10 @@ class tst_QXmppIceConnection : public QObject
 {
     Q_OBJECT
 
-private slots:
-    void testBind();
-    void testBindStun();
-    void testConnect();
+private:
+    Q_SLOT void testBind();
+    Q_SLOT void testBindStun();
+    Q_SLOT void testConnect();
 };
 
 void tst_QXmppIceConnection::testBind()
@@ -80,7 +61,7 @@ void tst_QXmppIceConnection::testBindStun()
     client.setIceControlling(true);
     QList<QPair<QHostAddress, quint16>> stunServers;
     for (auto &address : stunInfo.addresses()) {
-        stunServers.push_back({address, 19302});
+        stunServers.push_back({ address, 19302 });
     }
     client.setStunServers(stunServers);
     client.addComponent(componentId);
@@ -104,10 +85,11 @@ void tst_QXmppIceConnection::testBindStun()
     const auto &localCandidates = client.localCandidates();
     for (const auto &c : localCandidates) {
         QCOMPARE(c.component(), componentId);
-        if (c.type() == QXmppJingleCandidate::ServerReflexiveType)
+        if (c.type() == QXmppJingleCandidate::ServerReflexiveType) {
             foundReflexive = true;
-        else
+        } else {
             QCOMPARE(c.type(), QXmppJingleCandidate::HostType);
+        }
     }
     QVERIFY(foundReflexive);
 }
@@ -141,11 +123,13 @@ void tst_QXmppIceConnection::testConnect()
 
     // exchange candidates
     const auto &rLocalCandidates = clientR.localCandidates();
-    for (const auto &candidate : rLocalCandidates)
+    for (const auto &candidate : rLocalCandidates) {
         clientL.addRemoteCandidate(candidate);
+    }
     const auto &lLocalCandidates = clientL.localCandidates();
-    for (const auto &candidate : lLocalCandidates)
+    for (const auto &candidate : lLocalCandidates) {
         clientR.addRemoteCandidate(candidate);
+    }
 
     // start ICE
     QEventLoop loop;
