@@ -1,31 +1,17 @@
-/*
- * Copyright (C) 2008-2021 The QXmpp developers
- *
- * Authors:
- *  Jeremy Lainé
- *  Manjeet Dahiya
- *
- * Source:
- *  https://github.com/qxmpp-project/qxmpp
- *
- * This file is a part of QXmpp library.
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- */
+// SPDX-FileCopyrightText: 2012 Jeremy Lainé <jeremy.laine@m4x.org>
+// SPDX-FileCopyrightText: 2012 Manjeet Dahiya <manjeetdahiya@gmail.com>
+// SPDX-FileCopyrightText: 2021 Melvin Keskin <melvo@olomono.de>
+//
+// SPDX-License-Identifier: LGPL-2.1-or-later
 
 #include "QXmppBitsOfBinaryContentId.h"
 #include "QXmppBitsOfBinaryDataList.h"
+#include "QXmppEncryptedFileSource.h"
 #include "QXmppMessage.h"
+#include "QXmppMessageReaction.h"
 #include "QXmppMixInvitation.h"
+#include "QXmppOutOfBandUrl.h"
+#include "QXmppTrustMessageElement.h"
 
 #include <optional>
 
@@ -36,37 +22,42 @@ class tst_QXmppMessage : public QObject
 {
     Q_OBJECT
 
-private slots:
-    void testBasic_data();
-    void testBasic();
-    void testIsXmppStanza();
-    void testUnknownXExtension();
-    void testMessageAttention();
-    void testMessageReceipt();
-    void testDelay_data();
-    void testDelay();
-    void testDelayWithMultipleStamp();
-    void testExtendedAddresses();
-    void testMucInvitation();
-    void testState_data();
-    void testState();
-    void testXhtml();
-    void testSubextensions();
-    void testChatMarkers();
-    void testPrivateMessage();
-    void testOutOfBandUrl();
-    void testMessageCorrect();
-    void testMessageAttaching();
-    void testMix();
-    void testEme();
-    void testSpoiler();
-    void testProcessingHints();
-    void testBobData();
-    void testFallbackIndication();
-    void testStanzaIds();
-    void testSlashMe_data();
-    void testSlashMe();
-    void testMixInvitation();
+private:
+    Q_SLOT void testBasic_data();
+    Q_SLOT void testBasic();
+    Q_SLOT void testIsXmppStanza();
+    Q_SLOT void testUnknownXExtension();
+    Q_SLOT void testMessageAttention();
+    Q_SLOT void testMessageReceipt();
+    Q_SLOT void testDelay_data();
+    Q_SLOT void testDelay();
+    Q_SLOT void testDelayWithMultipleStamp();
+    Q_SLOT void testExtendedAddresses();
+    Q_SLOT void testMucInvitation();
+    Q_SLOT void testState_data();
+    Q_SLOT void testState();
+    Q_SLOT void testXhtml();
+    Q_SLOT void testSubextensions();
+    Q_SLOT void testChatMarkers();
+    Q_SLOT void testPrivateMessage();
+    Q_SLOT void testOutOfBandUrl();
+    Q_SLOT void testMessageCorrect();
+    Q_SLOT void testMessageAttaching();
+    Q_SLOT void testMix();
+    Q_SLOT void testEme();
+    Q_SLOT void testSpoiler();
+    Q_SLOT void testProcessingHints();
+    Q_SLOT void testBobData();
+    Q_SLOT void testFallbackIndication();
+    Q_SLOT void testStanzaIds();
+    Q_SLOT void testSlashMe_data();
+    Q_SLOT void testSlashMe();
+    Q_SLOT void testMixInvitation();
+    Q_SLOT void testTrustMessageElement();
+    Q_SLOT void testReaction();
+    Q_SLOT void testE2eeFallbackBody();
+    Q_SLOT void testFileSharing();
+    Q_SLOT void testEncryptedFileSource();
 };
 
 void tst_QXmppMessage::testBasic_data()
@@ -148,7 +139,7 @@ void tst_QXmppMessage::testBasic()
     QCOMPARE(message.isReceiptRequested(), false);
     QCOMPARE(message.receiptId(), QString());
     QCOMPARE(message.xhtml(), QString());
-    QCOMPARE(message.encryptionMethod(), QXmppMessage::NoEncryption);
+    QCOMPARE(message.encryptionMethod(), QXmpp::NoEncryption);
     QVERIFY(!message.isSpoiler());
     QVERIFY(!message.hasHint(QXmppMessage::NoPermanentStore));
     QVERIFY(!message.hasHint(QXmppMessage::NoStore));
@@ -219,7 +210,7 @@ void tst_QXmppMessage::testMessageReceipt()
 {
     const QByteArray xml(
         "<message id=\"richard2-4.1.247\" to=\"kingrichard@royalty.england.lit/throne\" from=\"northumberland@shakespeare.lit/westminster\" type=\"normal\">"
-        "<body>My lord, dispatch; read o'er these articles.</body>"
+        "<body>My lord, dispatch; read o&apos;er these articles.</body>"
         "<request xmlns=\"urn:xmpp:receipts\"/>"
         "</message>");
 
@@ -467,7 +458,7 @@ void tst_QXmppMessage::testSubextensions()
         "id=\"8a54s\" "
         "to=\"romeo@montague.lit/orchard\" "
         "type=\"chat\">"
-        "<body>What man art thou that thus bescreen'd in night so stumblest on my counsel?</body>"
+        "<body>What man art thou that thus bescreen&apos;d in night so stumblest on my counsel?</body>"
         "</message>"
         "</forwarded>"
         "</result>"
@@ -489,7 +480,7 @@ void tst_QXmppMessage::testChatMarkers()
         "id='message-1' "
         "to='ingrichard@royalty.england.lit/throne'>"
         "<thread>sleeping</thread>"
-        "<body>My lord, dispatch; read o'er these articles.</body>"
+        "<body>My lord, dispatch; read o&apos;er these articles.</body>"
         "<markable xmlns='urn:xmpp:chat-markers:0'/>"
         "</message>");
 
@@ -671,8 +662,8 @@ void tst_QXmppMessage::testPrivateMessage()
 {
     const QByteArray xml = QByteArrayLiteral(
         "<message type=\"chat\">"
-        "<body>My lord, dispatch; read o'er these articles.</body>"
         "<private xmlns=\"urn:xmpp:carbons:2\"/>"
+        "<body>My lord, dispatch; read o&apos;er these articles.</body>"
         "</message>");
 
     QXmppMessage message;
@@ -700,6 +691,10 @@ void tst_QXmppMessage::testOutOfBandUrl()
         "<x xmlns=\"jabber:x:oob\">"
         "<url>http://www.jabber.org/images/psa-license.jpg</url>"
         "</x>"
+        "<x xmlns=\"jabber:x:oob\">"
+        "<url>https://xmpp.org/images/logos/xmpp-logo.svg</url>"
+        "<desc>XMPP logo</desc>"
+        "</x>"
         "</message>");
     const QString firstUrl = "http://www.jabber.org/images/psa-license.jpg";
     const QString newUrl = "https://xmpp.org/theme/images/xmpp-logo.svg";
@@ -708,12 +703,19 @@ void tst_QXmppMessage::testOutOfBandUrl()
     parsePacket(oobMessage, oobXml);
     QCOMPARE(oobMessage.outOfBandUrl(), firstUrl);
 
+    QCOMPARE(oobMessage.outOfBandUrls().size(), 2);
+
+    QCOMPARE(oobMessage.outOfBandUrls().front().url(), QStringLiteral("http://www.jabber.org/images/psa-license.jpg"));
+    QVERIFY(!oobMessage.outOfBandUrls().front().description().has_value());
+
+    QCOMPARE(oobMessage.outOfBandUrls().at(1).url(), QStringLiteral("https://xmpp.org/images/logos/xmpp-logo.svg"));
+    QCOMPARE(oobMessage.outOfBandUrls().at(1).description().value(), QStringLiteral("XMPP logo"));
+
+    serializePacket(oobMessage, oobXml);
+
     oobMessage.setOutOfBandUrl(newUrl);
     QCOMPARE(oobMessage.outOfBandUrl(), newUrl);
-
-    // set first url again
-    oobMessage.setOutOfBandUrl(firstUrl);
-    serializePacket(oobMessage, oobXml);
+    QCOMPARE(oobMessage.outOfBandUrls().size(), 1);
 }
 
 void tst_QXmppMessage::testMessageCorrect()
@@ -756,11 +758,11 @@ void tst_QXmppMessage::testMix()
         "<message to=\"hag66@shakespeare.example\" "
         "from=\"coven@mix.shakespeare.example/123456\" "
         "type=\"groupchat\">"
-        "<body>Harpier cries: 'tis time, 'tis time.</body>"
         "<mix xmlns=\"urn:xmpp:mix:core:1\">"
         "<jid>hag66@shakespeare.example</jid>"
         "<nick>thirdwitch</nick>"
         "</mix>"
+        "<body>Harpier cries: &apos;tis time, &apos;tis time.</body>"
         "</message>");
 
     QXmppMessage message;
@@ -781,41 +783,41 @@ void tst_QXmppMessage::testEme()
     // test standard encryption: OMEMO
     const QByteArray xmlOmemo(
         "<message to=\"foo@example.com/QXmpp\" from=\"bar@example.com/QXmpp\" type=\"normal\">"
-        "<body>This message is encrypted with OMEMO, but your client doesn't seem to support that.</body>"
-        "<encryption xmlns=\"urn:xmpp:eme:0\" namespace=\"eu.siacs.conversations.axolotl\"/>"
+        "<encryption xmlns=\"urn:xmpp:eme:0\" namespace=\"eu.siacs.conversations.axolotl\" name=\"OMEMO\"/>"
+        "<body>This message is encrypted with OMEMO, but your client doesn&apos;t seem to support that.</body>"
         "</message>");
 
     QXmppMessage messageOmemo;
     parsePacket(messageOmemo, xmlOmemo);
     QCOMPARE(messageOmemo.encryptionMethodNs(), QString("eu.siacs.conversations.axolotl"));
-    QCOMPARE(messageOmemo.encryptionMethod(), QXmppMessage::OMEMO);
+    QCOMPARE(messageOmemo.encryptionMethod(), QXmpp::OMEMO);
     QCOMPARE(messageOmemo.encryptionName(), QString("OMEMO"));
     serializePacket(messageOmemo, xmlOmemo);
 
     // test custom encryption
     const QByteArray xmlCustom(
         "<message to=\"foo@example.com/QXmpp\" from=\"bar@example.com/QXmpp\" type=\"normal\">"
-        "<body>This message is encrypted with CustomCrypt, but your client doesn't seem to support that.</body>"
         "<encryption xmlns=\"urn:xmpp:eme:0\" namespace=\"im:example:customcrypt:1\" name=\"CustomCrypt\"/>"
+        "<body>This message is encrypted with CustomCrypt, but your client doesn&apos;t seem to support that.</body>"
         "</message>");
 
     QXmppMessage messageCustom;
     parsePacket(messageCustom, xmlCustom);
     QCOMPARE(messageCustom.encryptionMethodNs(), QString("im:example:customcrypt:1"));
-    QCOMPARE(messageCustom.encryptionMethod(), QXmppMessage::UnknownEncryption);
+    QCOMPARE(messageCustom.encryptionMethod(), QXmpp::UnknownEncryption);
     QCOMPARE(messageCustom.encryptionName(), QString("CustomCrypt"));
     serializePacket(messageCustom, xmlCustom);
 
     // test setters/getters
     QXmppMessage message;
-    message.setEncryptionMethod(QXmppMessage::LegacyOpenPGP);
-    QCOMPARE(message.encryptionMethod(), QXmppMessage::LegacyOpenPGP);
+    message.setEncryptionMethod(QXmpp::LegacyOpenPGP);
+    QCOMPARE(message.encryptionMethod(), QXmpp::LegacyOpenPGP);
     QCOMPARE(message.encryptionMethodNs(), QString("jabber:x:encrypted"));
     QCOMPARE(message.encryptionName(), QString("Legacy OpenPGP"));
 
     message.setEncryptionMethodNs("fancyorg:encryption:fancycrypt:0");
     message.setEncryptionName("FancyCrypt");
-    QCOMPARE(message.encryptionMethod(), QXmppMessage::UnknownEncryption);
+    QCOMPARE(message.encryptionMethod(), QXmpp::UnknownEncryption);
     QCOMPARE(message.encryptionMethodNs(), QString("fancyorg:encryption:fancycrypt:0"));
     QCOMPARE(message.encryptionName(), QString("FancyCrypt"));
 }
@@ -865,11 +867,11 @@ void tst_QXmppMessage::testProcessingHints()
         "<message to=\"juliet@capulet.lit/laptop\" "
         "from=\"romeo@montague.lit/laptop\" "
         "type=\"chat\">"
-        "<body>V unir avtug'f pybnx gb uvqr zr sebz gurve fvtug</body>"
         "<no-permanent-store xmlns=\"urn:xmpp:hints\"/>"
         "<no-store xmlns=\"urn:xmpp:hints\"/>"
         "<no-copy xmlns=\"urn:xmpp:hints\"/>"
         "<store xmlns=\"urn:xmpp:hints\"/>"
+        "<body>V unir avtug&apos;f pybnx gb uvqr zr sebz gurve fvtug</body>"
         "</message>");
 
     // test parsing
@@ -1096,10 +1098,192 @@ void tst_QXmppMessage::testMixInvitation()
     QXmppMessage message;
     parsePacket(message, xml);
 
-    QVERIFY(message.mixInvitation());
+    QVERIFY(message.mixInvitation().has_value());
 
     serializePacket(message, xml);
 }
 
+void tst_QXmppMessage::testTrustMessageElement()
+{
+    const QByteArray xml(
+        "<message id=\"1\" to=\"alice@example.org/\" from=\"alice@example.org/A2\" type=\"chat\">"
+        "<store xmlns=\"urn:xmpp:hints\"/>"
+        "<trust-message xmlns=\"urn:xmpp:tm:1\" usage=\"urn:xmpp:atm:1\" encryption=\"urn:xmpp:omemo:2\">"
+        "<key-owner jid=\"alice@example.org\">"
+        "<trust>aFABnX7Q/rbTgjBySYzrT2FsYCVYb49mbca5yB734KQ=</trust>"
+        "<trust>IhpPjiKLchgrAG5cpSfTvdzPjZ5v6vTOluHEUehkgCA=</trust>"
+        "</key-owner>"
+        "<key-owner jid=\"bob@example.com\">"
+        "<trust>YjVI04NcbTPvXLaA95RO84HPcSvyOgEZ2r5cTyUs0C8=</trust>"
+        "<distrust>tCP1CI3pqSTVGzFYFyPYUMfMZ9Ck/msmfD0wH/VtJBM=</distrust>"
+        "<distrust>2fhJtrgoMJxfLI3084/YkYh9paqiSiLFDVL2m0qAgX4=</distrust>"
+        "</key-owner>"
+        "</trust-message>"
+        "</message>");
+
+    QXmppMessage message1;
+    parsePacket(message1, xml);
+    QVERIFY(message1.trustMessageElement());
+    serializePacket(message1, xml);
+
+    QXmppMessage message2;
+    message2.setTrustMessageElement(QXmppTrustMessageElement());
+    QVERIFY(message2.trustMessageElement());
+}
+
+void tst_QXmppMessage::testReaction()
+{
+    const QByteArray xml(
+        "<message id=\"96d73204-a57a-11e9-88b8-4889e7820c76\" to=\"romeo@capulet.net/orchard\" type=\"chat\">"
+        "<store xmlns=\"urn:xmpp:hints\"/>"
+        "<reactions xmlns=\"urn:xmpp:reactions:0\" id=\"744f6e18-a57a-11e9-a656-4889e7820c76\">"
+        "<reaction>🐢</reaction>"
+        "<reaction>👋</reaction>"
+        "</reactions>"
+        "</message>");
+
+    QXmppMessage message1;
+    QVERIFY(!message1.reaction());
+
+    parsePacket(message1, xml);
+    QVERIFY(message1.reaction());
+    serializePacket(message1, xml);
+
+    QXmppMessage message2;
+    message2.addHint(QXmppMessage::Store);
+    message2.setReaction(QXmppMessageReaction());
+    QVERIFY(message2.reaction());
+}
+
+void tst_QXmppMessage::testE2eeFallbackBody()
+{
+    const QByteArray xml(
+        "<message type=\"chat\">"
+        "<body>This message is encrypted with OMEMO 2 but could not be decrypted</body>"
+        "</message>");
+
+    // The custom de- / serialization lambda expressions are needed because of
+    // "QXmpp::ScePublic".
+
+    const auto parsePacket = [](QXmppMessage &packet, const QByteArray &xml) {
+        // qDebug() << "parsing" << xml;
+        packet.parse(xmlToDom(xml), QXmpp::ScePublic);
+    };
+
+    const auto packetToXml = [](const QXmppMessage &packet) {
+        QBuffer buffer;
+        buffer.open(QIODevice::ReadWrite);
+        QXmlStreamWriter writer(&buffer);
+        packet.toXml(&writer, QXmpp::ScePublic);
+        auto data = buffer.data();
+        data.replace(u'\'', "&apos;");
+        return data;
+    };
+
+    const auto serializePacket = [=](QXmppMessage &packet, const QByteArray &xml) {
+        auto processedXml = xml;
+        processedXml.replace(u'\'', u'"');
+
+        const auto data = packetToXml(packet);
+        qDebug() << "expect " << processedXml;
+        qDebug() << "writing" << data;
+        QCOMPARE(data, processedXml);
+    };
+
+    QXmppMessage message1;
+    parsePacket(message1, xml);
+    QCOMPARE(message1.e2eeFallbackBody(), QStringLiteral("This message is encrypted with OMEMO 2 but could not be decrypted"));
+    serializePacket(message1, xml);
+
+    QXmppMessage message2;
+    message2.setE2eeFallbackBody(QStringLiteral("This message is encrypted with OMEMO 2 but could not be decrypted"));
+    serializePacket(message2, xml);
+}
+
+void tst_QXmppMessage::testFileSharing()
+{
+    const QByteArray xml(
+        "<message id='sharing-a-file' to='juliet@shakespeare.lit' from='romeo@montague.lit/resource' type='normal'>"
+        "<file-sharing xmlns='urn:xmpp:sfs:0' disposition='inline'>"
+        "<file xmlns='urn:xmpp:file:metadata:0'>"
+        "<desc>Photo from the summit.</desc>"
+        "<hash xmlns='urn:xmpp:hashes:2' algo='sha3-256'>2XarmwTlNxDAMkvymloX3S5+VbylNrJt/l5QyPa+YoU=</hash>"
+        "<hash xmlns='urn:xmpp:hashes:2' algo='blake2b-256'>2AfMGH8O7UNPTvUVAM9aK13mpCY=</hash>"
+        "<media-type>image/jpeg</media-type>"
+        "<name>summit.jpg</name>"
+        "<size>3032449</size>"
+        "<thumbnail xmlns='urn:xmpp:thumbs:1' uri='cid:sha1+ffd7c8d28e9c5e82afea41f97108c6b4@bob.xmpp.org' media-type='image/png' width='128' height='96'/>"
+        "</file>"
+        "<sources>"
+        "<url-data xmlns='http://jabber.org/protocol/url-data' target='https://download.montague.lit/4a771ac1-f0b2-4a4a-9700-f2a26fa2bb67/summit.jpg'/>"
+        "</sources>"
+        "</file-sharing>"
+        "</message>");
+
+    QXmppMessage message1;
+    parsePacket(message1, xml);
+    QVERIFY(!message1.sharedFiles().empty());
+    serializePacket(message1, xml);
+}
+
+void tst_QXmppMessage::testEncryptedFileSource()
+{
+    {
+        QByteArray xml(
+            "<encrypted xmlns='urn:xmpp:esfs:0' cipher='urn:xmpp:ciphers:aes-256-gcm-nopadding:0'>"
+            "<key>SuRJ2agVm/pQbJQlPq/B23Xt1YOOJCcEGJA5HrcYOGQ=</key>"
+            "<iv>T8RDMBaiqn6Ci4Nw</iv>"
+            "<hash xmlns='urn:xmpp:hashes:2' algo='sha3-256'>BgKI2gp2kNCRsARNvhFmw5kFf9BBo2pTbV2D8XHTMWI=</hash>"
+            "<hash xmlns='urn:xmpp:hashes:2' algo='blake2b-256'>id4cnqqy9/ssfCkM4vYSkiXXrlE=</hash>"
+            "<sources xmlns='urn:xmpp:sfs:0'>"
+            "<url-data xmlns='http://jabber.org/protocol/url-data' target='https://download.montague.lit/4a771ac1-f0b2-4a4a-9700-f2a26fa2bb67/encrypted.jpg'/>"
+            "</sources>"
+            "</encrypted>");
+
+        QXmppEncryptedFileSource encryptedSource;
+        parsePacket(encryptedSource, xml);
+        QCOMPARE(encryptedSource.key(), QByteArray::fromBase64("SuRJ2agVm/pQbJQlPq/B23Xt1YOOJCcEGJA5HrcYOGQ="));
+        QCOMPARE(encryptedSource.iv(), QByteArray::fromBase64("T8RDMBaiqn6Ci4Nw"));
+        QCOMPARE(encryptedSource.httpSources().front().url(), QUrl("https://download.montague.lit/4a771ac1-f0b2-4a4a-9700-f2a26fa2bb67/encrypted.jpg"));
+        QCOMPARE(encryptedSource.cipher(), QXmpp::Aes256GcmNoPad);
+        QVERIFY(!encryptedSource.hashes().empty());
+        serializePacket(encryptedSource, xml);
+    }
+
+    {
+        QByteArray xml(
+            "<encrypted xmlns='urn:xmpp:esfs:0' cipher='urn:xmpp:ciphers:aes-128-gcm-nopadding:0'>"
+            "<key>SuRJ2agVm/pQbJQlPq/B23Xt1YOOJCcEGJA5HrcYOGQ=</key>"
+            "<iv>T8RDMBaiqn6Ci4Nw</iv>"
+            "<hash xmlns='urn:xmpp:hashes:2' algo='sha3-256'>BgKI2gp2kNCRsARNvhFmw5kFf9BBo2pTbV2D8XHTMWI=</hash>"
+            "<hash xmlns='urn:xmpp:hashes:2' algo='blake2b-256'>id4cnqqy9/ssfCkM4vYSkiXXrlE=</hash>"
+            "<sources xmlns='urn:xmpp:sfs:0'>"
+            "<url-data xmlns='http://jabber.org/protocol/url-data' target='https://download.montague.lit/4a771ac1-f0b2-4a4a-9700-f2a26fa2bb67/encrypted.jpg'/>"
+            "</sources>"
+            "</encrypted>");
+
+        QXmppEncryptedFileSource encryptedSource;
+        parsePacket(encryptedSource, xml);
+        serializePacket(encryptedSource, xml);
+    }
+
+    {
+        QByteArray xml(
+            "<encrypted xmlns='urn:xmpp:esfs:0' cipher='urn:xmpp:ciphers:aes-256-cbc-pkcs7:0'>"
+            "<key>SuRJ2agVm/pQbJQlPq/B23Xt1YOOJCcEGJA5HrcYOGQ=</key>"
+            "<iv>T8RDMBaiqn6Ci4Nw</iv>"
+            "<hash xmlns='urn:xmpp:hashes:2' algo='sha3-256'>BgKI2gp2kNCRsARNvhFmw5kFf9BBo2pTbV2D8XHTMWI=</hash>"
+            "<hash xmlns='urn:xmpp:hashes:2' algo='blake2b-256'>id4cnqqy9/ssfCkM4vYSkiXXrlE=</hash>"
+            "<sources xmlns='urn:xmpp:sfs:0'>"
+            "<url-data xmlns='http://jabber.org/protocol/url-data' target='https://download.montague.lit/4a771ac1-f0b2-4a4a-9700-f2a26fa2bb67/encrypted.jpg'/>"
+            "</sources>"
+            "</encrypted>");
+
+        QXmppEncryptedFileSource encryptedSource;
+        parsePacket(encryptedSource, xml);
+        serializePacket(encryptedSource, xml);
+    }
+}
+
 QTEST_MAIN(tst_QXmppMessage)
 #include "tst_qxmppmessage.moc"
