@@ -1,25 +1,6 @@
-/*
- * Copyright (C) 2008-2021 The QXmpp developers
- *
- * Authors:
- *  Linus Jahn <lnj@kaidan.im>
- *
- * Source:
- *  https://github.com/qxmpp-project/qxmpp
- *
- * This file is a part of QXmpp library.
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- */
+// SPDX-FileCopyrightText: 2019 Linus Jahn <lnj@kaidan.im>
+//
+// SPDX-License-Identifier: LGPL-2.1-or-later
 
 #include "QXmppClient.h"
 #include "QXmppMessageReceiptManager.h"
@@ -31,25 +12,24 @@ class tst_QXmppMessageReceiptManager : public QObject
 {
     Q_OBJECT
 
-private slots:
-    void initTestCase();
+private:
+    Q_SLOT void initTestCase();
 
-    void testReceipt_data();
-    void testReceipt();
+    Q_SLOT void testReceipt_data();
+    Q_SLOT void testReceipt();
 
-    void handleMessageDelivered(const QString&, const QString&)
+    void handleMessageDelivered(const QString &, const QString &)
     {
         m_messageDelivered = true;
     }
-    void onLoggerMessage(QXmppLogger::MessageType type, const QString& text)
+    void onLoggerMessage(QXmppLogger::MessageType, const QString &)
     {
         m_receiptSent = true;
     }
 
-private:
-    QXmppMessageReceiptManager* m_manager;
+    QXmppMessageReceiptManager *m_manager;
     QXmppClient m_client;
-    QXmppLogger* m_logger;
+    QXmppLogger m_logger;
     bool m_messageDelivered = false;
     bool m_receiptSent = false;
 };
@@ -57,13 +37,12 @@ private:
 void tst_QXmppMessageReceiptManager::initTestCase()
 {
     m_manager = new QXmppMessageReceiptManager();
-    m_logger = new QXmppLogger();
 
     m_client.addExtension(m_manager);
-    m_logger->setLoggingType(QXmppLogger::SignalLogging);
-    m_client.setLogger(m_logger);
+    m_logger.setLoggingType(QXmppLogger::SignalLogging);
+    m_client.setLogger(&m_logger);
 
-    connect(m_logger, &QXmppLogger::message,
+    connect(&m_logger, &QXmppLogger::message,
             this, &tst_QXmppMessageReceiptManager::onLoggerMessage);
 
     connect(m_manager, &QXmppMessageReceiptManager::messageDelivered,
@@ -183,10 +162,12 @@ void tst_QXmppMessageReceiptManager::testReceipt()
     QFETCH(bool, handled);
 
     QDomDocument doc;
-    QCOMPARE(doc.setContent(xml, true), true);
+    QVERIFY(doc.setContent(xml, true));
     QDomElement element = doc.documentElement();
+    QXmppMessage msg;
+    msg.parse(element);
 
-    QCOMPARE(m_manager->handleStanza(element), handled);
+    QCOMPARE(m_manager->handleMessage(msg), handled);
     QCOMPARE(m_messageDelivered, accept);
     QCOMPARE(m_receiptSent, sent);
 }
