@@ -1,25 +1,6 @@
-/*
- * Copyright (C) 2008-2021 The QXmpp developers
- *
- * Author:
- *  Linus Jahn <lnj@kaidan.im>
- *
- * Source:
- *  https://github.com/qxmpp-project/qxmpp
- *
- * This file is a part of QXmpp library.
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- */
+// SPDX-FileCopyrightText: 2019 Linus Jahn <lnj@kaidan.im>
+//
+// SPDX-License-Identifier: LGPL-2.1-or-later
 
 #include "QXmppMixIq.h"
 
@@ -33,12 +14,13 @@ class tst_QXmppMixIq : public QObject
 {
     Q_OBJECT
 
-private slots:
-    void testBase_data();
-    void testBase();
-    void testDefaults();
-    void testSetters();
-    void testIsMixIq();
+private:
+    Q_SLOT void testBase_data();
+    Q_SLOT void testBase();
+    Q_SLOT void testDefaults();
+    Q_SLOT void testSetters();
+    Q_SLOT void testInvalidActionType();
+    Q_SLOT void testIsMixIq();
 };
 
 void tst_QXmppMixIq::testBase_data()
@@ -367,6 +349,18 @@ void tst_QXmppMixIq::testSetters()
     QCOMPARE(iq.nick(), QString("SMUDO"));
 }
 
+void tst_QXmppMixIq::testInvalidActionType()
+{
+    const QByteArray xml =
+        "<iq id='E6E10350' to='hag66@example.org'"
+        " from='hag66@example.org/123' type='set'>"
+        "<set-on-fire xmlns='urn:xmpp:mix:core:1' channel='coven'/>"
+        "</iq>";
+    QXmppMixIq iq;
+    parsePacket(iq, xml);
+    QCOMPARE(iq.actionType(), QXmppMixIq::None);
+}
+
 void tst_QXmppMixIq::testIsMixIq()
 {
     const QByteArray trueXml(
