@@ -1,26 +1,8 @@
-/*
- * Copyright (C) 2008-2021 The QXmpp developers
- *
- * Authors:
- *  Olivier Goffart
- *  Jeremy Lainé
- *
- * Source:
- *  https://github.com/qxmpp-project/qxmpp
- *
- * This file is a part of QXmpp library.
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- */
+// SPDX-FileCopyrightText: 2012 Oliver Goffart <ogoffart@woboq.com>
+// SPDX-FileCopyrightText: 2012 Jeremy Lainé <jeremy.laine@m4x.org>
+// SPDX-FileCopyrightText: 2022 Melvin Keskin <melvo@olomono.de>
+//
+// SPDX-License-Identifier: LGPL-2.1-or-later
 
 #include "QXmppPresence.h"
 
@@ -32,17 +14,18 @@ class tst_QXmppPresence : public QObject
 {
     Q_OBJECT
 
-private slots:
-    void testPresence();
-    void testPresence_data();
-    void testPresenceWithCapability();
-    void testPresenceWithExtendedAddresses();
-    void testPresenceWithMucItem();
-    void testPresenceWithMucPassword();
-    void testPresenceWithMucSupport();
-    void testPresenceWithLastUserInteraction();
-    void testPresenceWithMix();
-    void testPresenceWithVCard();
+private:
+    Q_SLOT void testPresence();
+    Q_SLOT void testPresence_data();
+    Q_SLOT void testPresenceWithCapability();
+    Q_SLOT void testPresenceWithExtendedAddresses();
+    Q_SLOT void testPresenceWithMucItem();
+    Q_SLOT void testPresenceWithMucPassword();
+    Q_SLOT void testPresenceWithMucSupport();
+    Q_SLOT void testPresenceWithMuji();
+    Q_SLOT void testPresenceWithLastUserInteraction();
+    Q_SLOT void testPresenceWithMix();
+    Q_SLOT void testPresenceWithVCard();
 };
 
 void tst_QXmppPresence::testPresence_data()
@@ -269,6 +252,45 @@ void tst_QXmppPresence::testPresenceWithMucSupport()
     serializePacket(presence, xml);
 }
 
+void tst_QXmppPresence::testPresenceWithMuji()
+{
+    const QByteArray xml(
+        "<presence>"
+        "<muji xmlns=\"urn:xmpp:jingle:muji:0\">"
+        "<preparing/>"
+        "<content creator=\"initiator\" name=\"video\"/>"
+        "<content creator=\"initiator\" name=\"voice\"/>"
+        "</muji>"
+        "</presence>");
+
+    QXmppPresence presence1;
+    QVERIFY(!presence1.isPreparingMujiSession());
+    QVERIFY(presence1.mujiContents().isEmpty());
+    parsePacket(presence1, xml);
+
+    QVERIFY(presence1.isPreparingMujiSession());
+    QCOMPARE(presence1.mujiContents().size(), 2);
+    QCOMPARE(presence1.mujiContents().at(0).name(), QStringLiteral("video"));
+    QCOMPARE(presence1.mujiContents().at(1).name(), QStringLiteral("voice"));
+    serializePacket(presence1, xml);
+
+    QXmppPresence presence2;
+    presence2.setIsPreparingMujiSession(true);
+    QXmppJingleIq::Content mujiContent1;
+    mujiContent1.setCreator(QStringLiteral("initiator"));
+    mujiContent1.setName(QStringLiteral("video"));
+    QXmppJingleIq::Content mujiContent2;
+    mujiContent2.setCreator(QStringLiteral("initiator"));
+    mujiContent2.setName(QStringLiteral("voice"));
+    presence2.setMujiContents({ mujiContent1, mujiContent2 });
+
+    QVERIFY(presence2.isPreparingMujiSession());
+    QCOMPARE(presence2.mujiContents().size(), 2);
+    QCOMPARE(presence2.mujiContents().at(0).name(), QStringLiteral("video"));
+    QCOMPARE(presence2.mujiContents().at(1).name(), QStringLiteral("voice"));
+    serializePacket(presence2, xml);
+}
+
 void tst_QXmppPresence::testPresenceWithLastUserInteraction()
 {
     const QByteArray xml(
