@@ -1,41 +1,23 @@
-/*
- * Copyright (C) 2008-2021 The QXmpp developers
- *
- * Author:
- *  Jonah Brüchert
- *
- * Source:
- *  https://github.com/qxmpp-project/qxmpp
- *
- * This file is a part of QXmpp library.
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- */
+// SPDX-FileCopyrightText: 2020 Jonah Brüchert <jbb@kaidan.im>
+//
+// SPDX-License-Identifier: LGPL-2.1-or-later
 
-#include <QObject>
-#include "util.h"
-#include <QXmppPushEnableIq.h>
 #include <QXmppDataForm.h>
+#include <QXmppPushEnableIq.h>
+
+#include "util.h"
+#include <QObject>
 
 class tst_QXmppPushEnableIq : public QObject
 {
     Q_OBJECT
 
-private slots:
-    void testPushEnable();
-    void testPushDisable();
-    void testXmlNs();
-    void testDataForm();
-    void testIsEnableIq();
+private:
+    Q_SLOT void testPushEnable();
+    Q_SLOT void testPushDisable();
+    Q_SLOT void testXmlNs();
+    Q_SLOT void testDataForm();
+    Q_SLOT void testIsEnableIq();
 };
 
 void tst_QXmppPushEnableIq::testPushEnable()
@@ -131,7 +113,7 @@ void tst_QXmppPushEnableIq::testDataForm()
 
     QXmppDataForm form;
     form.setType(QXmppDataForm::Submit);
-    form.setFields({field0, field1});
+    form.setFields({ field0, field1 });
 
     sIq.setDataForm(form);
 
