@@ -1,26 +1,7 @@
-/*
- * Copyright (C) 2008-2021 The QXmpp developers
- *
- * Author:
- *  Jeremy Lainé
- *  Linus Jahn
- *
- * Source:
- *  https://github.com/qxmpp-project/qxmpp
- *
- * This file is a part of QXmpp library.
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- */
+// SPDX-FileCopyrightText: 2012 Jeremy Lainé <jeremy.laine@m4x.org>
+// SPDX-FileCopyrightText: 2019 Linus Jahn <lnj@kaidan.im>
+//
+// SPDX-License-Identifier: LGPL-2.1-or-later
 
 #include "QXmppBitsOfBinaryContentId.h"
 #include "QXmppBitsOfBinaryData.h"
@@ -34,17 +15,19 @@ class tst_QXmppRegisterIq : public QObject
 {
     Q_OBJECT
 
-private slots:
-    void testGet();
-    void testResult();
-    void testResultWithForm();
-    void testSet();
-    void testSetWithForm();
-    void testBobData();
-    void testRegistered();
-    void testRemove();
-    void testChangePassword();
-    void testUnregistration();
+private:
+    Q_SLOT void testGet();
+    Q_SLOT void testResult();
+    Q_SLOT void testResultWithForm();
+    Q_SLOT void testResultWithRedirection();
+    Q_SLOT void testResultWithFormAndRedirection();
+    Q_SLOT void testSet();
+    Q_SLOT void testSetWithForm();
+    Q_SLOT void testBobData();
+    Q_SLOT void testRegistered();
+    Q_SLOT void testRemove();
+    Q_SLOT void testChangePassword();
+    Q_SLOT void testUnregistration();
 };
 
 void tst_QXmppRegisterIq::testGet()
@@ -67,6 +50,7 @@ void tst_QXmppRegisterIq::testGet()
     QVERIFY(iq.password().isNull());
     QVERIFY(iq.email().isNull());
     QVERIFY(iq.form().isNull());
+    QVERIFY(iq.outOfBandUrl().isNull());
     serializePacket(iq, xml);
 }
 
@@ -96,6 +80,7 @@ void tst_QXmppRegisterIq::testResult()
     QVERIFY(!iq.email().isNull());
     QVERIFY(iq.email().isEmpty());
     QVERIFY(iq.form().isNull());
+    QVERIFY(iq.outOfBandUrl().isNull());
     serializePacket(iq, xml);
 }
 
@@ -143,6 +128,87 @@ void tst_QXmppRegisterIq::testResultWithForm()
     QVERIFY(iq.email().isNull());
     QVERIFY(!iq.form().isNull());
     QCOMPARE(iq.form().title(), QLatin1String("Contest Registration"));
+    QVERIFY(iq.outOfBandUrl().isNull());
+    serializePacket(iq, xml);
+}
+
+void tst_QXmppRegisterIq::testResultWithRedirection()
+{
+    const QByteArray xml(
+        "<iq id=\"reg3\" type=\"result\">"
+        "<query xmlns=\"jabber:iq:register\">"
+        "<instructions>"
+        "To register, visit http://www.shakespeare.lit/contests.php"
+        "</instructions>"
+        "<x xmlns=\"jabber:x:oob\">"
+        "<url>http://www.shakespeare.lit/contests.php</url>"
+        "</x>"
+        "</query>"
+        "</iq>");
+
+    QXmppRegisterIq iq;
+    parsePacket(iq, xml);
+    QCOMPARE(iq.id(), QLatin1String("reg3"));
+    QCOMPARE(iq.to(), QString());
+    QCOMPARE(iq.from(), QString());
+    QCOMPARE(iq.type(), QXmppIq::Result);
+    QCOMPARE(iq.instructions(), QLatin1String("To register, visit http://www.shakespeare.lit/contests.php"));
+    QVERIFY(iq.username().isNull());
+    QVERIFY(iq.password().isNull());
+    QVERIFY(iq.email().isNull());
+    QVERIFY(iq.form().isNull());
+    QCOMPARE(iq.outOfBandUrl(), QLatin1String("http://www.shakespeare.lit/contests.php"));
+    serializePacket(iq, xml);
+}
+
+void tst_QXmppRegisterIq::testResultWithFormAndRedirection()
+{
+    const QByteArray xml(
+        "<iq id=\"reg3\" to=\"juliet@capulet.com/balcony\" from=\"contests.shakespeare.lit\" type=\"result\">"
+        "<query xmlns=\"jabber:iq:register\">"
+        "<instructions>Use the enclosed form to register. If your Jabber client does not support Data Forms, visit http://www.shakespeare.lit/contests.php</instructions>"
+        "<x xmlns=\"jabber:x:data\" type=\"form\">"
+        "<title>Contest Registration</title>"
+        "<instructions>"
+        "Please provide the following information"
+        "to sign up for our special contests!"
+        "</instructions>"
+        "<field type=\"hidden\" var=\"FORM_TYPE\">"
+        "<value>jabber:iq:register</value>"
+        "</field>"
+        "<field type=\"text-single\" label=\"Given Name\" var=\"first\">"
+        "<required/>"
+        "</field>"
+        "<field type=\"text-single\" label=\"Family Name\" var=\"last\">"
+        "<required/>"
+        "</field>"
+        "<field type=\"text-single\" label=\"Email Address\" var=\"email\">"
+        "<required/>"
+        "</field>"
+        "<field type=\"list-single\" label=\"Gender\" var=\"x-gender\">"
+        "<option label=\"Male\"><value>M</value></option>"
+        "<option label=\"Female\"><value>F</value></option>"
+        "</field>"
+        "</x>"
+        "<x xmlns=\"jabber:x:oob\">"
+        "<url>http://www.shakespeare.lit/contests.php</url>"
+        "</x>"
+        "</query>"
+        "</iq>");
+
+    QXmppRegisterIq iq;
+    parsePacket(iq, xml);
+    QCOMPARE(iq.id(), QLatin1String("reg3"));
+    QCOMPARE(iq.to(), QLatin1String("juliet@capulet.com/balcony"));
+    QCOMPARE(iq.from(), QLatin1String("contests.shakespeare.lit"));
+    QCOMPARE(iq.type(), QXmppIq::Result);
+    QCOMPARE(iq.instructions(), QLatin1String("Use the enclosed form to register. If your Jabber client does not support Data Forms, visit http://www.shakespeare.lit/contests.php"));
+    QVERIFY(iq.username().isNull());
+    QVERIFY(iq.password().isNull());
+    QVERIFY(iq.email().isNull());
+    QVERIFY(!iq.form().isNull());
+    QCOMPARE(iq.form().title(), QLatin1String("Contest Registration"));
+    QCOMPARE(iq.outOfBandUrl(), QLatin1String("http://www.shakespeare.lit/contests.php"));
     serializePacket(iq, xml);
 }
 
@@ -167,6 +233,7 @@ void tst_QXmppRegisterIq::testSet()
     QCOMPARE(iq.password(), QLatin1String("Calliope"));
     QCOMPARE(iq.email(), QLatin1String("bard@shakespeare.lit"));
     QVERIFY(iq.form().isNull());
+    QVERIFY(iq.outOfBandUrl().isNull());
     serializePacket(iq, xml);
 }
 
@@ -205,6 +272,7 @@ void tst_QXmppRegisterIq::testSetWithForm()
     QVERIFY(iq.password().isNull());
     QVERIFY(iq.email().isNull());
     QVERIFY(!iq.form().isNull());
+    QVERIFY(iq.outOfBandUrl().isNull());
     serializePacket(iq, xml);
 
     QXmppRegisterIq sIq;
