@@ -1,25 +1,6 @@
-/*
- * Copyright (C) 2008-2021 The QXmpp developers
- *
- * Authors:
- *  Linus Jahn
- *
- * Source:
- *  https://github.com/qxmpp-project/qxmpp
- *
- * This file is a part of QXmpp library.
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- */
+// SPDX-FileCopyrightText: 2020 Linus Jahn <lnj@kaidan.im>
+//
+// SPDX-License-Identifier: LGPL-2.1-or-later
 
 #include "QXmppClient.h"
 #include "QXmppDiscoveryManager.h"
@@ -32,34 +13,33 @@ class tst_QXmppRegistrationManager : public QObject
 {
     Q_OBJECT
 
-private slots:
-    void initTestCase();
-
-    void testDiscoFeatures();
-
-    void testChangePassword_data();
-    void testChangePassword();
-    void testDeleteAccount();
-    void testRequestRegistrationForm_data();
-    void testRequestRegistrationForm();
-    void testRegisterOnConnectGetSet();
-    void testServiceDiscovery();
-    void testSendCachedRegistrationForm_data();
-    void testSendCachedRegistrationForm();
-    void testStreamFeaturesCheck_data();
-    void testStreamFeaturesCheck();
-    void testRegistrationResult_data();
-    void testRegistrationResult();
-    void testChangePasswordResult_data();
-    void testChangePasswordResult();
-    void testDeleteAccountResult_data();
-    void testDeleteAccountResult();
-    void testRegistrationFormReceived();
-
-    void sendStreamFeaturesToManager(bool registrationEnabled = true);
-    void setManagerConfig(const QString &username, const QString &server = QStringLiteral("example.org"), const QString &password = {});
-
 private:
+    Q_SLOT void initTestCase();
+
+    Q_SLOT void testDiscoFeatures();
+
+    Q_SLOT void testChangePassword_data();
+    Q_SLOT void testChangePassword();
+    Q_SLOT void testDeleteAccount();
+    Q_SLOT void testRequestRegistrationForm_data();
+    Q_SLOT void testRequestRegistrationForm();
+    Q_SLOT void testRegisterOnConnectGetSet();
+    Q_SLOT void testServiceDiscovery();
+    Q_SLOT void testSendCachedRegistrationForm_data();
+    Q_SLOT void testSendCachedRegistrationForm();
+    Q_SLOT void testStreamFeaturesCheck_data();
+    Q_SLOT void testStreamFeaturesCheck();
+    Q_SLOT void testRegistrationResult_data();
+    Q_SLOT void testRegistrationResult();
+    Q_SLOT void testChangePasswordResult_data();
+    Q_SLOT void testChangePasswordResult();
+    Q_SLOT void testDeleteAccountResult_data();
+    Q_SLOT void testDeleteAccountResult();
+    Q_SLOT void testRegistrationFormReceived();
+
+    Q_SLOT void sendStreamFeaturesToManager(bool registrationEnabled = true);
+    Q_SLOT void setManagerConfig(const QString &username, const QString &server = QStringLiteral("example.org"), const QString &password = {});
+
     QXmppClient client;
     QXmppLogger logger;
     QXmppRegistrationManager *manager;
@@ -180,10 +160,11 @@ void tst_QXmppRegistrationManager::testRequestRegistrationForm()
         }
     });
 
-    if (triggerManually)
+    if (triggerManually) {
         manager->requestRegistrationForm();
-    else
+    } else {
         sendStreamFeaturesToManager(true);
+    }
 
     QVERIFY(signalCalled);
     delete context;
@@ -224,7 +205,7 @@ void tst_QXmppRegistrationManager::testServiceDiscovery()
     delete context;
 
     // on disconnect, supportedByServer needs to be reset
-    emit client.disconnected();
+    Q_EMIT client.disconnected();
     QVERIFY(!manager->supportedByServer());
 }
 
@@ -270,10 +251,11 @@ void tst_QXmppRegistrationManager::testSendCachedRegistrationForm()
     });
 
     manager->setRegistrationFormToSend(iq);
-    if (triggerSendingManually)
+    if (triggerSendingManually) {
         manager->sendCachedRegistrationForm();
-    else
+    } else {
         sendStreamFeaturesToManager(true);
+    }
 
     delete context;
 }
@@ -498,8 +480,9 @@ void tst_QXmppRegistrationManager::sendStreamFeaturesToManager(bool registration
 {
     QXmppStreamFeatures features;
     features.setBindMode(QXmppStreamFeatures::Enabled);
-    if (registrationEnabled)
+    if (registrationEnabled) {
         features.setRegisterMode(QXmppStreamFeatures::Enabled);
+    }
 
     auto writeFeaturesToDom = [&]() -> QDomElement {
         QBuffer buffer;
