@@ -1,26 +1,7 @@
-/*
- * Copyright (C) 2008-2021 The QXmpp developers
- *
- * Authors:
- *  Olivier Goffart
- *  Jeremy Lainé
- *
- * Source:
- *  https://github.com/qxmpp-project/qxmpp
- *
- * This file is a part of QXmpp library.
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- */
+// SPDX-FileCopyrightText: 2012 Oliver Goffart <ogoffart@woboq.com>
+// SPDX-FileCopyrightText: 2012 Jeremy Lainé <jeremy.laine@m4x.org>
+//
+// SPDX-License-Identifier: LGPL-2.1-or-later
 
 #include "QXmppResultSet.h"
 
@@ -31,11 +12,11 @@ class tst_QXmppResultSet : public QObject
 {
     Q_OBJECT
 
-private slots:
-    void testQuery_data();
-    void testQuery();
-    void testReply_data();
-    void testReply();
+private:
+    Q_SLOT void testQuery_data();
+    Q_SLOT void testQuery();
+    Q_SLOT void testReply_data();
+    Q_SLOT void testReply();
 };
 
 void tst_QXmppResultSet::testQuery_data()
