@@ -1,25 +1,6 @@
-/*
- * Copyright (C) 2008-2021 The QXmpp developers
- *
- * Author:
- *  Jeremy Lainé
- *
- * Source:
- *  https://github.com/qxmpp-project/qxmpp
- *
- * This file is a part of QXmpp library.
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- */
+// SPDX-FileCopyrightText: 2012 Jeremy Lainé <jeremy.laine@m4x.org>
+//
+// SPDX-License-Identifier: LGPL-2.1-or-later
 
 #include "QXmppRosterIq.h"
 
@@ -30,15 +11,15 @@ class tst_QXmppRosterIq : public QObject
 {
     Q_OBJECT
 
-private slots:
-    void testItem_data();
-    void testItem();
-    void testApproved_data();
-    void testApproved();
-    void testVersion_data();
-    void testVersion();
-    void testMixAnnotate();
-    void testMixChannel();
+private:
+    Q_SLOT void testItem_data();
+    Q_SLOT void testItem();
+    Q_SLOT void testApproved_data();
+    Q_SLOT void testApproved();
+    Q_SLOT void testVersion_data();
+    Q_SLOT void testVersion();
+    Q_SLOT void testMixAnnotate();
+    Q_SLOT void testMixChannel();
 };
 
 void tst_QXmppRosterIq::testItem_data()
@@ -185,12 +166,11 @@ void tst_QXmppRosterIq::testMixAnnotate()
 {
     const QByteArray xml(
         "<iq from=\"juliet@example.com/balcony\" "
-            "type=\"get\">"
-            "<query xmlns=\"jabber:iq:roster\">"
-                "<annotate xmlns=\"urn:xmpp:mix:roster:0\"/>"
-            "</query>"
-        "</iq>"
-    );
+        "type=\"get\">"
+        "<query xmlns=\"jabber:iq:roster\">"
+        "<annotate xmlns=\"urn:xmpp:mix:roster:0\"/>"
+        "</query>"
+        "</iq>");
 
     QXmppRosterIq iq;
     parsePacket(iq, xml);
@@ -205,9 +185,8 @@ void tst_QXmppRosterIq::testMixChannel()
 {
     const QByteArray xml(
         "<item jid=\"balcony@example.net\">"
-            "<channel xmlns=\"urn:xmpp:mix:roster:0\" participant-id=\"123456\"/>"
-        "</item>"
-    );
+        "<channel xmlns=\"urn:xmpp:mix:roster:0\" participant-id=\"123456\"/>"
+        "</item>");
 
     QXmppRosterIq::Item item;
     parsePacket(item, xml);
