@@ -1,25 +1,6 @@
-/*
- * Copyright (C) 2008-2021 The QXmpp developers
- *
- * Author:
- *  Jeremy Lainé
- *
- * Source:
- *  https://github.com/qxmpp-project/qxmpp
- *
- * This file is a part of QXmpp library.
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- */
+// SPDX-FileCopyrightText: 2012 Jeremy Lainé <jeremy.laine@m4x.org>
+//
+// SPDX-License-Identifier: LGPL-2.1-or-later
 
 #include "QXmppRpcIq.h"
 
@@ -39,12 +20,13 @@ static void checkVariant(const QVariant &value, const QByteArray &xml)
 
     // parse
     QDomDocument doc;
-    QCOMPARE(doc.setContent(xml, true), true);
+    QVERIFY(doc.setContent(xml, true));
     QDomElement element = doc.documentElement();
     QStringList errors;
     QVariant test = QXmppRpcMarshaller::demarshall(element, errors);
-    if (!errors.isEmpty())
+    if (!errors.isEmpty()) {
         qDebug() << errors;
+    }
     QCOMPARE(errors, QStringList());
     QCOMPARE(test, value);
 }
@@ -53,21 +35,21 @@ class tst_QXmppRpcIq : public QObject
 {
     Q_OBJECT
 
-private slots:
-    void testBase64();
-    void testBool();
-    void testDateTime();
-    void testDouble();
-    void testInt();
-    void testNil();
-    void testString();
+private:
+    Q_SLOT void testBase64();
+    Q_SLOT void testBool();
+    Q_SLOT void testDateTime();
+    Q_SLOT void testDouble();
+    Q_SLOT void testInt();
+    Q_SLOT void testNil();
+    Q_SLOT void testString();
 
-    void testArray();
-    void testStruct();
+    Q_SLOT void testArray();
+    Q_SLOT void testStruct();
 
-    void testInvoke();
-    void testResponse();
-    void testResponseFault();
+    Q_SLOT void testInvoke();
+    Q_SLOT void testResponse();
+    Q_SLOT void testResponseFault();
 };
 void tst_QXmppRpcIq::testBase64()
 {
