@@ -1,25 +1,6 @@
-/*
- * Copyright (C) 2008-2021 The QXmpp developers
- *
- * Author:
- *  Jeremy Lainé
- *
- * Source:
- *  https://github.com/qxmpp-project/qxmpp
- *
- * This file is a part of QXmpp library.
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- */
+// SPDX-FileCopyrightText: 2012 Jeremy Lainé <jeremy.laine@m4x.org>
+//
+// SPDX-License-Identifier: LGPL-2.1-or-later
 
 #include "QXmppClient.h"
 #include "QXmppServer.h"
@@ -30,9 +11,9 @@ class tst_QXmppServer : public QObject
 {
     Q_OBJECT
 
-private slots:
-    void testConnect_data();
-    void testConnect();
+private:
+    Q_SLOT void testConnect_data();
+    Q_SLOT void testConnect();
 };
 
 void tst_QXmppServer::testConnect_data()
@@ -75,7 +56,7 @@ void tst_QXmppServer::testConnect()
     const quint16 testPort = 12345;
 
     QXmppLogger logger;
-    //logger.setLoggingType(QXmppLogger::StdoutLogging);
+    // logger.setLoggingType(QXmppLogger::StdoutLogging);
 
     // prepare server
     TestPasswordChecker passwordChecker;
