@@ -1,25 +1,6 @@
-/*
- * Copyright (C) 2008-2021 The QXmpp developers
- *
- * Author:
- *  Jeremy Lainé
- *
- * Source:
- *  https://github.com/qxmpp-project/qxmpp
- *
- * This file is a part of QXmpp library.
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- */
+// SPDX-FileCopyrightText: 2015 Jeremy Lainé <jeremy.laine@m4x.org>
+//
+// SPDX-License-Identifier: LGPL-2.1-or-later
 
 #include "QXmppSocks.h"
 
@@ -31,17 +12,16 @@ class tst_QXmppSocks : public QObject
 {
     Q_OBJECT
 
-private slots:
-    void init();
-    void newConnectionSlot(QTcpSocket *socket, QString hostName, quint16 port);
-
-    void testClient_data();
-    void testClient();
-    void testClientAndServer();
-    void testServer_data();
-    void testServer();
-
 private:
+    Q_SLOT void init();
+    Q_SLOT void newConnectionSlot(QTcpSocket *socket, QString hostName, quint16 port);
+
+    Q_SLOT void testClient_data();
+    Q_SLOT void testClient();
+    Q_SLOT void testClientAndServer();
+    Q_SLOT void testServer_data();
+    Q_SLOT void testServer();
+
     QTcpSocket *m_connectionSocket;
     QString m_connectionHostName;
     quint16 m_connectionPort;
@@ -235,8 +215,9 @@ void tst_QXmppSocks::testServer()
     if (!clientHandshakeWorks) {
         // consume any last data
         QByteArray data = client.readAll();
-        if (client.state() != QAbstractSocket::UnconnectedState)
+        if (client.state() != QAbstractSocket::UnconnectedState) {
             loop.exec();
+        }
 
         QCOMPARE(client.state(), QAbstractSocket::UnconnectedState);
 
