@@ -1,43 +1,38 @@
-/*
- * Copyright (C) 2008-2021 The QXmpp developers
- *
- * Author:
- *  Jeremy Lainé
- *
- * Source:
- *  https://github.com/qxmpp-project/qxmpp
- *
- * This file is a part of QXmpp library.
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- */
+// SPDX-FileCopyrightText: 2012 Jeremy Lainé <jeremy.laine@m4x.org>
+// SPDX-FileCopyrightText: 2022 Melvin Keskin <melvo@olomono.de>
+//
+// SPDX-License-Identifier: LGPL-2.1-or-later
 
+#include "QXmppE2eeMetadata.h"
 #include "QXmppStanza.h"
 
 #include "util.h"
+#include <QDateTime>
 #include <QObject>
 
+class QXmppStanzaStub : public QXmppStanza
+{
+public:
+    void toXml(QXmlStreamWriter *) const override {};
+};
+
 class tst_QXmppStanza : public QObject
 {
     Q_OBJECT
 
-private slots:
-    void testExtendedAddress_data();
-    void testExtendedAddress();
+private:
+    Q_SLOT void testExtendedAddress_data();
+    Q_SLOT void testExtendedAddress();
 
-    void testErrorCases_data();
-    void testErrorCases();
-    void testErrorFileTooLarge();
-    void testErrorRetry();
+    Q_SLOT void testErrorCases_data();
+    Q_SLOT void testErrorCases();
+    Q_SLOT void testErrorFileTooLarge();
+    Q_SLOT void testErrorRetry();
+    Q_SLOT void testErrorEnums();
+
+    Q_SLOT void testEncryption();
+    Q_SLOT void testSenderKey();
+    Q_SLOT void testSceTimestamp();
 };
 
 void tst_QXmppStanza::testExtendedAddress_data()
@@ -90,19 +85,19 @@ void tst_QXmppStanza::testErrorCases_data()
     QTest::addColumn<QString>("by");
 
 #define ROW(name, xml, type, condition, text, redirect, by) \
-    QTest::newRow(QT_STRINGIFY(name)) \
-        << QByteArrayLiteral(xml) \
-        << QXmppStanza::Error::type \
-        << QXmppStanza::Error::condition \
-        << text \
-        << redirect \
+    QTest::newRow(QT_STRINGIFY(name))                       \
+        << QByteArrayLiteral(xml)                           \
+        << QXmppStanza::Error::type                         \
+        << QXmppStanza::Error::condition                    \
+        << text                                             \
+        << redirect                                         \
         << by
 
 #define BASIC(xml, type, condition) \
     ROW(condition, xml, type, condition, QString(), QString(), QString())
 
     ROW(
-        empty-text,
+        empty - text,
         "<error type=\"modify\">"
         "<bad-request xmlns=\"urn:ietf:params:xml:ns:xmpp-stanzas\"/>"
         "</error>",
@@ -112,7 +107,7 @@ void tst_QXmppStanza::testErrorCases_data()
         QString(),
         QString());
     ROW(
-        redirection-uri-gone,
+        redirection - uri - gone,
         "<error by=\"example.net\" type=\"cancel\">"
         "<gone xmlns=\"urn:ietf:params:xml:ns:xmpp-stanzas\">"
         "xmpp:romeo@afterlife.example.net"
@@ -124,7 +119,7 @@ void tst_QXmppStanza::testErrorCases_data()
         "xmpp:romeo@afterlife.example.net",
         "example.net");
     ROW(
-        redirection-uri-redirect,
+        redirection - uri - redirect,
         "<error type=\"cancel\">"
         "<redirect xmlns=\"urn:ietf:params:xml:ns:xmpp-stanzas\">"
         "xmpp:rms@afterlife.example.net"
@@ -136,7 +131,7 @@ void tst_QXmppStanza::testErrorCases_data()
         "xmpp:rms@afterlife.example.net",
         QString());
     ROW(
-        redirection-uri-empty,
+        redirection - uri - empty,
         "<error type=\"cancel\">"
         "<redirect xmlns=\"urn:ietf:params:xml:ns:xmpp-stanzas\"/>"
         "</error>",
@@ -146,7 +141,7 @@ void tst_QXmppStanza::testErrorCases_data()
         QString(),
         QString());
     ROW(
-        policy-violation-text,
+        policy - violation - text,
         "<error by=\"example.net\" type=\"modify\">"
         "<policy-violation xmlns=\"urn:ietf:params:xml:ns:xmpp-stanzas\"/>"
         "<text xml:lang=\"en\" xmlns=\"urn:ietf:params:xml:ns:xmpp-stanzas\">The used words are not allowed on this server.</text>"
@@ -157,7 +152,7 @@ void tst_QXmppStanza::testErrorCases_data()
         QString(),
         "example.net");
     ROW(
-        jid-malformed-with-by,
+        jid - malformed - with - by,
         "<error by=\"muc.example.com\" type=\"modify\">"
         "<jid-malformed xmlns=\"urn:ietf:params:xml:ns:xmpp-stanzas\"/>"
         "</error>",
@@ -391,5 +386,53 @@ void tst_QXmppStanza::testErrorRetry()
     QCOMPARE(error.retryDate(), QDateTime(QDate(1985, 10, 26), QTime(1, 35)));
 }
 
+void tst_QXmppStanza::testErrorEnums()
+{
+    QXmppStanza::Error err;
+    QCOMPARE(err.condition(), QXmppStanza::Error::NoCondition);
+    QCOMPARE(err.type(), QXmppStanza::Error::NoType);
+
+    err.setCondition(QXmppStanza::Error::BadRequest);
+    err.setType(QXmppStanza::Error::Cancel);
+
+    err.setCondition(QXmppStanza::Error::Condition(-1));
+    err.setType(QXmppStanza::Error::Type(-1));
+
+    QCOMPARE(err.condition(), QXmppStanza::Error::NoCondition);
+    QCOMPARE(err.type(), QXmppStanza::Error::NoType);
+}
+
+void tst_QXmppStanza::testEncryption()
+{
+    QXmppStanzaStub stanza;
+    QVERIFY(!stanza.e2eeMetadata().has_value());
+    QXmppE2eeMetadata e2eeMetadata;
+    e2eeMetadata.setEncryption(QXmpp::Omemo2);
+    stanza.setE2eeMetadata(e2eeMetadata);
+    QCOMPARE(stanza.e2eeMetadata()->encryption(), QXmpp::Omemo2);
+}
+
+void tst_QXmppStanza::testSenderKey()
+{
+    QXmppStanzaStub stanza;
+    QVERIFY(!stanza.e2eeMetadata().has_value());
+    QXmppE2eeMetadata e2eeMetadata;
+    e2eeMetadata.setSenderKey(QByteArray::fromBase64(QByteArrayLiteral("aFABnX7Q/rbTgjBySYzrT2FsYCVYb49mbca5yB734KQ=")));
+    stanza.setE2eeMetadata(e2eeMetadata);
+    QCOMPARE(stanza.e2eeMetadata()->senderKey(), QByteArray::fromBase64(QByteArrayLiteral("aFABnX7Q/rbTgjBySYzrT2FsYCVYb49mbca5yB734KQ=")));
+}
+
+void tst_QXmppStanza::testSceTimestamp()
+{
+    QXmppStanzaStub stanza;
+    QVERIFY(!stanza.e2eeMetadata().has_value());
+    QXmppE2eeMetadata e2eeMetadata;
+    QVERIFY(e2eeMetadata.senderKey().isNull());
+    QVERIFY(e2eeMetadata.sceTimestamp().isNull());
+    e2eeMetadata.setSceTimestamp(QDateTime(QDate(2022, 01, 01), QTime()));
+    stanza.setE2eeMetadata(e2eeMetadata);
+    QCOMPARE(stanza.e2eeMetadata()->sceTimestamp(), QDateTime(QDate(2022, 01, 01), QTime()));
+}
+
 QTEST_MAIN(tst_QXmppStanza)
 #include "tst_qxmppstanza.moc"
