@@ -1,25 +1,6 @@
-/*
- * Copyright (C) 2008-2021 The QXmpp developers
- *
- * Authors:
- *  Manjeet Dahiya
- *
- * Source:
- *  https://github.com/qxmpp-project/qxmpp
- *
- * This file is a part of QXmpp library.
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- */
+// SPDX-FileCopyrightText: 2012 Manjeet Dahiya <manjeetdahiya@gmail.com>
+//
+// SPDX-License-Identifier: LGPL-2.1-or-later
 
 #include "QXmppStreamFeatures.h"
 
@@ -35,8 +16,9 @@ static void parsePacketWithStream(T &packet, const QByteArray &xml)
 
     QString err;
     bool parsingSuccess = doc.setContent(wrappedXml, true, &err);
-    if (!err.isNull())
+    if (!err.isNull()) {
         qDebug() << err;
+    }
     QVERIFY(parsingSuccess);
 
     packet.parse(doc.documentElement().firstChildElement());
@@ -46,11 +28,11 @@ class tst_QXmppStreamFeatures : public QObject
 {
     Q_OBJECT
 
-private slots:
-    void testEmpty();
-    void testRequired();
-    void testFull();
-    void testSetters();
+private:
+    Q_SLOT void testEmpty();
+    Q_SLOT void testRequired();
+    Q_SLOT void testFull();
+    Q_SLOT void testSetters();
 };
 
 void tst_QXmppStreamFeatures::testEmpty()
