@@ -1,26 +1,7 @@
-/*
- * Copyright (C) 2008-2021 The QXmpp developers
- *
- * Authors:
- *  Olivier Goffart
- *  Jeremy Lainé
- *
- * Source:
- *  https://github.com/qxmpp-project/qxmpp
- *
- * This file is a part of QXmpp library.
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- */
+// SPDX-FileCopyrightText: 2012 Oliver Goffart <ogoffart@woboq.com>
+// SPDX-FileCopyrightText: 2012 Jeremy Lainé <jeremy.laine@m4x.org>
+//
+// SPDX-License-Identifier: LGPL-2.1-or-later
 
 #include "QXmppStreamInitiationIq_p.h"
 #include "QXmppTransferManager.h"
@@ -31,11 +12,10 @@ class tst_QXmppStreamInitiationIq : public QObject
 {
     Q_OBJECT
 
-private slots:
-    void testFileInfo_data();
-    void testFileInfo();
-    void testOffer();
-    void testResult();
+    Q_SLOT void testFileInfo_data();
+    Q_SLOT void testFileInfo();
+    Q_SLOT void testOffer();
+    Q_SLOT void testResult();
 };
 
 void tst_QXmppStreamInitiationIq::testFileInfo_data()
@@ -49,7 +29,7 @@ void tst_QXmppStreamInitiationIq::testFileInfo_data()
 
     QTest::newRow("normal")
         << QByteArray("<file xmlns=\"http://jabber.org/protocol/si/profile/file-transfer\" name=\"test.txt\" size=\"1022\"/>")
-        << QDateTime()
+        << QDateTime().toUTC()
         << QString()
         << QByteArray()
         << QString("test.txt")
