@@ -1,25 +1,6 @@
-/*
- * Copyright (C) 2008-2021 The QXmpp developers
- *
- * Author:
- *  Jeremy Lainé
- *
- * Source:
- *  https://github.com/qxmpp-project/qxmpp
- *
- * This file is a part of QXmpp library.
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- */
+// SPDX-FileCopyrightText: 2012 Jeremy Lainé <jeremy.laine@m4x.org>
+//
+// SPDX-License-Identifier: LGPL-2.1-or-later
 
 #include "QXmppStun.h"
 
@@ -30,13 +11,13 @@ class tst_QXmppStunMessage : public QObject
 {
     Q_OBJECT
 
-private slots:
-    void testFingerprint();
-    void testIntegrity();
-    void testIPv4Address();
-    void testIPv6Address();
-    void testXorIPv4Address();
-    void testXorIPv6Address();
+private:
+    Q_SLOT void testFingerprint();
+    Q_SLOT void testIntegrity();
+    Q_SLOT void testIPv4Address();
+    Q_SLOT void testIPv6Address();
+    Q_SLOT void testXorIPv4Address();
+    Q_SLOT void testXorIPv6Address();
 };
 
 void tst_QXmppStunMessage::testFingerprint()
