@@ -1,25 +1,6 @@
-/*
- * Copyright (C) 2008-2021 The QXmpp developers
- *
- * Authors:
- *  Jeremy Lainé
- *
- * Source:
- *  https://github.com/qxmpp-project/qxmpp
- *
- * This file is a part of QXmpp library.
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- */
+// SPDX-FileCopyrightText: 2015 Jeremy Lainé <jeremy.laine@m4x.org>
+//
+// SPDX-License-Identifier: LGPL-2.1-or-later
 
 #include "QXmppClient.h"
 #include "QXmppServer.h"
@@ -33,14 +14,13 @@ class tst_QXmppTransferManager : public QObject
 {
     Q_OBJECT
 
-private slots:
-    void init();
-    void testSendFile_data();
-    void testSendFile();
-
-    void acceptFile(QXmppTransferJob *job);
-
 private:
+    Q_SLOT void init();
+    Q_SLOT void testSendFile_data();
+    Q_SLOT void testSendFile();
+
+    Q_SLOT void acceptFile(QXmppTransferJob *job);
+
     QBuffer receiverBuffer;
     QXmppTransferJob *receiverJob;
 };
@@ -89,7 +69,7 @@ void tst_QXmppTransferManager::testSendFile()
     const quint16 testPort = 12345;
 
     QXmppLogger logger;
-    //logger.setLoggingType(QXmppLogger::StdoutLogging);
+    // logger.setLoggingType(QXmppLogger::StdoutLogging);
 
     // prepare server
     TestPasswordChecker passwordChecker;
