@@ -1,25 +1,6 @@
-/*
- * Copyright (C) 2008-2021 The QXmpp developers
- *
- * Author:
- *  Jeremy Lainé
- *
- * Source:
- *  https://github.com/qxmpp-project/qxmpp
- *
- * This file is a part of QXmpp library.
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- */
+// SPDX-FileCopyrightText: 2012 Jeremy Lainé <jeremy.laine@m4x.org>
+//
+// SPDX-License-Identifier: LGPL-2.1-or-later
 
 #include "QXmppVCardIq.h"
 
@@ -30,14 +11,14 @@ class tst_QXmppVCardIq : public QObject
 {
     Q_OBJECT
 
-private slots:
-    void testAddress_data();
-    void testAddress();
-    void testEmail_data();
-    void testEmail();
-    void testPhone_data();
-    void testPhone();
-    void testVCard();
+private:
+    Q_SLOT void testAddress_data();
+    Q_SLOT void testAddress();
+    Q_SLOT void testEmail_data();
+    Q_SLOT void testEmail();
+    Q_SLOT void testPhone_data();
+    Q_SLOT void testPhone();
+    Q_SLOT void testVCard();
 };
 
 void tst_QXmppVCardIq::testAddress_data()
